package ru.loylabs.portal.aop;

import lombok.RequiredArgsConstructor;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.Idea;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.EmailNotificationFactory;
import ru.loylabs.portal.service.interfaces.NotificationSender;
import ru.loylabs.portal.service.notification.email.EmailNotification;

import java.util.List;
import java.util.stream.Collectors;

@Aspect
@Component
@RequiredArgsConstructor
public class IdeaAspect {

	private final PersonRepository personRepository;
	private final EmailNotificationFactory emailNotificationFactory;
	@Qualifier("emailNotificationSenderImpl")
	private final NotificationSender<EmailNotification> emailNotificationSender;

	@AfterReturning(value = "execution(* ru.loylabs.portal.service.interfaces.IdeaService.saveIdea(..))",
					returning = "idea")
	public void sendNotificationNewIdea(Idea idea) {
		var receivers = personRepository.findAllByRoleRoleIn(List.of("ADMIN", "EDITOR"))
										.stream()
										.filter(rec -> rec.getId() != idea.getAuthor().getId() && !rec.isBlocked())
										.collect(Collectors.toSet());

		for (Person receiver : receivers) {
			emailNotificationSender.send(
					emailNotificationFactory.createNewIdeaMessage(receiver, idea.getAuthor(), idea)
			);
		}
	}
	// TODO: 07.12.2023  использовать не конкретный поток а пул


}
