package ru.loylabs.portal.aop;

import lombok.RequiredArgsConstructor;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.KbArticle;
import ru.loylabs.portal.entity.KbSection;
import ru.loylabs.portal.presentation.WebUtils;
import ru.loylabs.portal.service.interfaces.KbArticleService;

@Aspect
@Component
@RequiredArgsConstructor
public class KbAspect {

	private final KbArticleService kbArticleService;

	@Pointcut("within(ru.loylabs.portal.service.interfaces.KbSectionService+)")
	public void isSectionsService() {
	}

	@AfterReturning(returning = "kbSection", pointcut = "isSectionsService()")
	public void addTopArticles(KbSection kbSection) {
		var criteria = WebUtils.getCriteria("search");
		Page<KbArticle> kbArticles = kbArticleService
				.getAllArticles(0, 10, "name,asc", criteria, kbSection.getId());
		kbSection.setTopArticles(kbArticles.getContent());
	}

	@AfterReturning(returning = "page", pointcut = "isSectionsService()" +
			"&& !execution(* ru.loylabs.portal.service.KbSectionServiceImpl.searchSectionWithRelevantContent(..))")
	public void addTopArticlesForPage(Page<KbSection> page) {
		page.forEach(this::addTopArticles);
	}
}
