package ru.loylabs.portal.aop;

import lombok.RequiredArgsConstructor;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.entity.Story;
import ru.loylabs.portal.entity.StoryGroup;
import ru.loylabs.portal.repository.StoryGroupRepository;

import java.util.Comparator;
import java.util.stream.Collectors;

//TODO add transactions with @Around
// possible parallel transactions
@Aspect
@Component
@RequiredArgsConstructor
public class StoryAspect {
	private final StoryGroupRepository storyGroupRepository;

	@Pointcut("within(ru.loylabs.portal.service.interfaces.StoryService+) " +
			"&& @annotation(ru.loylabs.portal.annotation.UpdateStoryGroupTime)")
	public void allFromStoryServiceWithUpdateStoryGroupTimeAnnotation() {
	}

	@AfterReturning(returning = "story", pointcut = "allFromStoryServiceWithUpdateStoryGroupTimeAnnotation()")
	public void updateStoryGroupTime(Story story) {
		updateStoryGroupTime(story.getGroup());
	}

	@AfterReturning(returning = "group", pointcut = "allFromStoryServiceWithUpdateStoryGroupTimeAnnotation()")
	private void updateStoryGroupTime(StoryGroup group) {
		var instant = group.getStories().stream()
				.sorted(Comparator.comparing(Record::getDate))
				.collect(Collectors.toList())
				.get(group.getStories().size() - 1).getDate();

		group.setUpdateTime(instant);
		storyGroupRepository.save(group);
	}
}
