package ru.loylabs.portal.aop;

import lombok.RequiredArgsConstructor;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.StoryGroup;
import ru.loylabs.portal.presentation.search.SearchReversePolishNotation;
import ru.loylabs.portal.service.interfaces.StoryService;

import java.util.ArrayList;

@Aspect
@Component
@RequiredArgsConstructor
public class StoryGroupAspect {
	private final StoryService storyService;


	@AfterReturning(
			returning = "group",
			pointcut = "execution(ru.loylabs.portal.entity.StoryGroup " +
					"ru.loylabs.portal.service.interfaces.StoryGroupService.*(..))"
	)
	private void formAdditionalGroupData(StoryGroup group) {
		int page = 0;
		int size = 10;
		String sort = "date,asc";
		var criteria = new SearchReversePolishNotation(new ArrayList<>());
		var stories = storyService.getAllStoriesFromGroup(page, size, sort, criteria, group.getId());
		group.setFirstStories(stories.getContent());
		group.setAllStoriesAmount(stories.getTotalElements());
	}

	@AfterReturning(
			returning = "groups",
			pointcut = "execution(org.springframework.data.domain.Page<ru.loylabs.portal.entity.StoryGroup>" +
					" ru.loylabs.portal.service.interfaces.StoryGroupService.*(..))"
	)
	private void formAdditionalGroupDataPage(Page<StoryGroup> groups) {
		groups.forEach(this::formAdditionalGroupData);
	}
}
