package ru.loylabs.portal.aop;

import lombok.RequiredArgsConstructor;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.enums.RecordType;
import ru.loylabs.portal.repository.RecordRepository;

import java.util.Set;

@Aspect
@Component
@RequiredArgsConstructor
public class TaskAspect {
	private final RecordRepository recordRepository;

	@Pointcut("execution(ru.loylabs.portal.entity.Task " +
			"ru.loylabs.portal.service.interfaces.TaskService.*(..))")
	private void allWhichReturnTask() {
	}

	@Pointcut("execution(org.springframework.data.domain.Page<ru.loylabs.portal.entity.Task> " +
			"ru.loylabs.portal.service.interfaces.TaskService.*(..))")
	private void allWhichReturnTaskPage() {
	}


	@AfterReturning(returning = "task", pointcut = "allWhichReturnTask()")
	private void initLastModifyInOne(Task task) {
		initLastModify(task);
	}

	@AfterReturning(returning = "tasks", pointcut = "allWhichReturnTaskPage()")
	private void initLastModifyInPage(Page<Task> tasks) {
		tasks.forEach(this::initLastModify);
	}

	private void initLastModify(Task task) {
		var record = recordRepository.findTopByRecordTypeInAndParentRecordOrderByDateDesc(
						Set.of(RecordType.COMMENT, RecordType.TASK_STATUS_UPDATE),
						task)
				.orElse(new Record());
		task.setModifyAt(record.getDate());
		task.setModifyBy(record.getAuthor());
	}
}

