package ru.loylabs.portal.config;

import java.util.Properties;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.task.TaskExecutor;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.JavaMailSenderImpl;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;

@Configuration
public class EmailConfig {

	private static final int EMAIL_SENDER_EXECUTOR_CORE_THREADS = 4;
	private static final int EMAIL_SENDER_EXECUTOR_MAX_THREADS = 8;

	private static final long AWAIT_TERMINATION_MILLIS = 60000;

	@Value("${spring.mail.transport.protocol}")
	private String transportProtocol;
	@Value("${spring.mail.smtp.host}")
	private String mailServerHost;
	@Value("${spring.mail.smtp.port}")
	private Integer mailServerPort;
	@Value("${spring.mail.smtp.username}")
	private String mailServerUsername;
	@Value("${spring.mail.smtp.password}")
	private String mailServerPassword;
	@Value("${spring.mail.debug}")
	private String debug;
	@Value("${spring.mail.smtp.auth}")
	private String auth;
	@Value("${spring.mail.smtp.starttls.enable}")
	private String starttls;

	@Bean
	public JavaMailSender getJavaMailSender() {
		JavaMailSenderImpl mailSender = new JavaMailSenderImpl();

		mailSender.setHost(mailServerHost);
		mailSender.setPort(mailServerPort);
		mailSender.setUsername(mailServerUsername);
		mailSender.setPassword(mailServerPassword);

		Properties props = mailSender.getJavaMailProperties();
		props.put("mail.transport.protocol", transportProtocol);
		props.put("mail.smtp.auth", auth);
		props.put("mail.smtp.starttls.enable", starttls);
		props.put("mail.debug", debug);
		props.put("mail.mime.allowutf8", true);

		return mailSender;
	}

	@Bean("emailSenderTaskExecutor")
	public TaskExecutor emailSenderTaskExecutor() {
		ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();
		executor.setCorePoolSize(EMAIL_SENDER_EXECUTOR_CORE_THREADS);
		executor.setMaxPoolSize(EMAIL_SENDER_EXECUTOR_MAX_THREADS);
		executor.setDaemon(false);
		executor.setAwaitTerminationMillis(AWAIT_TERMINATION_MILLIS);
		executor.setThreadNamePrefix("email-sender-");

		return executor;
	}

}
