package ru.loylabs.portal.config;

import lombok.Getter;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.ConstructorBinding;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Positive;

@Getter
@ConfigurationProperties(prefix = "front-end")
public class FrontEndConfigProperties {

	@NotNull
	private final boolean ssl;

	@NotBlank
	private final String host;

	@NotNull
	@Positive
	private final int port;

	@NotBlank
	private final String resetPasswordPath;

	@NotBlank
	private final String loginLinkPath;

	@NotBlank
	private final String ideasLinkPath;

	@ConstructorBinding
	public FrontEndConfigProperties(boolean ssl, String host, int port, String resetPasswordPath, String loginLinkPath, String ideasLinkPath) {
		this.ssl = ssl;
		this.host = host;
		this.port = port;
		this.resetPasswordPath = resetPasswordPath;
		this.loginLinkPath = loginLinkPath;
		this.ideasLinkPath = ideasLinkPath;
	}

	public String getScheme() {
		return isSsl() ? "https" : "http";
	}

}
