package ru.loylabs.portal.config;

import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.RedisConnectionFailureException;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.SchedulingConfigurer;
import org.springframework.scheduling.concurrent.ThreadPoolTaskScheduler;
import org.springframework.scheduling.config.ScheduledTaskRegistrar;
import org.springframework.util.ErrorHandler;
import ru.loylabs.portal.exception.ApplicationException;

@Configuration
@EnableScheduling
@Slf4j
public class SchedulingConfig implements SchedulingConfigurer {
	private final ThreadPoolTaskScheduler taskScheduler;

	public SchedulingConfig() {
		taskScheduler = new ThreadPoolTaskScheduler();
		taskScheduler.setErrorHandler(getScheduledErrorHandler());
		taskScheduler.setThreadNamePrefix("@scheduled-");

		taskScheduler.initialize();
	}

	public ErrorHandler getScheduledErrorHandler() {
		return t -> {
			if (t instanceof ApplicationException) log.error("Service error {}", t.getMessage());
			if (t instanceof RedisConnectionFailureException) {
				log.error("Redis error {}", t.getMessage());
			} else log.error(t.getMessage(), t);
		};
	}

	@Override
	public void configureTasks(ScheduledTaskRegistrar taskRegistrar) {
		taskRegistrar.setScheduler(taskScheduler);
	}
}
