package ru.loylabs.portal.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationPropertiesScan;
import org.springframework.context.MessageSource;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.EnableAspectJAutoProxy;
import org.springframework.context.support.ReloadableResourceBundleMessageSource;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.validation.Validator;
import org.springframework.validation.beanvalidation.LocalValidatorFactoryBean;
import org.springframework.web.servlet.config.annotation.ResourceHandlerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
import ru.loylabs.portal.utility.PathUtil;

@EnableAspectJAutoProxy
@ConfigurationPropertiesScan
@Configuration
public class ServiceConfig implements WebMvcConfigurer {

	private static final String LOCALE_LANGUAGE_PATH = "classpath:/loyalty";
	private static final String LOCALE_ERRORS_PATH = "classpath:/errors";
	private static final String DEFAULT_ENCODING = "UTF-8";

	@Autowired
	PathUtil pathUtil;

	@Bean("messageSource")
	public MessageSource messageSource() {
		ReloadableResourceBundleMessageSource messageSource = new ReloadableResourceBundleMessageSource();
		messageSource.setBasenames(LOCALE_ERRORS_PATH, LOCALE_LANGUAGE_PATH);
		messageSource.setDefaultEncoding(DEFAULT_ENCODING);
		messageSource.setUseCodeAsDefaultMessage(true);
		return messageSource;
	}

	@Override
	public Validator getValidator() {
		LocalValidatorFactoryBean factory = new LocalValidatorFactoryBean();
		factory.setValidationMessageSource(messageSource());
		return factory;
	}

	@Bean
	public PasswordEncoder passwordEncoder() {
		return new BCryptPasswordEncoder(8);
	}

	@Override
	public void addResourceHandlers(ResourceHandlerRegistry registry) {
		registry.addResourceHandler("/attachments/**")
				.addResourceLocations(pathUtil.getPath());
	}

}
