package ru.loylabs.portal.config;

import lombok.RequiredArgsConstructor;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.springframework.security.config.annotation.method.configuration.EnableGlobalMethodSecurity;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.http.SessionCreationPolicy;
import org.springframework.security.web.SecurityFilterChain;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;
import ru.loylabs.portal.config.jwt.JwtFilter;
import ru.loylabs.portal.exception.ExceptionHandlerFilter;

import static ru.loylabs.portal.config.URIConstants.MATCH_ALL_WILDCARD;
import static ru.loylabs.portal.config.URIConstants.PASSWORDS_URI;
import static ru.loylabs.portal.config.URIConstants.VERSION_1_URI;


@Configuration
@EnableWebSecurity
@EnableGlobalMethodSecurity(prePostEnabled = true)
@RequiredArgsConstructor
public class WebSecurityConfig {

	private final JwtFilter jwtFilter;
	private final ExceptionHandlerFilter exceptionFilter;

	private static final String[] AUTH_WHITELIST = {
			"/v1/auth/**",
			"/webjars/**",
			"/v2/api-docs",
			"/v3/api-docs",
			"/swagger-ui/**",
			"/swagger-ui.html",
			"/swagger-resources/**",
			"/attachments/**",
			"/stomp/**",
			"/management/**",
			"/actuator/**",
			VERSION_1_URI + PASSWORDS_URI + MATCH_ALL_WILDCARD
	};

	@Bean
	public SecurityFilterChain filterChain(HttpSecurity http) throws Exception {
		return http
				.cors()
				.and()
				.csrf().disable()
				.sessionManagement()
				.sessionCreationPolicy(SessionCreationPolicy.STATELESS)
				.and()
				.authorizeHttpRequests()
				.antMatchers(AUTH_WHITELIST).permitAll()
				.antMatchers(HttpMethod.POST, "/v1/persons/yandex").permitAll()
				.antMatchers("/").permitAll()
				.anyRequest().authenticated()
				.and()
				.addFilterBefore(exceptionFilter, UsernamePasswordAuthenticationFilter.class)
				.addFilterAfter(jwtFilter, UsernamePasswordAuthenticationFilter.class)
				.build();
	}
}
