package ru.loylabs.portal.config.async;

import lombok.extern.slf4j.Slf4j;
import org.springframework.aop.interceptor.AsyncUncaughtExceptionHandler;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.AsyncConfigurer;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import ru.loylabs.portal.config.async.properties.AsyncProperties;
import ru.loylabs.portal.config.async.properties.DefaultAsyncProperties;
import ru.loylabs.portal.config.async.properties.ListenersAsyncProperties;
import ru.loylabs.portal.config.async.properties.StoryAsyncProperties;

import java.util.concurrent.Executor;

@Configuration
@EnableAsync(proxyTargetClass = true)
@Slf4j
public class AsyncConfig implements AsyncConfigurer {

    @Autowired
    private ListenersAsyncProperties listenersAsyncProperties;
    @Autowired
    private StoryAsyncProperties storyAsyncProperties;
    @Autowired
    private DefaultAsyncProperties defaultAsyncProperties;

    @Bean
    public Executor listenersThreadPoolTaskExecutor() {
        return getExecutorWithProperties(listenersAsyncProperties);
    }

    @Bean
    public Executor storiesThreadPoolTaskExecutor() {
        return getExecutorWithProperties(storyAsyncProperties);
    }

    @Override
    public Executor getAsyncExecutor() {
        return getExecutorWithProperties(defaultAsyncProperties);
    }

    @Override
    public AsyncUncaughtExceptionHandler getAsyncUncaughtExceptionHandler() {
        return new DefaultAsyncExceptionHandler();
    }

    private Executor getExecutorWithProperties(AsyncProperties properties) {
        ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();
        executor.setCorePoolSize(properties.getCorePoolSize());
        executor.setMaxPoolSize(properties.getMaxPoolSize());
        executor.setQueueCapacity(properties.getQueueCapacity());
        executor.setThreadNamePrefix(properties.getPrefix());
        executor.afterPropertiesSet();
        return executor;
    }
}
