package ru.loylabs.portal.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.Type;
import ru.loylabs.portal.enums.AchievementStatus;

import javax.persistence.*;
import java.time.Instant;
import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

@Getter
@Setter
@Entity
public class Achievement {
	@Id
	@GeneratedValue
	private UUID id;

	private String name;

	@ManyToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
	@JoinColumn(name = "owner_Id", referencedColumnName = "id")
	private Person owner;

	@ManyToOne(cascade = {CascadeType.MERGE})
	@JoinColumn(name = "author_id", referencedColumnName = "id")
	private Person author;


	@Enumerated(EnumType.STRING)
	@Type(type = "achievement_status_enum_type")
	private AchievementStatus status = AchievementStatus.NEW;

	private Instant creationDate;

	@ManyToMany(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
	@JoinTable(name = "achievement_observers",
			joinColumns = @JoinColumn(name = "achievement_id"),
			inverseJoinColumns = @JoinColumn(name = "person_id"))
	private Set<Person> observers = new HashSet<>();

	@OneToMany(mappedBy = "achievement", cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REMOVE}, orphanRemoval = true)
	private final Set<Task> tasks = new HashSet<>();

	@JsonIgnore
	@OneToMany(mappedBy = "achievement", cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REMOVE}, orphanRemoval = true)
	private final Set<TaskTag> availableTags = new HashSet<>();

	@Transient
	private long tasksSize;

	@Transient
	private long countOfDoneTasks;
}
