package ru.loylabs.portal.entity;

import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.hibernate.annotations.Type;
import ru.loylabs.portal.enums.BellNotificationType;
import ru.loylabs.portal.service.interfaces.Notification;
import ru.loylabs.portal.service.interfaces.NotificationType;

import javax.persistence.*;
import java.time.Instant;
import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

@Getter
@Setter
@Entity
@NoArgsConstructor
public class BellNotification implements Notification<NotificationType> {

	@Id
	@GeneratedValue
	private UUID id;

	@Enumerated(EnumType.STRING)
	@Type(type = "bell_notification_type_enum_type")
	private BellNotificationType notificationType;

	@ManyToOne
	@JoinColumn(name = "author_id", referencedColumnName = "id")
	private Person author;

	private String header;

	private String content;

	private Instant date;

	private String link;

	@OneToMany
	@JoinTable(name = "bell_notification_personal",
			joinColumns = @JoinColumn(name = "bell_notification_id"),
			inverseJoinColumns = @JoinColumn(name = "person_id"))
	private final Set<Person> receivers = new HashSet<>();

	private UUID subjectId;

	public BellNotification(Person author, Instant date, String header, String content, BellNotificationType notificationType, String link,UUID subjectId) {
		this.author = author;
		this.date = date;
		this.header = header;
		this.content = content;
		this.notificationType = notificationType;
		this.link = link;
		this.subjectId = subjectId;
	}
}
