package ru.loylabs.portal.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.Type;
import ru.loylabs.portal.enums.CalendarEventType;

import javax.persistence.*;
import java.time.LocalDate;
import java.time.ZonedDateTime;
import java.util.UUID;

import static java.time.ZoneOffset.UTC;

@Data
@Entity
@Table(name = "corporate_calendar_event")
@NoArgsConstructor
public class CorporateCalendarEvent {
	@Id
	@GeneratedValue
	private UUID id;

	@Column(name = "event_name")
	private String eventName;

	@Column(name = "description")
	private String description;

	@Enumerated(EnumType.STRING)
	@Type(type = "calendar_event_type_enum_type")
	private CalendarEventType eventType;

	@Column(name = "start_date_time")
	private ZonedDateTime startDateTime;

	@Column(name = "end_date_time")
	private ZonedDateTime endDateTime;

	@JsonIgnore
	@ManyToOne(cascade = {CascadeType.PERSIST, CascadeType.MERGE})
	@JoinTable(name = "corporate_calendar_event_target",
			joinColumns = @JoinColumn(name = "event_id"),
			inverseJoinColumns = @JoinColumn(name = "person_id"))
	private Person target;

	@Column(name = "repeat_id")
	private UUID repeatId;

	@Column(name = "is_generated")
	private Boolean isGenerated;

	public CorporateCalendarEvent(String eventName,
								  String description,
								  CalendarEventType eventType,
								  LocalDate localDate) {
		this.eventName = eventName;
		this.description = description;
		this.eventType = eventType;
		this.startDateTime = localDate.atTime(0, 0, 0).atZone(UTC);
		this.endDateTime = localDate.atTime(23, 59, 59).atZone(UTC);
	}

	public CorporateCalendarEvent(String eventName,
								  String description,
								  CalendarEventType eventType,
								  LocalDate localDate,
								  boolean isGenerated) {
		this(eventName, description, eventType, localDate);
		this.isGenerated = isGenerated;
	}

	public CorporateCalendarEvent(String eventName,
								  String description,
								  CalendarEventType eventType,
								  ZonedDateTime startDateTime,
								  ZonedDateTime endDateTime,
								  Person person) {
		this.eventName = eventName;
		this.description = description;
		this.eventType = eventType;
		this.startDateTime = startDateTime;
		this.endDateTime = endDateTime;
		this.target = person;
	}

	public CorporateCalendarEvent(String eventName,
								  String description,
								  CalendarEventType eventType,
								  ZonedDateTime startDateTime,
								  ZonedDateTime endDateTime,
								  UUID repeatId) {
		this.description = description;
		this.eventName = eventName;
		this.eventType = eventType;
		this.startDateTime = startDateTime;
		this.endDateTime = endDateTime;
		this.repeatId = repeatId;
	}
}
