package ru.loylabs.portal.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.Hibernate;
import org.hibernate.annotations.Type;
import ru.loylabs.portal.entity.audit.AuditListener;
import ru.loylabs.portal.entity.audit.Auditable;
import ru.loylabs.portal.entity.audit.PersonAudit;
import ru.loylabs.portal.enums.Gender;

import javax.persistence.*;
import java.time.LocalDate;
import java.util.List;
import java.util.Objects;
import java.util.UUID;

@Entity
@Getter
@Setter
@EntityListeners(AuditListener.class)
public class Person implements Auditable<PersonAudit> {
    @Id
    @GeneratedValue
    @EqualsAndHashCode.Include
    private UUID id;

    private String username;

    private String password;

    private String name;

    private String surname;

    private String patronymic;

    private LocalDate dob;

    @Enumerated(EnumType.STRING)
    @Type(type = "gender_enum_type")
    private Gender gender;

    @OneToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST}, orphanRemoval = true)
    @JoinColumn(name = "job_id", referencedColumnName = "id")
    private Job job;

    @ManyToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
    @JoinColumn(name = "city_id")
    private City city;

    private String description;

    @OneToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
    @JoinColumn(name = "contact_id", referencedColumnName = "id")
    private Contact contact;

    private LocalDate hired;

    private LocalDate fired;

    private boolean blocked;

    @ManyToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
    @JoinColumn(name = "avatar_id")
    private Attachment avatar;

    @ManyToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
    @JoinColumn(name = "background_id")
    private Attachment background;

    @ManyToOne(fetch = FetchType.EAGER)
    @JoinColumn(name = "role_id")
    private SecurityRole role;

    private String resetPasswordToken;

    @Column(name = "external_user_id", nullable = true, unique = true)
    private String externalUserId;

    @OneToMany(mappedBy = "person", cascade = {CascadeType.MERGE, CascadeType.PERSIST}, fetch = FetchType.EAGER)
    private List<PersonSkill> skills;

    @JsonIgnore
    @OneToOne(mappedBy = "person", cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REMOVE}, orphanRemoval = true)
    private PersonAudit personAudit;

    @ManyToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
    @JoinTable(name = "person_status",
            joinColumns = {@JoinColumn(name = "person_id")},
            inverseJoinColumns = {@JoinColumn(name = "status_id")})
    private Status status;

    @Override
    public PersonAudit getAudit() {
        return personAudit;
    }

    @Override
    public void setAudit(PersonAudit auditEntity) {
        this.personAudit = auditEntity;
    }

    @Override
    public PersonAudit initAudit() {
        var audit = new PersonAudit();
        this.personAudit = audit;
        audit.setEntity(this);
        return audit;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || Hibernate.getClass(this) != Hibernate.getClass(o)) return false;
        Person person = (Person) o;
        return id != null && Objects.equals(id, person.id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }
}

