package ru.loylabs.portal.entity;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.hibernate.annotations.Type;
import ru.loylabs.portal.enums.RecordType;

import javax.persistence.*;
import java.time.Instant;
import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

@Entity
@Getter
@Setter
@AllArgsConstructor
@NoArgsConstructor
@Inheritance(strategy = InheritanceType.JOINED)
public class Record {
	@Id
	@GeneratedValue
	private UUID id;

	@ManyToOne
	@JoinColumn(name = "author_id", referencedColumnName = "id")
	private Person author;

	private Instant date;

	private String content;

	@Enumerated(EnumType.STRING)
	@Type(type = "record_type_enum_type")
	private RecordType recordType;

	private boolean modified = false;

	@OneToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
	@JoinColumn(name = "reaction_id", referencedColumnName = "id")
	private Reaction reaction;

	@OneToMany(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
	@JoinTable(name = "record_attachment",
			joinColumns = @JoinColumn(name = "record_id"),
			inverseJoinColumns = @JoinColumn(name = "attachment_id"))
	private final Set<Attachment> attachments = new HashSet<>();

	@ManyToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
	@JoinTable(name = "record_community",
			joinColumns = @JoinColumn(name = "record_id"),
			inverseJoinColumns = @JoinColumn(name = "community_id"))
	private Community community;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinTable(name = "record_comment",
			joinColumns = @JoinColumn(name = "comment_record_id"),
			inverseJoinColumns = @JoinColumn(name = "parent_record_id")
	)
	private Record parentRecord;

	@OneToMany(cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REMOVE},
			mappedBy = "parentRecord",
			fetch = FetchType.LAZY)
	private final Set<Record> comments = new HashSet<>();
}