package ru.loylabs.portal.entity;

import java.util.Set;
import java.util.UUID;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.Transient;
import lombok.Getter;
import lombok.Setter;
import ru.loylabs.portal.enums.CredentialPermission;

// TODO 2023-10-12: Можно добавить аудит. Наверное)
@Entity
@Getter
public class SecurityRole {

	@Id
	@GeneratedValue
	@Setter
	private UUID id;

	@Setter
	private String role;

	@Setter
	private String name;

	@Setter
	private String description;

	@Column(name = "is_mutable")
	private Boolean isMutable = Boolean.TRUE;

	@Setter
	@ManyToMany(cascade = CascadeType.MERGE, fetch = FetchType.EAGER)
	@JoinTable(
			name = "role_permission",
			joinColumns = { @JoinColumn(name = "role_id") },
			inverseJoinColumns = { @JoinColumn(name = "permission_id") }
	)
	private Set<SecurityPermission> permissions;

	@Transient
	public boolean hasCredentialPermission(CredentialPermission permission) {
		return getPermissions() != null && getPermissions().stream().anyMatch(sp -> sp.getPermission().equals(permission));
	}

}


