package ru.loylabs.portal.entity;

import lombok.*;
import ru.loylabs.portal.enums.RecordType;

import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToOne;
import java.time.Instant;
import java.time.LocalDateTime;
import java.util.Collection;
import java.util.Collections;
import java.util.UUID;

@Getter
@Setter
@Entity
@NoArgsConstructor
@AllArgsConstructor
public class Story extends Record {
	private String header;
	private LocalDateTime expireTime;
	private Integer priority;

	@ManyToOne
	@JoinTable(name = "story_group_story",
			joinColumns = @JoinColumn(name = "story_id"),
			inverseJoinColumns = @JoinColumn(name = "story_group_id"))
	private StoryGroup group;

	@Builder
	public Story(UUID id,
				 Person author,
				 Instant date,
				 String content,
				 boolean modified,
				 Reaction reaction,
				 Community community,
				 Record parentRecord,
				 String header,
				 LocalDateTime expireTime,
				 Integer priority,
				 StoryGroup group,
				 Collection<? extends Attachment> attachments) {
		super(id, author, date, content, RecordType.STORY, modified, reaction, community, parentRecord);
		this.header = header;
		this.expireTime = expireTime;
		this.priority = priority;
		this.group = group;
		this.getAttachments().addAll(attachments);
	}
}