package ru.loylabs.portal.entity;

import lombok.*;
import org.hibernate.annotations.Type;
import ru.loylabs.portal.enums.StoryGroupType;

import javax.persistence.*;
import java.time.Instant;
import java.util.*;

@Getter
@Setter
@Entity
public class StoryGroup {
    @Id
    @GeneratedValue
    private UUID id;

    private Boolean pinned;

    private Instant updateTime;

    @Enumerated(EnumType.STRING)
    @Type(type = "story_group_enum_type")
    private StoryGroupType groupType;

    @ManyToOne
    @JoinColumn(name = "author_id", referencedColumnName = "id")
    private Person author;

    @OneToMany(cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REMOVE}, fetch = FetchType.LAZY, mappedBy = "group", orphanRemoval = true)
    private List<Story> stories;

    @Transient
    private List<Story> firstStories;

    @Transient
    private long allStoriesAmount;

    @Builder
    public StoryGroup(UUID id, Boolean pinned, Instant updateTime, StoryGroupType groupType, Person author, List<Story> stories, List<Story> firstStories, long allStoriesAmount) {
        this.id = id;
        this.pinned = pinned;
        this.updateTime = updateTime;
        this.groupType = groupType;
        this.author = author;
        this.stories = stories == null ? new LinkedList<>() : stories;
        this.firstStories = firstStories;
        this.allStoriesAmount = allStoriesAmount;
    }

    public StoryGroup() {
        this.stories = new LinkedList<>();
    }

    @PreRemove
    private void removeWithDetach() {
        new ArrayList<>(stories).forEach(this::detachStory);
    }

    public void addStory(Story story){
        stories.add(story);
    }

    public void detachAllStories(){
        stories.forEach(story -> story.setGroup(null));
        stories.clear();
    }

    public void detachStory(Story story) {
        stories.remove(story);
        story.setGroup(null);
    }
}