package ru.loylabs.portal.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.Type;
import ru.loylabs.portal.enums.TaskStatus;

import javax.persistence.*;
import java.time.Instant;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

@Entity
@Getter
@Setter
public class Task extends Record {

	@ManyToOne(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
	@JoinColumn(name = "achievement_id", referencedColumnName = "id")
	@JsonIgnore
	private Achievement achievement;

	private String header;

	private int sequence;

	@Enumerated(EnumType.STRING)
	@Type(type = "task_status_enum_type")
	private TaskStatus status = TaskStatus.PENDING;

	@ManyToMany(cascade = {CascadeType.MERGE, CascadeType.PERSIST})
	@JoinTable(name = "task_observers",
			joinColumns = @JoinColumn(name = "task_id"),
			inverseJoinColumns = @JoinColumn(name = "person_id"))
	private Set<Person> observers = new HashSet<>();

	@ManyToMany(cascade = {CascadeType.MERGE,CascadeType.PERSIST, CascadeType.REMOVE})
	@JoinTable(name = "task_tag_task",
			joinColumns = @JoinColumn(name = "task_id"),
			inverseJoinColumns = @JoinColumn(name = "task_tag_id"))
	private Set<TaskTag> tags = new HashSet<>();

	@Transient
	private Instant modifyAt;

	@Transient
	private Person modifyBy;

	@Transient
	private List<Record> topRailRecords;

	@Transient
	private long commentSize;

}
