package ru.loylabs.portal.entity.audit;

import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.*;
import ru.loylabs.portal.presentation.SecurityUtil;
import ru.loylabs.portal.service.security.Credential;

import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import java.time.Instant;
import java.util.Optional;
import java.util.UUID;

@Component
public class AuditListener {

	@PrePersist
	@PreUpdate
	public void onAudit(Object entity) {
		if (entity instanceof Auditable) audit((Auditable) entity);
	}

	private void audit(Auditable<?> entity){
		AuditEntityBase auditEntity = entity.getAudit();
		if(auditEntity == null){
			initializedAuditFields(entity.initAudit());
		} else {
			updateAuditFields(auditEntity);
		}
	}

	private void initializedAuditFields(AuditEntityBase audit) {
		audit.setCreatedAt(Instant.now());
		audit.setCreatedBy(auditorId());
	}

	private void updateAuditFields(AuditEntityBase audit) {
		audit.setModifiedAt(Instant.now());
		audit.setModifiedBy(auditorId());
	}

	private UUID auditorId() {
		return Optional.ofNullable(SecurityUtil.safeGet())
				.map(Credential::getPerson).map(Person::getId).orElse(null);
	}

}
