package ru.loylabs.portal.enums;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.experimental.FieldNameConstants;
import org.springframework.security.core.GrantedAuthority;

import static ru.loylabs.portal.enums.CredentialPermissionGroup.*;

@FieldNameConstants(onlyExplicitlyIncluded = true)
@RequiredArgsConstructor
public enum CredentialPermission implements GrantedAuthority {

	// ACHIEVEMENTS
	@FieldNameConstants.Include ACHIEVEMENT_READ(ACHIEVEMENT),
	@FieldNameConstants.Include ACHIEVEMENT_READ_OWN(ACHIEVEMENT),
	@FieldNameConstants.Include ACHIEVEMENT_WRITE(ACHIEVEMENT),
	@FieldNameConstants.Include ACHIEVEMENT_WRITE_OWN(ACHIEVEMENT),
	@FieldNameConstants.Include ACHIEVEMENT_APPROVAL(ACHIEVEMENT),
	@FieldNameConstants.Include ACHIEVEMENT_ARCHIVE(ACHIEVEMENT),
	@FieldNameConstants.Include ACHIEVEMENT_UNARCHIVE(ACHIEVEMENT),

	// COMMENT
	@FieldNameConstants.Include COMMENT_READ_ATTACHMENT(COMMENT),
	@FieldNameConstants.Include COMMENT_WRITE_ATTACHMENT(COMMENT),
	@FieldNameConstants.Include COMMENT_WRITE_OWN_ATTACHMENT(COMMENT),

	// BUG_REPORT
	@FieldNameConstants.Include BUG_REPORT_WRITE(BUG_REPORT),

	// CALENDAR
	@FieldNameConstants.Include CALENDAR_READ_WORKING(CALENDAR),
	@FieldNameConstants.Include CALENDAR_READ_CORPORATE(CALENDAR),
	@FieldNameConstants.Include CALENDAR_WRITE_CORPORATE(CALENDAR),
	@FieldNameConstants.Include CALENDAR_READ_YANDEX(CALENDAR),
	@FieldNameConstants.Include CALENDAR_WRITE_YANDEX(CALENDAR),

	// DEPARTMENT
	@FieldNameConstants.Include DEPARTMENT_READ(DEPARTMENT),
	@FieldNameConstants.Include DEPARTMENT_WRITE(DEPARTMENT),

	// FEED
	@FieldNameConstants.Include FEED_READ(FEED),
	@FieldNameConstants.Include FEED_CREATE_GENERAL(FEED),
	@FieldNameConstants.Include FEED_CREATE_IMPORTANT(FEED),
	@FieldNameConstants.Include FEED_MODIFY(FEED),
	@FieldNameConstants.Include FEED_MODIFY_OWN(FEED),
	@FieldNameConstants.Include FEED_READ_COMMENT(FEED),
	@FieldNameConstants.Include FEED_WRITE_COMMENT(FEED),
	@FieldNameConstants.Include FEED_WRITE_OWN_COMMENT(FEED),
	@FieldNameConstants.Include FEED_READ_ATTACHMENT(FEED),
	@FieldNameConstants.Include FEED_WRITE_ATTACHMENT(FEED),
	@FieldNameConstants.Include FEED_WRITE_OWN_ATTACHMENT(FEED),

	// FILES
	@FieldNameConstants.Include FILE_READ(FILE),
	@FieldNameConstants.Include FILE_WRITE(FILE),

	// COMMUNITIES
	@FieldNameConstants.Include COMMUNITY_READ(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_READ_OWN(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_READ_PUBLIC(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_JOIN_LEAVE(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_JOIN_PRIVATE(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_READ_COMMENT(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_READ_OWN_COMMENT(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE_COMMENT(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE_OWN_COMMENT(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE_OWN(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_INVITE_KICK(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_INVITE_KICK_OWN(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE_MESSAGE(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE_OWN_MESSAGE(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_READ_MESSAGE_ATTACHMENT(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE_MESSAGE_ATTACHMENT(COMMUNITY),
	@FieldNameConstants.Include COMMUNITY_WRITE_OWN_MESSAGE_ATTACHMENT(COMMUNITY),

	// IDEAS
	@FieldNameConstants.Include IDEA_READ(IDEA),
	@FieldNameConstants.Include IDEA_WRITE(IDEA),
	@FieldNameConstants.Include IDEA_WRITE_OWN(IDEA),
	@FieldNameConstants.Include IDEA_APPROVAL(IDEA),
	@FieldNameConstants.Include IDEA_FAVORITE(IDEA),
	@FieldNameConstants.Include IDEA_READ_COMMENT(IDEA),
	@FieldNameConstants.Include IDEA_WRITE_COMMENT(IDEA),
	@FieldNameConstants.Include IDEA_WRITE_OWN_COMMENT(IDEA),
	@FieldNameConstants.Include IDEA_READ_ATTACHMENT(IDEA),
	@FieldNameConstants.Include IDEA_WRITE_ATTACHMENT(IDEA),
	@FieldNameConstants.Include IDEA_WRITE_OWN_ATTACHMENT(IDEA),

	// KNOWLEDGE BASE
	@FieldNameConstants.Include KB_READ(KB),
	@FieldNameConstants.Include KB_WRITE_SECTION(KB),
	@FieldNameConstants.Include KB_WRITE_ARTICLE(KB),
	@FieldNameConstants.Include KB_READ_ATTACHMENT(KB),
	@FieldNameConstants.Include KB_WRITE_ATTACHMENT(KB),

	// NOTES
	@FieldNameConstants.Include NOTE_READ(NOTE),
	@FieldNameConstants.Include NOTE_WRITE(NOTE),

	// NOTIFICATIONS
	@FieldNameConstants.Include NOTIFICATION_READ(NOTIFICATION),
	@FieldNameConstants.Include NOTIFICATION_WRITE(NOTIFICATION),

	// PERSONS
	@FieldNameConstants.Include PERSON_READ(PERSON),
	@FieldNameConstants.Include PERSON_READ_SELF(PERSON),
	@FieldNameConstants.Include PERSON_READ_LOGIN(PERSON),
	@FieldNameConstants.Include PERSON_READ_LOGIN_SELF(PERSON),
	@FieldNameConstants.Include PERSON_CREATE(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_SELF(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_PERSONAL(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_PERSONAL_SELF(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_IMAGERY(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_IMAGERY_SELF(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_ROLE(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_PASSWORD(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_PASSWORD_SELF(PERSON),
	@FieldNameConstants.Include PERSON_BLOCK(PERSON),
	@FieldNameConstants.Include PERSON_WRITE_PROTECTION(PERSON),
	@FieldNameConstants.Include PERSON_YANDEX_CALENDAR(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_STATUS(PERSON),
	@FieldNameConstants.Include PERSON_MODIFY_STATUS_SELF(PERSON),

	// REACTIONS
	@FieldNameConstants.Include REACTION_READ(REACTION),
	@FieldNameConstants.Include REACTION_WRITE(REACTION),

	// ROLES
	@FieldNameConstants.Include ROLE_READ(ROLE),
	@FieldNameConstants.Include ROLE_WRITE(ROLE),

	// SETTINGS
	@FieldNameConstants.Include SETTINGS_READ(SETTINGS),
	@FieldNameConstants.Include SETTINGS_WRITE(SETTINGS),

	// STORIES
	@FieldNameConstants.Include STORY_READ(STORY),
	@FieldNameConstants.Include STORY_WRITE(STORY),
	@FieldNameConstants.Include STORY_WRITE_OWN(STORY),

	// TASKS
	@FieldNameConstants.Include TASK_READ(TASK),
	@FieldNameConstants.Include TASK_READ_OWN(TASK),
	@FieldNameConstants.Include TASK_WRITE(TASK),
	@FieldNameConstants.Include TASK_WRITE_OWN(TASK),
	@FieldNameConstants.Include TASK_APPROVAL(TASK),
	@FieldNameConstants.Include TASK_READ_COMMENT(TASK),
	@FieldNameConstants.Include TASK_READ_TAG(TASK),
	@FieldNameConstants.Include TASK_WRITE_TAG(TASK),
	@FieldNameConstants.Include TASK_WRITE_COMMENT(TASK),
	@FieldNameConstants.Include TASK_WRITE_OWN_COMMENT(TASK),
	@FieldNameConstants.Include TASK_READ_ATTACHMENT(TASK),
	@FieldNameConstants.Include TASK_WRITE_ATTACHMENT(TASK),
	@FieldNameConstants.Include TASK_WRITE_OWN_ATTACHMENT(TASK),

	// TITLES
	@FieldNameConstants.Include TITLE_READ(TITLE),
	@FieldNameConstants.Include TITLE_WRITE(TITLE),

	//GRADE
	@FieldNameConstants.Include GRADE_READ(GRADE),
	@FieldNameConstants.Include GRADE_WRITE(GRADE),

	// SKILLS
	@FieldNameConstants.Include SKILL_READ(SKILL),
	@FieldNameConstants.Include SKILL_WRITE(SKILL),

	// STATUS
	@FieldNameConstants.Include STATUS_READ(STATUS),
	@FieldNameConstants.Include STATUS_WRITE(STATUS),

	// REVIEW
	@FieldNameConstants.Include REVIEW_READ(REVIEW),
	@FieldNameConstants.Include REVIEW_WRITE(REVIEW),
	@FieldNameConstants.Include REVIEW_RATING_WRITE(REVIEW);


	@Getter
	private final CredentialPermissionGroup group;

	@Override
	public String getAuthority() {
		return name();
	}

}
