package ru.loylabs.portal.exception;

import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import ru.loylabs.portal.utility.StaticMessageSource;

@EqualsAndHashCode(callSuper = true)
@Data
public abstract class BaseException extends RuntimeException {
	private final int errorCode;

	public BaseException(Exception exception, Object... args) {
		super(StaticMessageSource.getMessage(exception.getLabel(), args));
		this.errorCode = exception.getCode();
	}

	@Getter
	@RequiredArgsConstructor
	public enum Exception {

		PERSON_NOT_FOUND(1, "loyalty.exception.person.not_found"),
		JOB_NOT_FOUND(2, "loyalty.exception.job.not_found"),
		ROLE_NOT_FOUND(3, "loyalty.exception.role.not_found"),
		SECTION_NOT_FOUND(4, "loyalty.exception.section.not_found"),
		ARTICLE_NOT_FOUND(5, "loyalty.exception.article.not_found"),
		RECORD_TYPE_NOT_FOUND(6, "loyalty.exception.record.type.not_found"),
		IDEA_NOT_FOUND(7, "loyalty.exception.idea.not_found"),
		FEED_NOT_FOUND(9, "loyalty.exception.feed.not_found"),
		COMMUNITY_NOT_FOUND(11, "loyalty.exception.community.not_found"),
		PUBLIC_COMMUNITY_NOT_FOUND(12, "loyalty.exception.community.public.not_found"),
		NOTE_NOT_FOUND(13, "loyalty.exception.note.not_found"),
		USERNAME_NOT_FOUND(14, "loyalty.exception.person.username.not_found"),
		STORY_GROUP_NOT_FOUND(16, "loyalty.exception.story_group.not_found"),
		STORY_NOT_FOUND(17, "loyalty.exception.story.not_found"),
		STORY_GROUP_EMPTY(18, "loyalty.exception.story_group.empty"),
		PERSON_NOT_IN_COMMUNITY(19, "loyalty.exception.community.person.not_exists"),
		IDEA_CAN_NOT_BE_APPROVED(20, "loyalty.exception.idea.not_approved"),
		IDEA_CAN_NOT_BE_REJECTED(21, "loyalty.exception.idea.not_rejected"),
		RECORD_NOT_FOUND(22, "loyalty.exception.record.not_found"),
		COMMUNITY_RECORD_NOT_FOUND(23, "loyalty.exception.community.record.not_found"),
		IDEA_ALREADY_IN_FAVORITES(24, "loyalty.exception.idea.favorite"),
		IDEA_NOT_IN_FAVORITES(25, "loyalty.exception.idea.not_favorite"),
		IDEA_CANNOT_BE_CHANGE(26, "loyalty.exception.idea.not_change"),
        IDEA_ALREADY_EXISTS(27, "loyalty.exception.idea.already_exists"),
        PERSON_ALREADY_IN_COMMUNITY(28, "loyalty.exception.community.person.exists"),
		PERSON_USERNAME_ALREADY_EXIST(29, "loyalty.exception.person.username.exists"),
		CONTACT_PHONE_ALREADY_EXIST(30, "loyalty.exception.contact.phone.exists"),
		CONTACT_EMAIL_ALREADY_EXIST(31, "loyalty.exception.contact.email.exists"),
		CONTACT_TELEGRAM_ALREADY_EXIST(32, "loyalty.exception.contact.telegram.exists"),
		CONTACT_SKYPE_ALREADY_EXIST(33, "loyalty.exception.contact.skype.exists"),
		CONTACT_LINKEDIN_ALREADY_EXIST(34, "loyalty.exception.contact.linkedin.exists"),
		CONTACT_GITHUB_ALREADY_EXIST(35, "loyalty.exception.contact.github.exists"),
		CONTACT_VK_ALREADY_EXIST(36, "loyalty.exception.contact.vk.exists"),
		CONTACT_INSTAGRAM_ALREADY_EXIST(37, "loyalty.exception.contact.instagram.exists"),
		SECTION_NAME_ALREADY_EXIST(38, "loyalty.exception.section.name.exists"),
		NOTE_USER_ALREADY_EXIST(39, "loyalty.exception.person.note.exists"),
		COMMUNITY_NO_OWNER(40, "loyalty.exception.community.owner.not_found"),
		COMMUNITY_CHANGE_OF_OWNER(41, "loyalty.exception.community.owner.change"),
		ARTICLE_IN_SECTION_ALREADY_EXIST(42, "loyalty.exception.article.in.section.exists"),
		TOKEN_NOT_VALID(60, "loyalty.exception.token.not_found"),
		EMAIL_NOT_FOUND(61, "loyalty.exception.email.not_found"),
		CITY_NOT_FOUND(62, "loyalty.exception.city.not_found"),
		WRONG_PASSWORD(70, "loyalty.exception.person.password.incorrect"),
		WRONG_CREDENTIAL(71, "loyalty.exception.credential.incorrect"),
		WRONG_REFRESH_TOKEN(72, "loyalty.exception.credential.token-refresh.incorrect"),
		WEAK_PASSWORD(73, "loyalty.exception.person.password.weak"),
		ACHIEVEMENT_NOT_FOUND(80, "loyalty.exception.achievement.not_found"),
		ACHIEVEMENT_WRONG_SUPERVISOR(81, "loyalty.exception.achievement.owner_cant_observe"),
		ACHIEVEMENT_EMPTY_SUPERVISOR(82, "loyalty.exception.achievement.achievement_no_supervisor"),
		ACHIEVEMENT_NOT_UPDATABLE(83, "loyalty.exception.achievement.achievement_not_updatable"),
		ACHIEVEMENT_NOT_ARCHIVED(84, "loyalty.exception.achievement.achievement_not_archived"),
		ACHIEVEMENT_WRONG_COUNT_TASK(85, "loyalty.exception.achievement.task.wrong_count"),
		ACHIEVEMENT_WRONG_STATUS(86,"loyalty.exception.achievement.wrong_status"),
		ACHIEVEMENT_NO_ARCHIVED(86,"loyalty.exception.achievement.no_archived"),
		TASK_NOT_FOUND(90, "loyalty.exception.task.not_found"),
		TASK_WRONG_SUPERVISOR(91, "loyalty.exception.task.wrong_supervisor_id"),
		TASK_WRONG_STATUS(92, "loyalty.exception.task.wrong_status"),
		TASK_TAG_NOT_FOUND(95,"loyalty.exception.task-tag.not_found"),
		TASK_TAG_EXIST_ON_TASK(96,"loyalty.exception.task.task-tag.exist"),
		TASK_TAG_NOT_EXIST_ON_TASK(96,"loyalty.exception.task.task-tag.exist"),
		DEPARTMENT_BAN_ON_DELETION(97,"loyalty.exception.department.ban_on_deletion"),
		TITLE_BAN_ON_DELETION(98,"loyalty.exception.title.ban_on_deletion"),
		DEPARTMENT_ALREADY_EXISTS(99,"loyalty.exception.department.already_exists"),
		TITLE_ALREADY_EXISTS(100,"loyalty.exception.title.already_exists"),

		AVATAR_WRONG_FILE_TYPE(101, "loyalty.exception.person.avatar.wrong.file.type"),
		STORY_WRONG_FILE_AMOUNT(102, "loyalty.exception.story.wrong.file.amount"),
		PERSON_NO_DEFAULT_AVATAR(103, "loyalty.exception.person.no-default-avatar"),
		STORY_WRONG_FILE_TYPE(104, "loyalty.exception.person.story.wrong.file.type"),
		PERSON_SMILE_NOT_FOUND(110, "loyalty.exception.person.smile.not_found"),
		PERSON_SMILE_ALREADY_EXIST(111, "loyalty.exception.person.smile.exists"),
		REACTION_NOT_FOUND(112, "loyalty.exception.reaction.not.found"),
		SMILE_NOT_FOUND(113, "loyalty.exception.smile.not.found"),
		REACTION_SMILE_NOT_FOUND(114, "loyalty.exception.reaction.smile.not.found"),
		EMOJI_NOT_FOUND(115, "loyalty.exception.emoji.not.found"),
		STATUS_NOT_FOUND_BY_ID(116,"loyalty.exception.status.not_found.id"),
		STATUS_NOT_FOUND_BY_NAME(117,"loyalty.exception.status.not_found.name"),
		TITLE_NOT_FOUND(120, "loyalty.exception.title.not_found"),
		DEPARTMENT_NOT_FOUND(121, "loyalty.exception.department.not_found"),
		SKILL_NOT_FOUND(122, "loyalty.exception.skill.not_found"),
		SKILL_ALREADY_EXISTS(123, "loyalty.exception.skill.already_exists"),
		EMAIL_NOTIFICATION_SETTINGS_NOT_FOUND_CURRENT(130, "loyalty.exception.settings.notification.email.not_found.current"),
		EMAIL_NOTIFICATION_SETTINGS_NOT_FOUND(131, "loyalty.exception.settings.notification.email.not_found"),
		STORY_SETTINGS_NOT_FOUND_CURRENT(140, "loyalty.exception.settings.story.not_found.current"),
		STORY_SETTINGS_NOT_FOUND(141, "loyalty.exception.settings.story.not_found"),
		BELL_NOTIFICATION_SETTINGS_NOT_FOUND_CURRENT(142, "loyalty.exception.settings.notification.bell.not_found.current"),
		BELL_NOTIFICATION_SETTINGS_NOT_FOUND(143, "loyalty.exception.settings.notification.bell.not_found"),
		BELL_NOTIFICATION_NOT_FOUND(144, "loyalty.exception.notification.bell.not_found"),
		NO_COMMUNITY_MANAGEMENT_RIGHT(150, "loyalty.exception.person.community.no_right"),
		PERSON_DONT_HAVE_CONTROL_OVER_RECORD(151, "loyalty.exception.person.record.no_access"),
		PERSON_NOT_AUTHOR_OF_RECORD(152, "loyalty.exception.person.community.author"),
		PERSON_HAS_INSUFFICIENT_RIGHTS(153, "loyalty.exception.person.no_access"),
		NO_ACCESS_FOR_ACHIEVEMENT(154, "loyalty.exception.person.achievement.not_enough_rights"),
		NO_RIGHTS_TO_APPOINT_ACHIEVEMENT(155, "loyalty.exception.person.achievement.appoint.no_right"),
		BUG_REPORT_NOT_FOUND(160, "loyalty.exception.bug_report.not_found"),
		GRADE_NOT_FOUND(161, "loyalty.exception.grade.not_found"),
		GRADE_ALREADY_EXISTS(162, "loyalty.exception.grade.already_exists"),
		GRADE_BAN_ON_DELETION(163,"loyalty.exception.grade.ban_on_deletion"),
		REVIEW_NOT_FOUNT(170, "loyalty.exception.review.not_found"),
		REVIEWER_NOT_FOUNT(171, "loyalty.exception.reviewer.not_found"),
		REVIEWER_ALREADY_VOTED(172, "loyalty.exception.reviewer.already.voted"),
		REVIEW_OWNER_IS_REVIEWER(173, "loyalty.exception.owner.is.reviewer"),
		REVIEW_DATE_ERROR(174, "loyalty.exception.review.date.error"),
		REVIEW_OWNER_IS_YOURSELF(175, "loyalty.exception.owner.is.yourself"),
		EDIT_REVIEW_YOURSELF(176, "loyalty.exception.review.edit.yourself"),
		YANDEX_CREDENTIALS_NOT_FOUND(200, "loyalty.exception.calendar.yandex.credentials.not.found"),
		WORKING_CALENDAR_SOURCE_UNAVAILABLE(201, "loyalty.exception.calendar.working.calendar.source.unavailable"),
		YANDEX_CALENDAR_DATA_ERROR(203, "loyalty.exception.calendar.yandex.data.error"),
		CORPORATE_CALENDAR_EVENT_NOT_FOUND(204, "loyalty.exception.calendar.corporate.event.not.found"),
		CORPORATE_CALENDAR_EVENT_DATE_ERROR(205, "loyalty.exception.calendar.corporate.event.date.error"),
		INTEGRATED_CALENDAR_LINK_NOT_FOUND(206, "loyalty.exception.integrated.calendar.link.not.found"),
		LINK_CONNECT_ERROR(207, "loyalty.exception.link.connect.error"),
		INTEGRATED_CALENDAR_PARSE_ERROR(208, "loyalty.exception.integrated.calendar.parse.error"),
		INTEGRATED_CALENDAR_PARSE_DATE_ERROR(209, "loyalty.exception.integrated.calendar.parse.date.error"),
		INTEGRATION_CALENDAR_LINK_EXISTS(210, "loyalty.exception.integrated.calendar.link.exists"),
		INTEGRATION_CALENDAR_NAME_AND_PERSON_EXISTS(211, "loyalty.exception.integrated.calendar.name.and.person.exists"),
		YANDEX_360_USER_SERVICE_UNAVAILABLE(220, "loyalty.exception.yandex.user_service.unavailable"),
		YANDEX_360_USER_SERVICE_INTERNAL_ERROR(220, "loyalty.exception.yandex.user_service.internal_error"),
		YANDEX_360_USER_UNAUTHORIZED(221, "loyalty.exception.yandex.user_service.unauthorized"),
		YANDEX_360_USER_NOT_FOUND(222, "loyalty.exception.yandex.user_service.not_found"),
		YANDEX_360_USER_EXISTS(223, "loyalty.exception.yandex.user_service.exists"),
		YANDEX_360_NUMBER_OF_REQUESTS_EXCEEDED(224, "loyalty.exception.yandex.user_service.number_of_requests_exceeded"),
		PERSON_BAN_ADMIN(300, "loyalty.exception.person.can-not-ban.admin"),
		PERSON_BANNED(301, "loyalty.exception.person.banned"),
		PERSON_NOT_ADMIN(302, "loyalty.exception.person.not.admin"),
		WS_AUTH_ERROR(310, "loyalty.exception.ws.auth.error"),
		SEARCH_STACK_OVERFLOW(330, "loyalty.exception.search.stack_overflow"),
		PERMISSION_NOT_FOUND(400, "loyalty.exception.permission.not_found"),
		ROLE_NAME_ALREADY_EXISTS(401, "loyalty.exception.role.name_exists"),
		ROLE_ROLE_ALREADY_EXISTS(402, "loyalty.exception.role.not_found"),
		ROLE_IMMUTABLE(403, "loyalty.exception.role.immutable"),
		STATUS_NAME_ALREADY_EXISTS(404, "loyalty.exception.status.already_exist.name"),
		SYSTEM_CREDENTIAL_FAILURE(1000, "loyalty.exception.system.credential"),
		SEARCH_FIELD_NOT_FOUND(0, "loyalty.exception.search.field.not_found"),
		SEARCH_FIELD_NOT_SEARCHABLE(0, "loyalty.exception.search.field.not_searchable");

		private final int code;
		private final String label;
	}
}
