package ru.loylabs.portal.exception;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

@Component
@RequiredArgsConstructor
public class ExceptionHandlerFilter extends OncePerRequestFilter {

	private final WebExceptionHandler handler;

	@Override
	@SneakyThrows
	@SuppressWarnings("all")
	protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain) {
		ResponseEntity<Object> responseEntity = null;

		try {
			filterChain.doFilter(request, response);
		} catch (ForbiddenException e) {
			responseEntity = handler.handleForbiddenException(e);
		}

		if (responseEntity != null) wrightResponse(responseEntity, response);
	}

	private void wrightResponse(ResponseEntity<Object> responseEntity, HttpServletResponse response) throws IOException {
		response.setContentType(MediaType.APPLICATION_JSON_VALUE);
		response.setStatus(responseEntity.getStatusCodeValue());
		response.getWriter().write(convertObjectToJson(responseEntity.getBody()));
	}

	private String convertObjectToJson(Object object) throws JsonProcessingException {
		return object == null ? "" : new ObjectMapper().writeValueAsString(object);
	}
}
