package ru.loylabs.portal.listener.achievement;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.AchievementCreateNotificationData;
import ru.loylabs.portal.listener.events.AchievementEvents;
import ru.loylabs.portal.repository.AchievementRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Slf4j
@Component
@RequiredArgsConstructor
public class AchievementCreateListener implements BaseEventListener<AchievementEvents.AchievementCreateEvent> {

	private final BellNotificationPersister persister;
	private final BellNotificationFactory notificationFactory;
	private final AchievementRepository achievementRepository;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;


	@Override
	@EventListener
	public void handle(AchievementEvents.AchievementCreateEvent event) {
		achievementRepository.findById(event.getAchievementId())
				.ifPresent(achievement -> {
					var notification = notificationFactory.create(new AchievementCreateNotificationData(achievement));
					persister.persist(notification,achievement.getOwner());
					wsSender.send(notification);
				});
	}
}
