package ru.loylabs.portal.listener.calendar;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.CalendarEventCreateNotificationData;
import ru.loylabs.portal.listener.events.CalendarEvents;
import ru.loylabs.portal.repository.CorporateCalendarEventRepository;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Slf4j
@Component
@RequiredArgsConstructor
public class CalendarEventCreateListener implements BaseEventListener<CalendarEvents.CalendarCreateEvent> {

	private final CorporateCalendarEventRepository cceRepository;
	private final PersonRepository personRepository;
	private final BellNotificationFactory factory;
	private final BellNotificationPersister notificationPersister;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@EventListener
	@Override
	public void handle(CalendarEvents.CalendarCreateEvent event) {
		personRepository.findById(event.getAuthorId())
				.ifPresent(author ->cceRepository.findById(event.getEventId())
						.ifPresent(calendarEvent ->{
							var notification = factory.create(
									new CalendarEventCreateNotificationData(calendarEvent,author)
							);
							notificationPersister.persistForAll(notification);
							wsSender.send(notification);
						}));
	}
}
