package ru.loylabs.portal.listener.comment;

import lombok.AllArgsConstructor;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.entity.Feed;
import ru.loylabs.portal.entity.Idea;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.enums.BellNotificationType;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.listener.events.CommentEvents;
import ru.loylabs.portal.repository.RecordRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;
import ru.loylabs.portal.service.notification.bell.data.FeedCommentNotificationData;
import ru.loylabs.portal.service.notification.bell.data.IdeaCommentNotificationData;
import ru.loylabs.portal.service.notification.bell.data.TaskCommentNotificationData;

import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

@Component
@AllArgsConstructor
public class CommentCreateListener implements BaseEventListener<CommentEvents.CommentCreateEvent> {

	private final RecordRepository repository;

	private final BellNotificationFactory factory;

	private final BellNotificationPersister notificationPersister;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;


	@Override
	@EventListener
	public void handle(CommentEvents.CommentCreateEvent event) {
		repository.findById(event.getCommentId())
				.filter(record -> record.getParentRecord() != null)
				.ifPresent(record -> {
					var notification = createNotification(record.getParentRecord(), record);
					if (Objects.nonNull(notification)) {
						persist(notification,record);
						wsSender.send(notification);
					}
				});
	}

	private BellNotification createNotification(Record parentRecord, Record comment) {
		return switch (parentRecord.getRecordType()) {
			case FEED -> factory.create(new FeedCommentNotificationData((Feed) parentRecord, comment));
			case IDEA -> factory.create(new IdeaCommentNotificationData((Idea) parentRecord, comment));
			case TASK -> factory.create(new TaskCommentNotificationData(
					((Task) parentRecord).getAchievement(),
					(Task) parentRecord,
					comment));
			default -> null;
		};
	}

	private void persist(BellNotification notification, Record record){
		if(notification.getNotificationType() == BellNotificationType.TASK_COMMENT){
			Task task = (Task)record.getParentRecord();
			Set<Person> receivers = new HashSet<>(task.getObservers());
			receivers.add(task.getAchievement().getOwner());
			notificationPersister.persist(notification,receivers);
		}
		else {
			notificationPersister.persist(notification, record.getParentRecord().getAuthor());
		}
	}

}
