package ru.loylabs.portal.listener.community;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.listener.events.CommunityEvents;
import ru.loylabs.portal.repository.CommunityRepository;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;
import ru.loylabs.portal.service.notification.bell.data.CommunityInvitationNotificationData;

import java.util.HashSet;

@Component
@RequiredArgsConstructor
public class CommunityAddMemberListener implements BaseEventListener<CommunityEvents.CommunityAddMemberEvent> {

	private final PersonRepository personRepository;
	private final CommunityRepository communityRepository;
	private final BellNotificationFactory notificationFactory;
	private final BellNotificationPersister notificationPersister;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@Override
	@EventListener
	public void handle(CommunityEvents.CommunityAddMemberEvent event) {
		communityRepository.findById(event.getCommunityId())
				.ifPresent(community -> {
					var whoInvited = personRepository.findById(event.getWhoInvitedId()).orElse(null);
					var invited = personRepository.findAllById(event.getInvitedIds());
					var notification = notificationFactory
							.create(new CommunityInvitationNotificationData(community, whoInvited));
					notificationPersister.persist(notification,new HashSet<>(invited));
					wsSender.send(notification);
				});

	}
}
