package ru.loylabs.portal.listener.community;

import lombok.RequiredArgsConstructor;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.listener.events.CommunityEvents;
import ru.loylabs.portal.repository.CommunityRepository;
import ru.loylabs.portal.repository.PersonalBellNotificationRepository;

@Component
@RequiredArgsConstructor
public class CommunityDeletingMemberListener implements BaseEventListener<CommunityEvents.CommunityDeletingMember> {

	private final PersonalBellNotificationRepository notificationRepository;
	private final CommunityRepository communityRepository;

	@Override
	@EventListener
	@Transactional
	public void handle(CommunityEvents.CommunityDeletingMember event) {
		communityRepository.findById(event.getCommunityId())
				.ifPresent(community -> {
					notificationRepository
							.deleteAllByPersonIdInAndBellNotificationSubjectId(
									event.getDeletingMemberIds(),
									event.getCommunityId());

					community.getRecords()
							.stream()
							.map(Record::getId)
							.forEach(commentId -> notificationRepository
									.deleteAllByPersonIdInAndBellNotificationSubjectId(
											event.getDeletingMemberIds(),
											commentId));
				});
	}
}
