package ru.loylabs.portal.listener.community;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.CommunityRecordCreateNotificationData;
import ru.loylabs.portal.listener.events.CommunityEvents;
import ru.loylabs.portal.repository.CommunityRepository;
import ru.loylabs.portal.repository.RecordRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Slf4j
@Component
@RequiredArgsConstructor
public class CommunityRecordCreateListener implements BaseEventListener<CommunityEvents.CommunityRecordCreateEvent> {

	private final RecordRepository recordRepository;
	private final CommunityRepository communityRepository;
	private final BellNotificationFactory notificationFactory;
	private final BellNotificationPersister notificationPersister;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@Override
	@EventListener
	public void handle(CommunityEvents.CommunityRecordCreateEvent event) {
		communityRepository.findById(event.getCommunityId())
				.ifPresent(community -> {
					recordRepository.findById(event.getCommentId())
							.ifPresent(comment -> {
								var notification = notificationFactory.create(
										new CommunityRecordCreateNotificationData(community, comment)
								);
								notificationPersister.persist(notification, community.getMembers());
								wsSender.send(notification);
							});
				});
	}
}
