package ru.loylabs.portal.listener.events;

import lombok.EqualsAndHashCode;
import lombok.Value;
import ru.loylabs.portal.entity.Achievement;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.listener.BaseEvent;

import java.util.Set;
import java.util.UUID;
import java.util.stream.Collectors;

public class AchievementEvents extends BaseEvent {

	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class AchievementCreateEvent extends AchievementEvents {

		UUID achievementId;

		public static AchievementCreateEvent of(UUID achievementId) {
			return new AchievementCreateEvent(achievementId);
		}
	}

	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class AchievementConfirmEvent extends AchievementEvents {

		UUID achievementId;
		UUID confirmedId;

		public static AchievementConfirmEvent of(UUID achievementId, UUID confirmedId) {
			return new AchievementConfirmEvent(achievementId, confirmedId);
		}
	}

	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class AchievementDeleteEvent extends AchievementEvents {

		UUID achievementId;
		Set<UUID> taskIds;
		Set<UUID> commentIds;

		public static AchievementDeleteEvent of(Achievement achievement) {
			Set<UUID> comments = achievement.getTasks()
					.stream()
					.flatMap(task -> task.getComments().stream())
					.map(Record::getId).collect(Collectors.toSet());
			Set<UUID> task = achievement.getTasks()
					.stream()
					.map(Task::getId)
					.collect(Collectors.toSet());

			return new AchievementDeleteEvent(achievement.getId(), task,comments);
		}
	}


}
