package ru.loylabs.portal.listener.events;

import lombok.EqualsAndHashCode;
import lombok.Value;
import ru.loylabs.portal.entity.Community;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.listener.BaseEvent;

import java.util.Set;
import java.util.UUID;
import java.util.stream.Collectors;


public class CommunityEvents extends BaseEvent {


	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class CommunityRecordCreateEvent extends CommunityEvents {

		UUID communityId;

		UUID commentId;

		public static CommunityRecordCreateEvent of(UUID communityId, UUID commentId) {
			return new CommunityRecordCreateEvent(communityId, commentId);
		}
	}

	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class CommunityRecordDeleteEvent extends CommunityEvents {

		UUID communityId;

		UUID commentId;

		public static CommunityRecordDeleteEvent of(UUID communityId, UUID commentId) {
			return new CommunityRecordDeleteEvent(communityId, commentId);
		}
	}

	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class CommunityDeleteEvent extends CommunityEvents {

		UUID communityId;

		Set<UUID> commentIds;

		public static CommunityDeleteEvent of(Community community) {
			return new CommunityDeleteEvent(community.getId(), community.getRecords()
					.stream()
					.map(Record::getId)
					.collect(Collectors.toSet()));
		}
	}

	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class CommunityAddMemberEvent extends CommunityEvents {

		UUID communityId;

		UUID whoInvitedId;

		Set<UUID> invitedIds;

		public static CommunityAddMemberEvent of(UUID communityId, UUID whoInvitedId, Set<UUID> invitedIds) {
			return new CommunityAddMemberEvent(communityId, whoInvitedId,invitedIds);
		}
	}

	@EqualsAndHashCode(callSuper = false)
	@Value
	public static class CommunityDeletingMember extends CommunityEvents {

		UUID communityId;

		Set<UUID> deletingMemberIds;

		public static CommunityDeletingMember of(UUID communityId, Set<UUID> deletingMemberIds) {
			return new CommunityDeletingMember(communityId,deletingMemberIds);
		}
	}

}
