package ru.loylabs.portal.listener.feed;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.entity.Feed;
import ru.loylabs.portal.listener.events.FeedEvents;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.repository.FeedRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;
import ru.loylabs.portal.service.notification.bell.data.FeedCreateNotificationData;

@Slf4j
@Component
@RequiredArgsConstructor
public class FeedCreateListener implements BaseEventListener<FeedEvents.FeedCreateEvent> {

	private final FeedRepository feedRepository;
	private final BellNotificationFactory factory;
	private final BellNotificationPersister notificationService;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;


	@Override
	@EventListener
	public void handle(FeedEvents.FeedCreateEvent event) {
		feedRepository.findById(event.getFeedId())
				.filter(Feed::isImportant)
				.ifPresent(feed -> {
					var notification = factory.create(new FeedCreateNotificationData(feed));
					notificationService.persistForAll(notification);
					wsSender.send(notification);
				});
	}
}
