package ru.loylabs.portal.listener.idea;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.IdeaCreateNotificationData;
import ru.loylabs.portal.listener.events.IdeaEvents;
import ru.loylabs.portal.repository.IdeaRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Slf4j
@Component
@RequiredArgsConstructor
public class IdeaCreateListener implements BaseEventListener<IdeaEvents.IdeaCreateEvent> {

	private final IdeaRepository ideaRepository;

	private final BellNotificationFactory factory;

	private final BellNotificationPersister notificationService;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;


	@Override
	@EventListener
	public void handle(IdeaEvents.IdeaCreateEvent event) {
		ideaRepository.findById(event.getIdeaId())
				.ifPresent(idea -> {
					var notification = factory.create(new IdeaCreateNotificationData(idea));
					notificationService.persistForPersonWithRole(notification,"ADMIN","EDITOR");
					wsSender.send(notification);
				});
	}
}
