package ru.loylabs.portal.listener.person;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.PersonDobNotSpecifiedNotificationData;
import ru.loylabs.portal.listener.events.PersonEvents;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;
import ru.loylabs.portal.service.notification.bell.data.PersonHasRegisteredNotificationData;
import ru.loylabs.portal.service.story.updater.SystemBirthdaysStoryUpdater;
import ru.loylabs.portal.service.story.updater.SystemNewEmployeeStoryUpdater;

@Slf4j
@Component
@RequiredArgsConstructor
public class PersonCreateListener implements BaseEventListener<PersonEvents.PersonCreateEvent> {

    private final PersonRepository personRepository;
    private final SystemBirthdaysStoryUpdater systemBirthdaysStoryUpdater;
    private final SystemNewEmployeeStoryUpdater systemNewEmployeeStoryUpdater;
    private final BellNotificationFactory factory;
    private final BellNotificationPersister notificationPersister;
    @Qualifier("bellNotificationSenderImpl")
    private final NotificationSender<BellNotification> wsSender;

    @Override
    @EventListener
    public void handle(PersonEvents.PersonCreateEvent event) {
        personRepository.findById(event.getPersonId()).filter(person -> person.getDob() == null)
                .ifPresent(person ->
                        {
                            var notification = factory
                                    .create(new PersonDobNotSpecifiedNotificationData(person));
                            notificationPersister.persist(notification, person);
                            wsSender.send(notification);

                            var notificationToManagers = factory
                                    .create(new PersonHasRegisteredNotificationData(person));
                            notificationPersister.persistForPersonWithRole(notificationToManagers, "ADMIN", "EDITOR");
                            wsSender.send(notificationToManagers);

                            systemNewEmployeeStoryUpdater.refreshSystemGroup();
                            systemBirthdaysStoryUpdater.refreshSystemGroup();
                        }
                );
    }
}
