package ru.loylabs.portal.listener.person;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.PersonDobNotificationData;
import ru.loylabs.portal.listener.events.PersonEvents;
import ru.loylabs.portal.repository.BellNotificationRepository;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

import java.util.UUID;

import static ru.loylabs.portal.enums.BellNotificationType.PERSON_UPCOMING_BIRTHDAY;

@Slf4j
@Component
@RequiredArgsConstructor
public class PersonDobListener implements BaseEventListener<PersonEvents.PersonDobEvent> {

	private final PersonRepository personRepository;
	private final BellNotificationFactory factory;
	private final BellNotificationPersister notificationPersister;
	private final BellNotificationRepository notificationRepository;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@Override
	@EventListener
	@Transactional
	public void handle(PersonEvents.PersonDobEvent event) {
		personRepository.findById(event.getPersonId())
				.ifPresent(person -> {
					clearUpcomingDobNotification(person.getId());
					var notification = factory.create(new PersonDobNotificationData(person));
					notificationPersister.persistForAll(notification);
					wsSender.send(notification);
				});
	}

	private void clearUpcomingDobNotification(UUID personId) {
		notificationRepository.deleteAllBySubjectIdAndNotificationType(personId, PERSON_UPCOMING_BIRTHDAY);
	}
}
