package ru.loylabs.portal.listener.person;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.PersonDobUpcomingNotificationData;
import ru.loylabs.portal.listener.events.PersonEvents;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Component
@RequiredArgsConstructor
public class PersonUpcomingDobListener implements BaseEventListener<PersonEvents.PersonUpcomingDobEvent> {

	private final PersonRepository personRepository;
	private final BellNotificationFactory factory;
	private final BellNotificationPersister notificationPersister;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@Override
	@EventListener
	public void handle(PersonEvents.PersonUpcomingDobEvent event) {
		personRepository.findById(event.getPersonId())
				.ifPresent( person -> {
					var notification = factory.create(new PersonDobUpcomingNotificationData(person));
					notificationPersister.persistForAll(notification);
					wsSender.send(notification);
				});
	}
}
