package ru.loylabs.portal.listener.review;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.listener.events.ReviewEvents;
import ru.loylabs.portal.repository.ReviewPersonSkillRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;
import ru.loylabs.portal.service.notification.bell.data.ReviewCreateOwnerNotificationData;

@Slf4j
@Component
@RequiredArgsConstructor
public class ReviewCreateOwnerListener implements BaseEventListener<ReviewEvents.ReviewCreateEventOwner> {
	private final BellNotificationPersister persister;
	private final BellNotificationFactory notificationFactory;
	private final ReviewPersonSkillRepository repository;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@Override
	@EventListener
	public void handle(ReviewEvents.ReviewCreateEventOwner event) {
		repository.findById(event.getReviewId())
				.ifPresent(review -> {
					var notification = notificationFactory.create(new ReviewCreateOwnerNotificationData(review));
					persister.persist(notification, review.getOwner());
					wsSender.send(notification);
				});
	}
}
