package ru.loylabs.portal.listener.review;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.listener.events.ReviewEvents;
import ru.loylabs.portal.repository.BellNotificationRepository;

import java.util.Collections;

import static ru.loylabs.portal.enums.BellNotificationType.CREATE_REVIEW;
import static ru.loylabs.portal.enums.BellNotificationType.OWNER_NEW_REVIEW;

@Slf4j
@Component
@RequiredArgsConstructor
public class ReviewDeleteListener implements BaseEventListener<ReviewEvents.ReviewDeleteEvent> {

	private final BellNotificationRepository repository;

	@Override
	@Transactional
	@EventListener
	public void handle(ReviewEvents.ReviewDeleteEvent reviewEvents) {
		repository.deleteByNotificationTypeAndSubjectIdAndLinkId(CREATE_REVIEW, reviewEvents.getReviewersId(), reviewEvents.getReviewId());
		repository.deleteByNotificationTypeAndSubjectIdAndLinkId(OWNER_NEW_REVIEW, Collections.singletonList(reviewEvents.getOwnerReviewId()), reviewEvents.getReviewId());
	}
}