package ru.loylabs.portal.listener.review;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.listener.events.ReviewEvents;
import ru.loylabs.portal.repository.ReviewersRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;
import ru.loylabs.portal.service.notification.bell.data.ReviewRemainderPassingNotificationData;

@Slf4j
@Component
@RequiredArgsConstructor
public class ReviewRemainderPassingListener implements BaseEventListener<ReviewEvents.RemainderPassingReviewEvent> {

	private final BellNotificationPersister persister;
	private final BellNotificationFactory notificationFactory;
	private final ReviewersRepository reviewersRepository;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@Override
	@EventListener
	public void handle(ReviewEvents.RemainderPassingReviewEvent event) {
		reviewersRepository.findByReviewerIdAndReviewId(event.getReviewerId(), event.getReviewId())
				.ifPresent(reviewer -> {
					var notification = notificationFactory.create(new ReviewRemainderPassingNotificationData(reviewer));
					persister.persist(notification, reviewer.getReviewer());
					wsSender.send(notification);
				});
	}
}
