package ru.loylabs.portal.listener.skill;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.event.EventListener;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.listener.events.GradeEvents;
import ru.loylabs.portal.repository.GradeRepository;
import ru.loylabs.portal.repository.PersonSkillRepository;

@Slf4j
@RequiredArgsConstructor
@Component
public class ReplaceGradeInPersonSkillOnDefaultValueListener implements BaseEventListener<GradeEvents.GradeDeletedEvent> {

	private final PersonSkillRepository personSkillRepository;
	private final GradeRepository gradeRepository;

	@Override
	@Async("listenersThreadPoolTaskExecutor")
	@EventListener
	public void handle(GradeEvents.GradeDeletedEvent event) {
		var defaultGrade = gradeRepository.getDefaultGrade();
		personSkillRepository.findAllByGradeId(event.getGradeId())
				.forEach(personSkill -> {
					personSkill.setGrade(defaultGrade);
					personSkillRepository.save(personSkill);
				});

	}
}
