package ru.loylabs.portal.listener.story;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.StoryGroupCreateNotificationData;
import ru.loylabs.portal.listener.events.StoryEvents;
import ru.loylabs.portal.repository.StoryGroupRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Component
@RequiredArgsConstructor
public class StoryGroupCreateListener implements BaseEventListener<StoryEvents.StoryGroupCreateEvent> {

	private final StoryGroupRepository storyGroupRepository;
	private final BellNotificationFactory factory;
	private final BellNotificationPersister notificationPersister;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;


	@Override
	@EventListener
	public void handle(StoryEvents.StoryGroupCreateEvent event) {
		storyGroupRepository.findById(event.getStoryGroupId())
				.ifPresent(group -> {
					var notification = factory.create(new StoryGroupCreateNotificationData(group));
					notificationPersister.persistForAll(notification);
					wsSender.send(notification);
				});
	}
}
