package ru.loylabs.portal.listener.task;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.listener.BaseEventListener;
import ru.loylabs.portal.service.notification.bell.data.TaskAppointObserverNotificationData;
import ru.loylabs.portal.service.notification.bell.data.TaskCreateNotificationData;
import ru.loylabs.portal.listener.events.TaskEvents;
import ru.loylabs.portal.repository.TaskRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationFactory;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Slf4j
@Component
@RequiredArgsConstructor
public class TaskCreateListener implements BaseEventListener<TaskEvents.TaskCreateEvent> {

	private final BellNotificationPersister persister;
	private final BellNotificationFactory notificationFactory;
	private final TaskRepository taskRepository;
	@Qualifier("bellNotificationSenderImpl")
	private final NotificationSender<BellNotification> wsSender;

	@Override
	@EventListener
	public void handle(TaskEvents.TaskCreateEvent event) {
		taskRepository.findByIdAndAchievementId(event.getTaskId(),event.getAchievementId())
				.ifPresent(task ->{
					notifyTaskOwner(task);
					notifyTaskObservers(task);
				});
	}

	private void notifyTaskObservers(Task task) {
		var notificationForObservers = notificationFactory.create(
				new TaskAppointObserverNotificationData(task.getAchievement(), task, task.getAuthor())
		);
		persister.persist(notificationForObservers, task.getObservers());
		wsSender.send(notificationForObservers);
	}

	private void notifyTaskOwner(Task task) {
		var notificationForOwner = notificationFactory.create(
				new TaskCreateNotificationData(task.getAchievement(), task)
		);
		persister.persist(notificationForOwner, task.getAchievement().getOwner());
		wsSender.send(notificationForOwner);
	}
}
