package ru.loylabs.portal.mapper;

import java.util.List;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.MappingConstants;
import org.mapstruct.MappingTarget;
import org.mapstruct.NullValuePropertyMappingStrategy;
import org.mapstruct.ReportingPolicy;
import ru.loylabs.portal.entity.Contact;
import ru.loylabs.portal.mapper.Qualifier.EmptyStringToNull;
import ru.loylabs.portal.presentation.request.UpdateContactRequest;
import ru.loylabs.portal.presentation.view.ContactView;
import ru.loylabs.portal.service.yandex.dto.Yandex360UserContactResponse;

@Mapper(componentModel = MappingConstants.ComponentModel.SPRING,
		unmappedTargetPolicy = ReportingPolicy.IGNORE,
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE)
public interface ContactMapper extends AbstractViewMapper<Contact, ContactView> {

	@Mapping(target = "phone", qualifiedBy = EmptyStringToNull.class)
	@Mapping(target = "email", qualifiedBy = EmptyStringToNull.class)
	@Mapping(target = "telegram", qualifiedBy = EmptyStringToNull.class)
	@Mapping(target = "skype", qualifiedBy = EmptyStringToNull.class)
	@Mapping(target = "linkedin", qualifiedBy = EmptyStringToNull.class)
	@Mapping(target = "github", qualifiedBy = EmptyStringToNull.class)
	@Mapping(target = "vk", qualifiedBy = EmptyStringToNull.class)
	@Mapping(target = "instagram", qualifiedBy = EmptyStringToNull.class)
	Contact toEntity(@MappingTarget Contact contact, UpdateContactRequest request);

	default Contact toEntity(List<Yandex360UserContactResponse> responses) {
		Contact contact = new Contact();
		responses.forEach(response -> {
			switch (response.getType()) {
				case "email" -> contact.setEmail(response.getValue());
				case "phone" -> contact.setPhone(response.getValue());
				case "skype" -> contact.setSkype(response.getValue());
			}
		});

		return contact;
	}

	@EmptyStringToNull
	default String emptyStringToNull(String s) {
		return s.isEmpty() ? null : s;
	}

}

