package ru.loylabs.portal.mapper;

import org.mapstruct.*;
import ru.loylabs.portal.entity.*;
import ru.loylabs.portal.enums.CommunityRole;
import ru.loylabs.portal.presentation.request.CreatePersonRequest;
import ru.loylabs.portal.presentation.request.UpdatePersonInfoRequest;
import ru.loylabs.portal.presentation.request.UpdatePersonRequest;
import ru.loylabs.portal.presentation.view.PersonCommunityView;
import ru.loylabs.portal.presentation.view.PersonLoginView;
import ru.loylabs.portal.presentation.view.PersonReviewView;
import ru.loylabs.portal.presentation.view.PersonView;

import java.time.LocalDate;

@Mapper(componentModel = MappingConstants.ComponentModel.SPRING,
		uses = { ContactMapper.class, JobMapper.class, AttachmentMapper.class, CityMapper.class, SecurityRoleMapper.class, PersonSkillMapper.class, StatusMapper.class},
		unmappedTargetPolicy = ReportingPolicy.IGNORE,
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE)
public interface PersonMapper extends AbstractViewMapper<Person, PersonView> {

	@Mapping(target = "id", ignore = true)
	@Mapping(target = "password", source = "password")
	@Mapping(target = "name", source = "request.name")
	@Mapping(target = "role", source = "role")
	@Mapping(target = "job", source = "job")
	@Mapping(target = "audit", ignore = true)
	@Mapping(target = "skills", ignore = true)
	Person toEntity(CreatePersonRequest request, String password, Job job,
					Contact contact, LocalDate hired, SecurityRole role, City city);

	@Mapping(target = "id", ignore = true)
	@Mapping(target = "avatar", ignore = true)
	@Mapping(target = "name", source = "request.name")
	Person toEntity(@MappingTarget Person person, UpdatePersonRequest request,City city);

	@Mapping(target = "id", ignore = true)
	@Mapping(target = "avatar", ignore = true)
	@Mapping(target = "name", ignore = true)
	@Mapping(target = "surname", ignore = true)
	@Mapping(target = "patronymic", ignore = true)
	@Mapping(target = "gender", ignore = true)
	Person toEntity(@MappingTarget Person person, UpdatePersonInfoRequest request);

	@Mapping(target = "id", ignore = true)
	@Mapping(target = "name", ignore = true)
	@Mapping(target = "role", source = "securityRole")
	Person toEntity(@MappingTarget Person person, SecurityRole securityRole);

	PersonLoginView toLoginView(Person person);

	PersonCommunityView toPersonCommunityView(Person person, CommunityRole communityRole);

	@Mapping(target = "id", source = "id")
	@Mapping(target = "name", ignore = true)
	@Mapping(target = "surname", ignore = true)
	@Mapping(target = "job", ignore = true)
	@Mapping(target = "avatar", ignore = true)
	@Mapping(target = "blocked", ignore = true)
	PersonReviewView toPersonReviewView(String id);
}
