package ru.loylabs.portal.mapper;

import org.mapstruct.*;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.entity.*;
import ru.loylabs.portal.presentation.request.CreateTaskRequest;
import ru.loylabs.portal.presentation.request.UpdateTaskRequest;
import ru.loylabs.portal.presentation.request.UpdateTaskSequenceStatusRequest;
import ru.loylabs.portal.presentation.view.TaskTagView;
import ru.loylabs.portal.presentation.view.TaskView;

import java.util.Comparator;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

@Mapper(componentModel = MappingConstants.ComponentModel.SPRING,
		unmappedTargetPolicy = ReportingPolicy.IGNORE,
		nullValuePropertyMappingStrategy = NullValuePropertyMappingStrategy.IGNORE,
		uses = {AttachmentMapper.class, PersonMapper.class, AchievementMapper.class})
public interface TaskMapper {
	@Mapping(target = "tags", expression = "java(sortSetToSortedList(task.getTags()))")
	TaskView toView(Task task);

	@Mapping(target = "id", ignore = true)
	@Mapping(source = "request.content", target = "content")
	@Mapping(source = "record.author", target = "author")
	@Mapping(source = "request.header", target = "header")
	@Mapping(source = "request.status", target = "status")
	@Mapping(source = "observers", target = "observers")
	@Mapping(source = "achievement", target = "achievement")
	Task toEntity(Record record, CreateTaskRequest request, Achievement achievement,
				  Set<Person> observers, Set<TaskTag> tags, int sequence);


	@Mapping(target = "id", ignore = true)
	Task toEntity(UpdateTaskRequest request, @MappingTarget Task task);

	@Mapping(target = "id", ignore = true)
	Task toEntity(UpdateTaskSequenceStatusRequest request, @MappingTarget Task task);

	default List<TaskTagView> sortSetToSortedList(Set<TaskTag> tags) {
		return tags.stream()
				.sorted(Comparator.comparing(TaskTag::getName))
				.map(TaskTagMapper.INSTANCE::toView)
				.collect(Collectors.toList());
	}
}
