package ru.loylabs.portal.mapper.parse;

import lombok.RequiredArgsConstructor;
import net.fortuna.ical4j.model.Calendar;
import net.fortuna.ical4j.model.Property;
import net.fortuna.ical4j.model.component.CalendarComponent;
import net.fortuna.ical4j.model.property.Attendee;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.presentation.request.IntegratedCalendarEvent;

import java.util.HashSet;

@Component
@RequiredArgsConstructor
public class CalendarEventParse {
	private final DateTimeParse dateTimeParse;
	private static final String EVENT_START = "DTSTART";
	private static final String EVENT_END = "DTEND";
	private static final String EVENT_DESCRIPTION = "DESCRIPTION";
	private static final String EVENT_NAME = "SUMMARY";
	private static final String EVENT_PARTICIPANTS = "ATTENDEE";
	private static final String TIME_ZONE = "X-WR-TIMEZONE";


	public IntegratedCalendarEvent toEntity(CalendarComponent component, String timeZone) {
		var event = new IntegratedCalendarEvent();
		component.getProperties().forEach(property -> {
			switch (property.getName()) {
				case EVENT_START ->
						event.setStartEvent(dateTimeParse.parseStringToZoneDateTime(property.getValue(), timeZone));
				case EVENT_END ->
						event.setEndEvent(dateTimeParse.parseStringToZoneDateTime(property.getValue(), timeZone));
				case EVENT_DESCRIPTION -> event.setDescription(property.getValue());
				case EVENT_NAME -> event.setName(property.getValue());
				case EVENT_PARTICIPANTS -> {
					String email = ((Attendee) property).getCalAddress().getSchemeSpecificPart();
					var allEmail = event.getEmailsEventParticipants();
					(allEmail = allEmail == null ? new HashSet<>() : allEmail).add(email);
					event.setEmailsEventParticipants(allEmail);
				}
			}
		});
		return event;
	}

	public String getTimeZone(Calendar calendar) {
		return calendar.getProperties().stream()
				.filter(property -> property.getName().equals(TIME_ZONE))
				.findFirst()
				.map(Property::getValue)
				.orElse(null);
	}
}
