package ru.loylabs.portal.mapper.parse;

import org.springframework.stereotype.Component;
import ru.loylabs.portal.exception.ApplicationException;

import java.time.LocalDate;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeFormatterBuilder;
import java.time.format.DateTimeParseException;
import java.time.temporal.ChronoField;

import static ru.loylabs.portal.exception.BaseException.Exception.INTEGRATED_CALENDAR_PARSE_DATE_ERROR;

@Component
public class DateTimeParse {
	public ZonedDateTime parseStringToZoneDateTime(String inputDate, String timeZone) {
		DateTimeFormatter formatter = new DateTimeFormatterBuilder()
				.appendPattern("[yyyyMMdd'T'HHmmssX][yyyyMMdd'T'HHmmss][yyyyMMdd]")
				.parseDefaulting(ChronoField.HOUR_OF_DAY, 0)
				.parseDefaulting(ChronoField.MINUTE_OF_HOUR, 0)
				.parseDefaulting(ChronoField.SECOND_OF_MINUTE, 0)
				.toFormatter();
		try {
			return ZonedDateTime.parse(inputDate, formatter.withZone(ZoneId.of(timeZone)));
		} catch (DateTimeParseException e) {
			throw new ApplicationException(INTEGRATED_CALENDAR_PARSE_DATE_ERROR);
		}
	}

	public LocalDate parseStringToLocalDate(String date) {
		try {
			return LocalDate.parse(date, DateTimeFormatter.ofPattern("dd-MM-yyyy")); // TODO Не уверен на счет формата, нужно обсуждать с фронтом
		} catch (DateTimeParseException e) {
			throw new ApplicationException(INTEGRATED_CALENDAR_PARSE_DATE_ERROR);
		}
	}
}
