package ru.loylabs.portal.presentation;

import lombok.RequiredArgsConstructor;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.service.security.Credential;

import java.util.Optional;
import java.util.UUID;

import static ru.loylabs.portal.exception.BaseException.Exception.SYSTEM_CREDENTIAL_FAILURE;

@RequiredArgsConstructor
public class SecurityUtil {

	public static Credential safeGet() {
		Authentication auth = SecurityContextHolder.getContext().getAuthentication();
		if (auth == null) return null;
		Object principal = auth.getPrincipal();
		return (principal instanceof Credential) ? (Credential) principal : null;
	}

	public static Credential getCredential() {
		return Optional.ofNullable(safeGet()).orElseThrow(() -> new ApplicationException(SYSTEM_CREDENTIAL_FAILURE));
	}

	public static UUID getCredentialPersonId() {
		return getCredential().getPerson().getId();
	}
}
