package ru.loylabs.portal.presentation.controller;

import static ru.loylabs.portal.config.URIConstants.AUTH_URI;
import static ru.loylabs.portal.config.URIConstants.LOGIN_URI;
import static ru.loylabs.portal.config.URIConstants.REFRESH_TOKEN_URI;
import static ru.loylabs.portal.config.URIConstants.TOKEN_URI;
import static ru.loylabs.portal.config.URIConstants.TOKEN_URI_PARAM;
import static ru.loylabs.portal.config.URIConstants.TOKEN_URI_PARAM_NAME;
import static ru.loylabs.portal.config.URIConstants.VERSION_1_URI;

import javax.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import io.swagger.annotations.ApiOperation;
import ru.loylabs.portal.config.jwt.JwtRequest;
import ru.loylabs.portal.config.jwt.JwtResponse;
import ru.loylabs.portal.config.jwt.RefreshJwtRequest;
import ru.loylabs.portal.service.interfaces.AuthService;

@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping(path = VERSION_1_URI + AUTH_URI,
				produces = MediaType.APPLICATION_JSON_VALUE)
public class AuthController {

	private final AuthService authService;

//--AUTH-----------------------------------------------------------------------------------------------------------------//

	@ApiOperation("Логин")
	@PostMapping(path = LOGIN_URI,
				 consumes = MediaType.APPLICATION_JSON_VALUE)
	public JwtResponse login(@Valid @RequestBody JwtRequest authRequest) {
		log.info("Request to login");
		return authService.login(authRequest);
	}

	@ApiOperation("Логин по ссылке")
	@PostMapping(LOGIN_URI + TOKEN_URI_PARAM)
	public JwtResponse loginViaToken(@PathVariable(TOKEN_URI_PARAM_NAME) String token) {
		log.info("Request to login via token: {}", token);
		return authService.loginViaToken(token);
	}

	@ApiOperation("Обновление AccessToken")
	@PostMapping(path = TOKEN_URI,
				 consumes = MediaType.APPLICATION_JSON_VALUE)
	public JwtResponse refresh(@Valid @RequestBody RefreshJwtRequest request) {
		log.info("Request to get new access token via refresh token");
		return authService.refresh(request.getRefreshToken());
	}

	@ApiOperation("Обновление RefreshToken")
	@PostMapping(path = REFRESH_TOKEN_URI,
				 consumes = MediaType.APPLICATION_JSON_VALUE)
	public JwtResponse updateRefreshToken(@Valid @RequestBody RefreshJwtRequest request) {
		log.info("Request to get new refresh token");
		return authService.updateRefreshToken(request.getRefreshToken());
	}

}
