package ru.loylabs.portal.presentation.controller;

import static ru.loylabs.portal.config.URIConstants.BUG_REPORT_URI;
import static ru.loylabs.portal.config.URIConstants.SEND_URI;
import static ru.loylabs.portal.config.URIConstants.VERSION_1_URI;
import static ru.loylabs.portal.enums.CredentialPermission.Fields.BUG_REPORT_WRITE;
import static ru.loylabs.portal.presentation.SecurityUtil.getCredential;

import java.util.Arrays;
import java.util.Collections;
import java.util.Optional;
import javax.validation.Valid;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import ru.loylabs.portal.presentation.request.CreateRecordRequest;
import ru.loylabs.portal.presentation.view.common.SuccessResponse;
import ru.loylabs.portal.service.interfaces.BugService;

@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping(path = VERSION_1_URI + BUG_REPORT_URI,
				produces = MediaType.APPLICATION_JSON_VALUE)
public class BugReportController {

	private final BugService bugService;

//--BUG-REPORTS-------------------------------------------------------------------------------------------------------//

	@PreAuthorize("hasAuthority('" + BUG_REPORT_WRITE + "')")
	@ApiOperation("Отправление уведомления об ошибки")
	@ApiImplicitParam(name = "request", value = "Use it in a form with type application/json", required = true,
					  dataType = "ru.loylabs.portal.presentation.request.CreateRecordRequest", paramType = "body")
	@PostMapping(path = SEND_URI,
				 consumes = { MediaType.APPLICATION_JSON_VALUE, MediaType.MULTIPART_FORM_DATA_VALUE })
	public SuccessResponse sendBugReport(@Valid @RequestPart CreateRecordRequest request,
										 @RequestPart(required = false) MultipartFile[] files) {
		log.info("Request to send a bug report: {}", request);
		bugService.sendBugReport(request, getCredential().getPerson(), Optional.ofNullable(files).map(Arrays::asList).orElse(Collections.emptyList()));
		return new SuccessResponse();
	}

}
