package ru.loylabs.portal.presentation.controller;

import static ru.loylabs.portal.config.URIConstants.DOWNLOAD_URI;
import static ru.loylabs.portal.config.URIConstants.FILE_NAME_URI_PARAM;
import static ru.loylabs.portal.config.URIConstants.FILE_NAME_URI_PARAM_NAME;
import static ru.loylabs.portal.config.URIConstants.VERSION_1_URI;
import static ru.loylabs.portal.config.URIConstants.ZIP_URI;
import static ru.loylabs.portal.enums.CredentialPermission.Fields.FILE_READ;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.io.Resource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.servlet.mvc.method.annotation.StreamingResponseBody;
import io.swagger.annotations.ApiOperation;
import ru.loylabs.portal.service.interfaces.DownloadService;

@Slf4j
@RequiredArgsConstructor
@RestController
@RequestMapping(VERSION_1_URI + DOWNLOAD_URI)
public class DownloadController {

	private final DownloadService downloadService;

//--FILES-------------------------------------------------------------------------------------------------------------//

	@PreAuthorize("hasAuthority('" + FILE_READ + "')")
	@ApiOperation("Получение пути к файлу")
	@GetMapping(produces = MediaType.TEXT_PLAIN_VALUE)
	public String getFilePath(@RequestParam String fileName) {
		return "attachments/" + fileName;
	}

	@PreAuthorize("hasAuthority('" + FILE_READ + "')")
	@ApiOperation("Загрузка файла")
	@GetMapping(path = FILE_NAME_URI_PARAM,
				produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
	public ResponseEntity<Resource> findFile(@PathVariable(FILE_NAME_URI_PARAM_NAME) String fileName) {
		log.info("Request to download file with name '{}'", fileName);
		Resource resource = downloadService.downloadFile(fileName);
		return ResponseEntity.ok()
							 .contentType(MediaType.APPLICATION_OCTET_STREAM)
							 .header(HttpHeaders.CONTENT_DISPOSITION, getFileHeaders(resource))
							 .body(resource);
	}

	private String getFileHeaders(Resource resource) {
		return String.format(
				"attachment; filename=\"%s\"", resource == null ? null : resource.getFilename()
		);
	}

	@PreAuthorize("hasAuthority('" + FILE_READ + "')")
	@ApiOperation("Загрузка файлов в архиве(zip)")
	@GetMapping(path = ZIP_URI,
				produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
	public StreamingResponseBody findFilesAsZip(HttpServletResponse response,
												@RequestParam List<String> fileNames) {
		log.info("Request to download files as ZIP-archive with names '{}'", fileNames);
		return downloadService.downloadZip(response, fileNames);
	}

}
