package ru.loylabs.portal.presentation.controller;

import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import ru.loylabs.portal.presentation.request.GenerateResetTokenRequest;
import ru.loylabs.portal.presentation.request.UpdatePersonPasswordViaTokenRequest;
import ru.loylabs.portal.presentation.view.common.SuccessResponse;
import ru.loylabs.portal.service.interfaces.PasswordService;

import javax.validation.Valid;

import static ru.loylabs.portal.config.URIConstants.PASSWORDS_URI;
import static ru.loylabs.portal.config.URIConstants.RESET_URI;
import static ru.loylabs.portal.config.URIConstants.TOKEN_URI_PARAM;
import static ru.loylabs.portal.config.URIConstants.TOKEN_URI_PARAM_NAME;
import static ru.loylabs.portal.config.URIConstants.UNBLOCK_URI;
import static ru.loylabs.portal.config.URIConstants.VERSION_1_URI;

@Slf4j
@RestController
@RequestMapping(path = VERSION_1_URI + PASSWORDS_URI,
				produces = MediaType.APPLICATION_JSON_VALUE)
@RequiredArgsConstructor
public class PasswordController {

	private final PasswordService passwordService;

//--PASSWORDS---------------------------------------------------------------------------------------------------------//

	@ApiOperation("Генерация ключа для смены пароля")
	@PutMapping(path = RESET_URI,
				consumes = MediaType.APPLICATION_JSON_VALUE)
	public SuccessResponse createResetToken(@Valid @RequestBody GenerateResetTokenRequest request) {
		log.info("Request for generating password-reset token");
		passwordService.updatePasswordResetToken(request);
		return new SuccessResponse();
	}

	@ApiOperation("Смена пароля с помощью токена")
	@PutMapping(path = RESET_URI + TOKEN_URI_PARAM,
				consumes = MediaType.APPLICATION_JSON_VALUE)
	public SuccessResponse updatePasswordViaToken(@PathVariable(TOKEN_URI_PARAM_NAME) String token,
												  @Valid @RequestBody UpdatePersonPasswordViaTokenRequest request) {
		log.info("Request for changing password via reset token");
		passwordService.updatePasswordViaToken(request, token);
		return new SuccessResponse();
	}

	@ApiOperation("Смена пароля c разблокировкой")
	@PutMapping(path = UNBLOCK_URI + RESET_URI + TOKEN_URI_PARAM,
			consumes = MediaType.APPLICATION_JSON_VALUE)
	public SuccessResponse passwordUpdateWithUnblock(@PathVariable(TOKEN_URI_PARAM_NAME) String token,
													@Valid @RequestBody UpdatePersonPasswordViaTokenRequest request) {
		log.info("Request for unblock user and update password");
		passwordService.passwordUpdateWithUnblock(request, token);
		return new SuccessResponse();
	}

}
