package ru.loylabs.portal.repository;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.enums.BellNotificationType;

import java.time.Instant;
import java.util.Collection;
import java.util.List;
import java.util.UUID;

@Repository
public interface BellNotificationRepository extends JpaRepository<BellNotification, UUID> {

	boolean existsBySubjectIdAndNotificationType(UUID eventId, BellNotificationType notificationType);

	boolean existsByNotificationTypeAndSubjectIdAndReceiversId(BellNotificationType type,
															   UUID subjectID,
															   UUID receiversId);

	int deleteAllByDateIsBefore(Instant cutoffDate);

	int deleteAllBySubjectId(UUID subjectId);

	int deleteAllBySubjectIdIn(Collection<UUID> subjectIds);

	void deleteAllBySubjectIdAndNotificationType(UUID subjectId, BellNotificationType type);

	@Transactional
	@Modifying
	@Query("DELETE FROM BellNotification n " +
			"WHERE n.notificationType = :notificationType " +
			"AND n.subjectId IN :subjectId " +
			"AND n.link LIKE CONCAT('%', :context, '%')")
	int deleteByNotificationTypeAndSubjectIdAndLinkId(@Param("notificationType") BellNotificationType notificationType,
													   @Param("subjectId") List<UUID> subjectId,
													   @Param("context") UUID context);

	@Transactional
	@Modifying
	@Query("DELETE FROM BellNotification n " +
			"WHERE n.notificationType = :notificationType " +
			"AND n.subjectId = :subjectId " +
			"AND n.link LIKE CONCAT('%', :context, '%')")
	int deleteNotificationByTypeAndSubjectAndLink(@Param("notificationType") BellNotificationType notificationType,
												   @Param("subjectId") UUID subjectId,
												   @Param("context") UUID context);
}