package ru.loylabs.portal.repository;

import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import ru.loylabs.portal.entity.CorporateCalendarEvent;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.enums.CalendarEventType;

import java.time.ZonedDateTime;
import java.util.List;
import java.util.Set;
import java.util.UUID;

public interface CorporateCalendarEventRepository extends JpaRepository<CorporateCalendarEvent, UUID> {

	List<CorporateCalendarEvent> findAllByRepeatId(UUID repeatId);
	List<CorporateCalendarEvent> findAllByStartDateTimeBetween(ZonedDateTime start, ZonedDateTime end);

	@Query("select e.id from CorporateCalendarEvent e where e.repeatId = :repeatId")
	Set<UUID> findByRepeatId(UUID repeatId);
	int deleteByEventTypeAndStartDateTimeBefore(CalendarEventType type, ZonedDateTime time);

	@Modifying
	@Query("DELETE FROM CorporateCalendarEvent e " +
			"WHERE e.isGenerated = true " +
			"AND e.eventType = :type " +
			"And e.startDateTime >= :time")
	int deleteGeneratedEventAfterStartDateTime(CalendarEventType type, ZonedDateTime time);

	@Query("SELECT COUNT(e) > 0 FROM CorporateCalendarEvent e " +
			"WHERE e.target = :target " +
			"AND YEAR(e.startDateTime) = :year " +
			"AND MONTH(e.startDateTime) = :month " +
			"AND DAY(e.startDateTime) = :day")
	boolean existByTargetAndDate(Person target, int year, int month, int day);

	int deleteAllByRepeatId(UUID repeatId);

	int deleteCorporateCalendarEventById(UUID uuid);
}
