package ru.loylabs.portal.repository;

import org.mapstruct.util.Experimental;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import ru.loylabs.portal.entity.KbArticle;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

public interface KbArticleRepository extends JpaRepository<KbArticle, UUID> {

	String SEARCH_ALGORITHM = "no_stop_words_search";

	Optional<KbArticle> findByIdAndSectionId(UUID id, UUID sectionId);

	int deleteByIdAndSectionId(UUID id, UUID sectionId);

	Page<KbArticle> findAll(Specification<KbArticle> specification, Pageable pageable);

	long countBySectionId(UUID sectionId);

	@Query("select a from KbArticle a where a.section.id = ?1")
	List<KbArticle> findAllBySectionId(UUID sectionId);

	@Experimental
	@Query(value = "select cast(a.id as varchar) from kb_article a join kb_section ks on ks.id = a.section_id" +
			" where to_tsvector('" + SEARCH_ALGORITHM + "',ks.name) @@ plainto_tsquery('" + SEARCH_ALGORITHM + "',:searchPhrase)" +
			" or to_tsvector('" + SEARCH_ALGORITHM + "',a.name) @@ plainto_tsquery('" + SEARCH_ALGORITHM + "',:searchPhrase)" +
			"or to_tsvector('" + SEARCH_ALGORITHM + "',a.content) @@ plainto_tsquery('" + SEARCH_ALGORITHM + "',:searchPhrase)",
			nativeQuery = true)
	List<UUID> getArticlesUUIDWithContent(String searchPhrase);

	boolean existsByNameAndSectionId(String name, UUID sectionId);
}
