package ru.loylabs.portal.repository;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import ru.loylabs.portal.entity.Department;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Title;
import java.sql.Date;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.*;

public interface PersonRepository extends JpaRepository<Person, UUID> {

	Optional<Person> findByUsername(String username);

	boolean existsByUsername(String username);

	Page<Person> findAll(Specification<Person> specification, Pageable pageable);

	@Query("SELECT p from Person p where date_part('month', p.dob) = ?1 and date_part('day', p.dob) >= ?2")
	Page<Person> findByDob(int month, int day, Pageable pageable);

	@Query("select p from Person p where to_char(p.dob, 'MM-DD') between ?1 and ?2")
	List<Person> findByDobBetween(String before, String after);

	@Query("SELECT p from Person p where date_part('month', p.dob) = ?1 and date_part('day', p.dob) = ?2")
	Set<Person> findAllByDob(int month, int day);

	@Query("select p from Person p where p.hired between ?1 and ?2 order by p.hired")
	List<Person> findByHiredBetweenOrderByHired(LocalDate hiredFirst, LocalDate hiredSecond);

	@Query("select p from Person p where to_char(p.dob, 'MM-DD') < ?1 and " +
		   "to_char(p.dob, 'MM-DD') >= to_char(now(), 'MM-DD')")
	List<Person> findAllBirthdaysTillDate(String date);

	@Query("select p from Person p where (to_char(p.dob, 'MM-DD') < ?1 and " +
		   "to_char(p.dob, 'MM-DD') >= to_char(now(), 'MM-DD')) or to_char(p.dob, 'MM-DD') < ?2")
	List<Person> findAllBirthdaysTillDateWithYearOverlap(String currentYearDate, String overlappingYearDate);

	List<Person> findAllByRoleRoleIn(Collection<String> roles);

	List<Person> findAllByJobDepartment(Department department);
	List<Person> findAllByJobTitle(Title title);
}
