package ru.loylabs.portal.repository;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.enums.RecordType;

import java.util.Optional;
import java.util.Set;
import java.util.UUID;

public interface RecordRepository extends JpaRepository<Record, UUID> {

	@Query("SELECT r  FROM Record r " +
			"WHERE (r.recordType = 'COMMENT' OR r.recordType = 'TASK_STATUS_UPDATE') " +
			"AND r.parentRecord.id = :parentId AND r.parentRecord.recordType = 'TASK' " +
			"ORDER BY r.date DESC")
	Optional<Record>  findLatestCommentOrTaskStatusUpdateByParentRecord(@Param("parentId") UUID parentId);

	Optional<Record> findTopByRecordTypeInAndParentRecordOrderByDateDesc(Set<RecordType> types,Record record);

	Optional<Record> findByIdAndRecordType(UUID id, RecordType recordType);

	Optional<Record> findByIdAndCommunityId(UUID id, UUID communityId);

	Optional<Record> findByIdAndRecordTypeAndParentRecordId(UUID id,RecordType type ,UUID parentId);

	Optional<Record> findByIdAndParentRecordIdAndParentRecordRecordType(UUID id, UUID parentId, RecordType parentType);

	Page<Record> findAll(Specification<Record> specification, Pageable pageable);

	boolean existsByIdAndRecordType(UUID id, RecordType recordType);

	boolean existsByIdAndAuthorId(UUID id, UUID authorId);

	int deleteByIdAndParentRecordId(UUID id, UUID parentId);

	int deleteByIdAndCommunityId(UUID id, UUID communityId);

	long countByParentRecordId(UUID parentRecordId);
}
