package ru.loylabs.portal.repository;

import java.util.Collection;
import java.util.List;
import java.util.Optional;
import java.util.UUID;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import ru.loylabs.portal.entity.SecurityPermission;
import ru.loylabs.portal.entity.SecurityRole;
import ru.loylabs.portal.enums.CredentialPermission;

public interface SecurityRoleRepository extends JpaRepository<SecurityRole, UUID> {

	Page<SecurityRole> findAll(Specification<SecurityRole> specification, Pageable pageable);

	Optional<SecurityRole> findByRole(String role);

	Optional<SecurityRole> findByName(String name);

	List<SecurityRole> findByPermissionsIn(Collection<SecurityPermission> permissions);

	List<SecurityRole> findByPermissions_IdIn(Collection<UUID> ids);

	boolean existsByRole(String role);

	boolean existsByName(String name);

	@Query("select case when count(sr) > 0 then true else false end from SecurityRole sr left join sr.permissions sp " +
		   "where sr.id = :id and sp.permission = :permission")
	boolean existsByIdAndPermissions(@Param("id") UUID id, @Param("permission") CredentialPermission permission);

}
