package ru.loylabs.portal.repository;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import ru.loylabs.portal.entity.Achievement;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.enums.TaskStatus;

import java.util.Optional;
import java.util.UUID;

public interface TaskRepository extends JpaRepository<Task, UUID> {

	Page<Task> findAll(Specification<Task> specification, Pageable pageable);

	Optional<Task> findByIdAndAchievementId(UUID taskId, UUID achievementID);

	int deleteByAchievementIdAndId(UUID achievementId, UUID taskId);

	boolean existsByAchievementAndStatus(Achievement achievement, TaskStatus status);

	boolean existsByAchievementAndStatusIsNot(Achievement achievement, TaskStatus status);

	int countByAchievement(Achievement achievement);

	int countByAchievementAndStatus(Achievement achievement, TaskStatus status);

	@Query("select coalesce(max(t.sequence),-1) from Task t where t.achievement.id = ?1 and t.status = ?2")
	int getMaxSequenceInStatus(UUID achievementId, TaskStatus status);

	boolean existsByAchievementIdAndObserversId(UUID achievementId, UUID personId);

	boolean existsByIdAndObserversId(UUID taskId,UUID observerId);
}