package ru.loylabs.portal.repository.redis.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Repository;
import ru.loylabs.portal.enums.redis.RedisHashKey;
import ru.loylabs.portal.repository.redis.JwtRefreshTokenRepository;

import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Repository
public class JwtRefreshTokenRepositoryImpl implements JwtRefreshTokenRepository {
	private final RedisTemplate<String, String> template;
	private final String HASH_KEY = RedisHashKey.PASSWORD_TOKEN.name();

	@Value("${jwt.ttl.refresh-token}")
	public long ttl;

	public JwtRefreshTokenRepositoryImpl(@Autowired @Qualifier("redisTemplateStringString") RedisTemplate<String, String> template) {
		this.template = template;
	}

	private String getKey(UUID personId) {
		return String.format("%s:%s", HASH_KEY, personId);
	}

	@Override
	public String get(UUID personId) {
		return template.opsForValue().get(getKey(personId));
	}

	@Override
	public void save(UUID personId, String token) {
		template.opsForValue().set(getKey(personId), token);
		template.expire(getKey(personId), ttl, TimeUnit.SECONDS);
	}

	@Override
	public void delete(UUID personId) {
		template.delete(getKey(personId));
	}
}
