package ru.loylabs.portal.repository.redis.impl;

import java.util.Optional;
import java.util.UUID;
import java.util.concurrent.TimeUnit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Repository;
import ru.loylabs.portal.enums.redis.RedisHashKey;
import ru.loylabs.portal.repository.redis.LoginTokenRepository;

@Repository
public class LoginTokenRepositoryImpl implements LoginTokenRepository {

	private final RedisTemplate<String, String> template;
	private final String HASH_KEY = RedisHashKey.LOGIN_TOKEN.name();

	@Value("${redis.ttl.login-link}")
	public long ttl;

	public LoginTokenRepositoryImpl(@Autowired @Qualifier("redisTemplateStringString") RedisTemplate<String, String> template) {
		this.template = template;
	}

	@Override
	public Optional<UUID> get(String token) {
		return Optional.ofNullable(template.opsForValue().get(( getKey(token) ))).map(UUID::fromString);
	}

	@Override
	public void save(String token, UUID personId) {
		template.opsForValue().set(getKey(token), personId.toString());
		template.expire(getKey(token), ttl, TimeUnit.SECONDS);
	}

	@Override
	public void delete(String token) {
		template.delete(getKey(token));
	}

	private String getKey(String token) {
		return String.format("%s:%s", HASH_KEY, token);
	}

}
