package ru.loylabs.portal.repository.redis.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Repository;
import ru.loylabs.portal.enums.redis.RedisHashKey;
import ru.loylabs.portal.repository.redis.OnlineStatusRepository;

import java.util.*;
import java.util.stream.Collectors;

@Repository
public class OnlineStatusRepositoryImpl implements OnlineStatusRepository {
	private final RedisTemplate<String, String> template;
	private final String HASH_KEY = RedisHashKey.ONLINE_PERSON.name();

	@Value("${redis.ttl.email-token}")
	public long ttl;

	public OnlineStatusRepositoryImpl(@Autowired @Qualifier("redisTemplateStringString") RedisTemplate<String, String> template) {
		this.template = template;
	}


	@Override
	public Set<UUID> getAll() {
		return Optional.ofNullable(template.opsForSet().members(HASH_KEY)).orElse(new HashSet<>())
				.stream()
				.map(s -> template.opsForValue().get(getKey(s)))
				.filter(Objects::nonNull)
				.map(UUID::fromString)
				.collect(Collectors.toSet());
	}

	@Override
	public void save(String sessionId, UUID personId) {
		template.opsForValue().set(getKey(sessionId), personId.toString());
		template.opsForSet().add(HASH_KEY, sessionId);
	}

	@Override
	public void delete(String sessionId) {
		template.delete(getKey(sessionId));
		template.opsForSet().remove(HASH_KEY, sessionId);
	}

	private String getKey(String sessionId) {
		return String.format("%s:%s", HASH_KEY, sessionId);
	}
}
