package ru.loylabs.portal.repository.redis.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Repository;
import ru.loylabs.portal.enums.redis.RedisHashKey;
import ru.loylabs.portal.repository.redis.PasswordEntryAttemptRepository;

import java.util.Optional;
import java.util.concurrent.TimeUnit;

@Repository
public class PasswordEntryAttemptRepositoryImpl implements PasswordEntryAttemptRepository {

    private final RedisTemplate<String, Integer> template;

    private final String HASH_KEY = RedisHashKey.PASSWORD_ENTRY_ATTEMPT.name();
    @Value("${redis.ttl.attempt-storage}")
    public long ttl;

    public PasswordEntryAttemptRepositoryImpl(@Autowired @Qualifier("redisTemplateStringInteger") RedisTemplate<String, Integer> template) {
        this.template = template;
    }


    @Override
    public Optional<Integer> get(String idPerson) {
        return Optional.ofNullable(template.opsForValue().get((getKey(idPerson))));
    }

    @Override
    public void update(String idPerson, Integer count) {
        template.opsForValue().set(getKey(idPerson), count);
        template.expire(getKey(idPerson), ttl, TimeUnit.HOURS);
    }

    @Override
    public void delete(String idPerson) {
        template.delete(getKey(idPerson));

    }

    private String getKey(String idPerson) {
        return String.format("%s:%s", HASH_KEY, idPerson);
    }
}
