package ru.loylabs.portal.repository.redis.impl;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.data.redis.core.HashOperations;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.enums.redis.RedisHashKey;
import ru.loylabs.portal.repository.redis.TaskDoneRepository;

import javax.annotation.PostConstruct;
import java.time.Instant;
import java.time.temporal.TemporalUnit;
import java.util.Map;
import java.util.Set;
import java.util.UUID;
import java.util.stream.Collectors;

@Repository
@RequiredArgsConstructor
public class TaskDoneRepositoryImpl implements TaskDoneRepository {

	@Qualifier("redisTemplateStringString")
	private final RedisTemplate<String,String> template;

	private HashOperations<String,String,String> hashOps;

	private static final String HASH_KEY = RedisHashKey.TASKS_DONE.name();

	@PostConstruct
	private void init(){
		hashOps = template.opsForHash();
	}

	@Override
	public Set<UUID> findAllCreatedTimeAgo(long amountToSubtract, TemporalUnit unit) {
		Map<String, String> allEntries = hashOps.entries(HASH_KEY);
		Instant timeAgo = Instant.now().minus(amountToSubtract, unit);

		return allEntries.entrySet().stream()
				.filter(entry -> Instant.parse(entry.getValue()).isBefore(timeAgo))
				.map(Map.Entry::getKey)
				.map(UUID::fromString)
				.collect(Collectors.toSet());
	}

	@Override
	public void save(Task task) {
		hashOps.put(HASH_KEY,task.getId().toString(), Instant.now().toString());
	}

	@Override
	@Transactional
	public void delete(UUID uuid) {
		hashOps.delete(HASH_KEY,uuid.toString());
	}
}
