package ru.loylabs.portal.repository.redis.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Repository;
import ru.loylabs.portal.enums.redis.RedisHashKey;
import ru.loylabs.portal.repository.redis.YandexRequestCounterRepository;

import java.util.concurrent.TimeUnit;

@Repository
public class YandexRequestCounterRepositoryImpl implements YandexRequestCounterRepository {

	private final RedisTemplate<String, Integer> template;
	private final String HASH_KEY = RedisHashKey.YANDEX_REQUEST_COUNTER.name();

	@Value("${yandex.service.period-requests.minutes}")
	public long ttl;

	public YandexRequestCounterRepositoryImpl(@Autowired @Qualifier("redisTemplateStringInteger") RedisTemplate<String, Integer> template) {
		this.template = template;
	}

	@Override
	public Long increment() {

		if (Boolean.FALSE.equals(template.hasKey(HASH_KEY))) {
			template.opsForValue().set(HASH_KEY, 0);
			template.expire(HASH_KEY, ttl, TimeUnit.MINUTES);
		}

		return template.opsForValue().increment(HASH_KEY);
	}

	@Override
	public Long getRemainingRequestPeriod() {
		return template.getExpire(HASH_KEY, TimeUnit.MINUTES);
	}
}
