package ru.loylabs.portal.script;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.service.interfaces.BellNotificationSchedulingService;

import java.util.concurrent.TimeUnit;

@Slf4j
@Component
@RequiredArgsConstructor
public class BellNotificationSchedulingExecutor {

	private final BellNotificationSchedulingService schedulingService;

	@Scheduled(timeUnit = TimeUnit.HOURS, fixedRate = 12)
	public void refreshBellNotification() {
		log.info("Cleaning outdated bell-notification");
		var cleared = schedulingService.cleanOutdatedBellNotification();
		log.info("{} bell-notification deleted", cleared);
	}

	@Scheduled(cron = "0 0 * * * *")
	public void notifyUpcomingEvents() {
		log.info("Creating notify upcoming events");
		var created = schedulingService.upcomingEventNotification();
		log.info("{} notification created", created);
	}

	@Scheduled(cron = "0 0 * * * *")
	public void notifyUpcomingBirthday() {
		log.info("Create upcoming birthday notifications");
		var created = schedulingService.upcomingPersonsBirthdayNotification();
		log.info("{} notification created", created);
	}

	@Scheduled(cron = "0 0 * * * *")
	public void notifyBirthday() {
		log.info("Create birthday notifications");
		var created = schedulingService.birthdaysNotification();
		log.info("{} notification created", created);
	}

	@Scheduled(cron = "0 * * * * *")
	public void notifyDeferred(){
		log.info("Creating deferred notifications");
		var created = schedulingService.taskDoneDelayedNotificationSend();
		log.info("{} delayed  notifications sent",created);
	}
}
