package ru.loylabs.portal.script;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.service.interfaces.CalendarSchedulingService;

import java.util.concurrent.TimeUnit;

@Slf4j
@Component
@EnableScheduling
@RequiredArgsConstructor
public class CalendarEventSchedulingExecutor {

	private final CalendarSchedulingService schedulingService;

	@Scheduled(timeUnit = TimeUnit.HOURS, fixedRate = 3)
	public void addingABirthdayCalendarEvent() {
		log.info("Adding a birthday event in calendar");
		var added = schedulingService.addBirthdayEvent();
		log.info("{} birthday calendar events added", added);
	}

	//	@Scheduled(cron = "0 0 4 * * *") 
	@Scheduled(timeUnit = TimeUnit.HOURS, fixedRate = 1) // TODO: 18.12.2023  

	public void addingAHolidayEvent() {
		log.info("Adding a holiday event in calendar");
		var added = schedulingService.addHolidayEvent();
		log.info("{} holiday calendar events added", added);
	}

	@Scheduled(cron = "0 0 3 * * *")
	public void cleanOutdatedBirthdayCalendarEvent() {
		log.info("clean a birthday event in calendar");
		var added = schedulingService.cleanOutdatedBirthdayEvent();
		log.info("{} birthday calendar events clean", added);
	}

}
