package ru.loylabs.portal.script;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import ru.loylabs.portal.service.interfaces.StoriesSchedulingService;

@Slf4j
@Service
@EnableScheduling
@RequiredArgsConstructor
public class StorySchedulingExecutor {
	private final StoriesSchedulingService systemStoriesSchedulingService;

	@Scheduled(cron = "${story.crons.clear-stories}")
	@Async("storiesThreadPoolTaskExecutor")
	public void clearOutdatedSystemStories() {
		log.info("Auto cleaning outdated stories from group");
		var cleared = systemStoriesSchedulingService.clearOutdatedStories();
		log.info("{} stories deleted from story groups", cleared);
	}

	@Scheduled(cron = "${story.crons.refresh-stories}")
	@Async("storiesThreadPoolTaskExecutor")
	public void refreshSystemStories() {
		log.info("Auto refreshing system stories");
		var added = systemStoriesSchedulingService.refreshSystemStories();
		log.info("{} stories have been refreshed.", added);
	}
}