package ru.loylabs.portal.service;

import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import ru.loylabs.portal.entity.CommunityPersonRole;
import ru.loylabs.portal.enums.CommunityRole;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.presentation.search.SearchCriteria;
import ru.loylabs.portal.presentation.search.SearchReversePolishNotation;
import ru.loylabs.portal.repository.CommunityPersonRoleRepository;
import ru.loylabs.portal.service.filter.AbstractFilteringAndSortingService;
import ru.loylabs.portal.service.filter.ListFilter;
import ru.loylabs.portal.service.interfaces.CommunityPersonRoleService;
import ru.loylabs.portal.service.interfaces.FilterUtils;

import java.util.UUID;

import static ru.loylabs.portal.enums.CommunityRole.OWNER;
import static ru.loylabs.portal.exception.BaseException.Exception.COMMUNITY_NOT_FOUND;
import static ru.loylabs.portal.exception.BaseException.Exception.COMMUNITY_NO_OWNER;

@Service
@RequiredArgsConstructor
public class CommunityPersonRoleServiceImpl extends AbstractFilteringAndSortingService<CommunityPersonRole> implements CommunityPersonRoleService {

	private final CommunityPersonRoleRepository communityPersonRoleRepository;
	private final FilterUtils filterUtils;

	@Override
	public Page<CommunityPersonRole> getAllPersonalCommunities(int page, int size, String sort, SearchReversePolishNotation criteria, UUID memberId) {
		criteria.add(SearchCriteria.builder().key("person.id").operation(":").value(memberId).build());
		ListFilter listFilter = filterUtils.getListFilter(page, size, sort, criteria, CommunityPersonRole.class);
		return communityPersonRoleRepository.findAll(getSpecification(listFilter), getPageable(listFilter));
	}

	@Override
	public Page<CommunityPersonRole> getAllPersonRoleInCommunity(UUID communityId, int page, int size, String sort, SearchReversePolishNotation criteria) {
		if (!communityPersonRoleRepository.existsByCommunityId(communityId))
			throw new ApplicationException(COMMUNITY_NOT_FOUND, communityId);
		criteria.add(SearchCriteria.builder().key("community.id").operation(":").value(communityId).build());
		ListFilter listFilter = filterUtils.getListFilter(page, size, sort, criteria, CommunityPersonRole.class);
		return communityPersonRoleRepository.findAll(getSpecification(listFilter), getPageable(listFilter));
	}

	@Override
	public CommunityPersonRole getCommunityOwner(UUID communityId) {
		return communityPersonRoleRepository.findByCommunityIdAndCommunityRole(communityId, OWNER)
				.orElseThrow(() -> new ApplicationException(COMMUNITY_NO_OWNER, communityId));
	}

	@Override
	public CommunityRole getPersonalRoleInCommunity(UUID communityId, UUID personId) {
		var role = communityPersonRoleRepository.findByCommunityIdAndPersonId(communityId, personId);
		return role.map(CommunityPersonRole::getCommunityRole).orElse(null);
	}
}
