package ru.loylabs.portal.service;

import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import ru.loylabs.portal.entity.Contact;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.presentation.request.UpdateContactRequest;
import ru.loylabs.portal.repository.ContactRepository;
import ru.loylabs.portal.service.interfaces.ContactService;

import static java.util.Objects.nonNull;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_EMAIL_ALREADY_EXIST;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_GITHUB_ALREADY_EXIST;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_INSTAGRAM_ALREADY_EXIST;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_LINKEDIN_ALREADY_EXIST;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_PHONE_ALREADY_EXIST;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_SKYPE_ALREADY_EXIST;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_TELEGRAM_ALREADY_EXIST;
import static ru.loylabs.portal.exception.BaseException.Exception.CONTACT_VK_ALREADY_EXIST;

@Service
@RequiredArgsConstructor
public class ContactServiceImpl implements ContactService {
	private final ContactRepository repository;

	@Override
	public void checkUnique(UpdateContactRequest newContact, Contact oldContact) {
		if (newContact != null) {
			if (newContact.getPhone() != null && !newContact.getPhone().equals(oldContact.getPhone())
					&& repository.existsByPhone(newContact.getPhone()))
				throw new ApplicationException(CONTACT_PHONE_ALREADY_EXIST, newContact.getPhone());
			if (newContact.getEmail() != null && !newContact.getEmail().equals(oldContact.getEmail())
					&& repository.existsByEmail(newContact.getEmail()))
				throw new ApplicationException(CONTACT_EMAIL_ALREADY_EXIST, newContact.getEmail());
			if (newContact.getTelegram() != null && !newContact.getTelegram().equals(oldContact.getTelegram())
					&& repository.existsByTelegram(newContact.getTelegram()))
				throw new ApplicationException(CONTACT_TELEGRAM_ALREADY_EXIST, newContact.getTelegram());
			if (newContact.getSkype() != null && !newContact.getSkype().equals(oldContact.getSkype())
					&& repository.existsBySkype(newContact.getSkype()))
				throw new ApplicationException(CONTACT_SKYPE_ALREADY_EXIST, newContact.getSkype());
			if (newContact.getLinkedin() != null && !newContact.getLinkedin().equals(oldContact.getLinkedin())
					&& repository.existsByLinkedin(newContact.getLinkedin()))
				throw new ApplicationException(CONTACT_LINKEDIN_ALREADY_EXIST, newContact.getLinkedin());
			if (newContact.getGithub() != null && !newContact.getGithub().equals(oldContact.getGithub())
					&& repository.existsByGithub(newContact.getGithub()))
				throw new ApplicationException(CONTACT_GITHUB_ALREADY_EXIST, newContact.getGithub());
			if (newContact.getVk() != null && !newContact.getVk().equals(oldContact.getVk())
					&& repository.existsByVk(newContact.getVk()))
				throw new ApplicationException(CONTACT_VK_ALREADY_EXIST, newContact.getVk());
			if (newContact.getInstagram() != null && !newContact.getInstagram().equals(oldContact.getInstagram())
					&& repository.existsByInstagram(newContact.getInstagram()))
				throw new ApplicationException(CONTACT_INSTAGRAM_ALREADY_EXIST, newContact.getInstagram());
		}
	}

	@Override
	public void checkUnique(Contact checkingContact) {
		if(nonNull(checkingContact)){

			var email = checkingContact.getEmail();
			if(nonNull(email) && repository.existsByEmail(email)){
				throw new ApplicationException(CONTACT_EMAIL_ALREADY_EXIST,email);
			}

			var phone = checkingContact.getPhone();
			if(nonNull(phone) && repository.existsByPhone(phone)){
				throw new ApplicationException(CONTACT_PHONE_ALREADY_EXIST, phone);
			}

			var skype = checkingContact.getSkype();
			if(nonNull(skype) && repository.existsBySkype(skype)){
				throw new ApplicationException(CONTACT_SKYPE_ALREADY_EXIST, skype);
			}
		}
	}
}
