package ru.loylabs.portal.service;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.Resource;
import org.springframework.core.io.UrlResource;
import org.springframework.stereotype.Service;
import org.springframework.web.servlet.mvc.method.annotation.StreamingResponseBody;
import ru.loylabs.portal.service.interfaces.DownloadService;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

@Service
@RequiredArgsConstructor
public class DownloadServiceImpl implements DownloadService {
	@Value("${file.path}")
	private String downloadPath;


	@Override
	public Resource downloadFile(String fileName) {
		Path path = Paths.get(downloadPath + "/" + fileName);
		Resource resource = null;

		try {
			resource = new UrlResource(path.toUri());
		} catch (MalformedURLException e) {
			e.printStackTrace();
		}
		return resource;
	}

	@Override
	public StreamingResponseBody downloadZip(HttpServletResponse response, List<String> fileNames) {
		StreamingResponseBody streamingResponseBody = out -> {
			final ZipOutputStream zipOutputStream = new ZipOutputStream(response.getOutputStream());
			InputStream inputStream = null;
			ZipEntry zipEntry;

			try {

				for (String name : fileNames) {
					Path path = Paths.get(downloadPath + "/" + name);
					File file = new File(path.toUri());
					zipEntry = new ZipEntry(file.getName());
					inputStream = new FileInputStream(file);

					zipOutputStream.putNextEntry(zipEntry);

					byte[] bytes = new byte[1024];
					while (inputStream.read(bytes) >= 0) {
						zipOutputStream.write(bytes, 0, bytes.length);
					}
				}

			} catch (IOException e) {
				e.printStackTrace();
			} finally {
				if (inputStream != null) {
					inputStream.close();
				}
				zipOutputStream.close();
			}
		};

		response.setContentType("application/zip");
		response.setHeader("Content-Disposition", "attachment; filename=ltPortal.zip");
		return streamingResponseBody;
	}
}
