package ru.loylabs.portal.service;

import lombok.RequiredArgsConstructor;
import net.fortuna.ical4j.data.CalendarBuilder;
import net.fortuna.ical4j.data.ParserException;
import net.fortuna.ical4j.model.Calendar;
import org.springframework.stereotype.Service;
import org.springframework.web.client.HttpClientErrorException;
import org.springframework.web.client.HttpServerErrorException;
import org.springframework.web.client.RestTemplate;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.mapper.parse.CalendarEventParse;
import ru.loylabs.portal.presentation.request.IntegratedCalendarEvent;
import ru.loylabs.portal.service.interfaces.RemoteCalendarClient;

import java.io.IOException;
import java.io.StringReader;
import java.util.List;
import java.util.stream.Collectors;

import static ru.loylabs.portal.exception.BaseException.Exception.INTEGRATED_CALENDAR_PARSE_ERROR;
import static ru.loylabs.portal.exception.BaseException.Exception.LINK_CONNECT_ERROR;

@RequiredArgsConstructor
@Service
public class RemoteCalendarClientImpl implements RemoteCalendarClient {

	private static final String SCOPE_EVENT = "VEVENT";
	private final CalendarEventParse calendarEventParse;

	public List<IntegratedCalendarEvent> getCalendarEvent(String urlFile) {
		var calendar = getICalendarFromBodyContent(getBodyContentFromUrl(urlFile));
		var timeZone = calendarEventParse.getTimeZone(calendar);
		return calendar.getComponents(SCOPE_EVENT).stream()
				.map(component -> calendarEventParse.toEntity(component, timeZone)).collect(Collectors.toList());
	}

	private String getBodyContentFromUrl(String url) {
		try {
			url = url.replace("%40", "@");
			var response = new RestTemplate().getForEntity(url, String.class);
			return response.getBody();
		} catch (HttpServerErrorException | HttpClientErrorException | IllegalArgumentException e) {
			throw new ApplicationException(LINK_CONNECT_ERROR, url);
		}
	}

	private Calendar getICalendarFromBodyContent(String bodyContent) {
		try {
			return new CalendarBuilder().build(new StringReader(bodyContent));
		} catch (ParserException | IOException e) {
			throw new ApplicationException(INTEGRATED_CALENDAR_PARSE_ERROR);
		}
	}
}
