package ru.loylabs.portal.service;

import static ru.loylabs.portal.exception.BaseException.Exception.PERMISSION_NOT_FOUND;

import java.util.List;
import java.util.UUID;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;
import ru.loylabs.portal.entity.SecurityPermission;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.presentation.search.SearchReversePolishNotation;
import ru.loylabs.portal.repository.SecurityPermissionRepository;
import ru.loylabs.portal.repository.SecurityRoleRepository;
import ru.loylabs.portal.service.filter.AbstractFilteringAndSortingService;
import ru.loylabs.portal.service.filter.ListFilter;
import ru.loylabs.portal.service.interfaces.FilterUtils;
import ru.loylabs.portal.service.interfaces.SecurityPermissionService;

@Service
@RequiredArgsConstructor
public class SecurityPermissionServiceImpl extends AbstractFilteringAndSortingService<SecurityPermission> implements SecurityPermissionService {

	private final SecurityPermissionRepository securityPermissionRepository;

	private final FilterUtils filterUtils;

	@Override
	public SecurityPermission getPermissionById(UUID id) {
		return securityPermissionRepository.findById(id)
										   .orElseThrow(() -> new ApplicationException(PERMISSION_NOT_FOUND, id));
	}

	@Override
	public SecurityPermission getPermissionByName(String name) {
		return securityPermissionRepository.findByName(name)
										   .orElseThrow(() -> new ApplicationException(PERMISSION_NOT_FOUND, name));
	}

	@Override
	public List<SecurityPermission> findByRoleId(UUID roleId) {
		return securityPermissionRepository.findByRoleId(roleId);
	}

	@Override
	public List<SecurityPermission> getAll() {
		return securityPermissionRepository.findAll();
	}

	@Override
	public Page<SecurityPermission> getAllPermissions(int page, int size, String sort,
													  SearchReversePolishNotation criteria) {
		ListFilter listFilter = filterUtils.getListFilter(page, size, sort, criteria, SecurityPermission.class);
		return securityPermissionRepository.findAll(getSpecification(listFilter), getPageable(listFilter));
	}

}
