package ru.loylabs.portal.service;

import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.enums.RecordType;
import ru.loylabs.portal.enums.TaskStatus;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.presentation.request.CreateRecordRequest;
import ru.loylabs.portal.presentation.search.SearchCriteria;
import ru.loylabs.portal.presentation.search.SearchReversePolishNotation;
import ru.loylabs.portal.repository.RecordRepository;
import ru.loylabs.portal.service.filter.AbstractFilteringAndSortingService;
import ru.loylabs.portal.service.filter.ListFilter;
import ru.loylabs.portal.service.interfaces.FilterUtils;
import ru.loylabs.portal.service.interfaces.RecordAdapter;
import ru.loylabs.portal.service.interfaces.TaskRailService;

import java.util.Collection;
import java.util.UUID;

import static ru.loylabs.portal.enums.RecordType.COMMENT;
import static ru.loylabs.portal.enums.RecordType.TASK_STATUS_UPDATE;
import static ru.loylabs.portal.exception.BaseException.Exception.RECORD_TYPE_NOT_FOUND;
import static ru.loylabs.portal.presentation.search.SearchOperation.OR;

@Component
@RequiredArgsConstructor
public class TaskRailServiceImpl extends AbstractFilteringAndSortingService<Record> implements TaskRailService {

	private final RecordRepository recordRepository;

	private final FilterUtils filterUtils;

	private final RecordAdapter recordAdapter;

	private final String messageUpdateTask = "Статус: %s → %s";


	@Override
	public Page<Record> getAllRecordInTaskRail(Integer page, Integer size, String sort,
											   SearchReversePolishNotation criteria, UUID parentId,
											   RecordType parentType) {
		if (!recordRepository.existsByIdAndRecordType(parentId, parentType))
			throw new ApplicationException(RECORD_TYPE_NOT_FOUND, parentId, parentType);
		criteria.add(SearchCriteria.builder().key("recordType").operation(":").value(COMMENT.name()).build());
		criteria.add(SearchCriteria.builder().key("recordType").operation(":").value(TASK_STATUS_UPDATE.name()).build(),
				OR);
		criteria.add(SearchCriteria.builder().key("parentRecord.id").operation(":").value(parentId).build());
		ListFilter listFilter = filterUtils.getListFilter(page, size, sort, criteria, Record.class);
		return recordRepository.findAll(getSpecification(listFilter), getPageable(listFilter));
	}

	@Override
	@Transactional
	public Record createRecordTaskStatusUpdate(Person author, Task task, TaskStatus oldStatus) {
		return recordRepository.save(
				recordAdapter.createRecord(
						new CreateRecordRequest(
								messageUpdateTask.formatted(
										oldStatus.getDescription(), task.getStatus().getDescription()
								)
						),
						author,
						task,
						TASK_STATUS_UPDATE,
						(Collection<MultipartFile>) null
				)
		);
	}

}
