package ru.loylabs.portal.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.select.Elements;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import ru.loylabs.portal.entity.MonthHolidayData;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.service.interfaces.WorkingCalendarService;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import static ru.loylabs.portal.exception.BaseException.Exception.WORKING_CALENDAR_SOURCE_UNAVAILABLE;
import static ru.loylabs.portal.utility.CalendarUtils.getMonth;

@Slf4j
@Service
@RequiredArgsConstructor
public class WorkingCalendarServiceImpl implements WorkingCalendarService {
	public static final String DIV_COL_MD_3 = "div.col-md-3";
	public static final String TABLE_CAL = "table.cal";
	public static final String TD_WEEKEND = "td.weekend";
	public static final String TD_HOLIDAY_WEEKEND = "td.holiday.weekend";
	public static final String TD_PREHOLIDAY = "td.preholiday";
	public static final String TH_MONTH = "th.month";

	@Value("${uri.consultant.working.calendar}")
	private String consultantWorkingCalendarUri;

	@Override
	public List<MonthHolidayData> getWorkingCalendar(String year) {
		final Document document;
		try {
			document = Jsoup.connect(consultantWorkingCalendarUri + year + "/").get();
		} catch (IOException e) {
			throw new ApplicationException(WORKING_CALENDAR_SOURCE_UNAVAILABLE, year);
		}
		final Elements elements = document.select(DIV_COL_MD_3);
		List<MonthHolidayData> calendar = new ArrayList<>();

		elements.forEach(e -> {
			MonthHolidayData mhd = new MonthHolidayData();
			final Elements eTable = e.select(TABLE_CAL);
			List<Integer> holidays = new ArrayList<>();
			List<Integer> preHolidays = new ArrayList<>();
			if (!eTable.isEmpty()) {
				final String month = eTable.select(TH_MONTH).text();
				mhd.setMonth(getMonth(month));
				eTable.select(TD_WEEKEND).forEach(s -> holidays.add(Integer.parseInt(s.text())));
				eTable.select(TD_HOLIDAY_WEEKEND).forEach(s -> holidays.add(Integer.parseInt(s.text())));
				eTable.select(TD_PREHOLIDAY).forEach(s -> preHolidays.add(Integer.parseInt(s.text().replace("*", ""))));
				mhd.setHolidays(holidays);
				mhd.setPreHolidays(preHolidays);
				calendar.add(mhd);
			}
		});

		return calendar;
	}
}
