package ru.loylabs.portal.service.adapter;

import java.time.Instant;
import java.util.Collection;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;
import ru.loylabs.portal.entity.Attachment;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Reaction;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.enums.RecordType;
import ru.loylabs.portal.mapper.RecordMapper;
import ru.loylabs.portal.presentation.request.CreateRecordRequest;
import ru.loylabs.portal.presentation.request.DeleteAttachmentsRequest;
import ru.loylabs.portal.presentation.request.UpdateRecordRequest;
import ru.loylabs.portal.service.interfaces.AttachmentAdapter;
import ru.loylabs.portal.service.interfaces.RecordAdapter;

@Component
@RequiredArgsConstructor
public class RecordAdapterImpl implements RecordAdapter {

	private final AttachmentAdapter attachmentAdapter;

	private final RecordMapper recordMapper;

	@Override
	public Record createRecord(CreateRecordRequest request, Person author, Record parentRecord, RecordType type,
							   Collection<MultipartFile> files) {
		return addAttachments(createRecord(request, author, parentRecord, type), files);
	}

	@Override
	public Record createRecord(CreateRecordRequest request, Person author, Record parentRecord, RecordType type,
							   Attachment attachment) {
		var record = createRecord(request, author, parentRecord, type);
		record.getAttachments().add(attachment);
		return record;
	}

	@Override
	public Record updateRecord(UpdateRecordRequest request, Record record) {
		var modified = request.getContent() != null;
		return recordMapper.toEntity(request, record, modified);
	}

	@Override
	@Transactional
	public <T extends Record> T addAttachments(T record, Collection<MultipartFile> files) {
		attachmentAdapter.addAttachments(record.getAttachments(), files);
		return record;
	}

	@Override
	@Transactional
	public <T extends Record> T deleteAttachments(T record, DeleteAttachmentsRequest request) {
		attachmentAdapter.deleteAttachments(record.getAttachments(), request.getAttachmentsIds());
		return record;
	}

	@Override
	public <T extends Record> T replaceAttachments(T record, MultipartFile file) {
		attachmentAdapter.replaceAttachment(record.getAttachments(), file);
		return record;
	}

	private Record createRecord(CreateRecordRequest request, Person author, Record parentRecord, RecordType type) {
		return recordMapper.toEntity(
				request, Instant.now(), type, new Reaction(), parentRecord, author
		);
	}

}

