package ru.loylabs.portal.service.adapter;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Story;
import ru.loylabs.portal.entity.StoryGroup;
import ru.loylabs.portal.enums.AttachmentType;
import ru.loylabs.portal.enums.RecordType;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.mapper.StoryMapper;
import ru.loylabs.portal.presentation.request.CreateRecordRequest;
import ru.loylabs.portal.presentation.request.CreateStoryRequest;
import ru.loylabs.portal.presentation.request.UpdateStoryRequest;
import ru.loylabs.portal.service.interfaces.RecordAdapter;
import ru.loylabs.portal.service.interfaces.StoryAdapter;

import java.time.LocalDateTime;
import java.util.Collection;
import java.util.List;

import static ru.loylabs.portal.exception.BaseException.Exception.STORY_WRONG_FILE_TYPE;
import static ru.loylabs.portal.utility.FileAttachmentTypeFactory.getCorrespondingType;

@Component
@RequiredArgsConstructor
public class StoryAdapterImpl implements StoryAdapter {
    private final RecordAdapter recordAdapter;
    private final StoryMapper storyMapper;

    @Value("${story.ttl.hours.admin}")
    private long adminTtlHours;

    @Override
    public Story createStory(CreateStoryRequest request, StoryGroup group, Person author, MultipartFile file) {
        var now = LocalDateTime.now();

        if (!AttachmentType.IMAGE.equals(getCorrespondingType(file.getContentType())))
            throw new ApplicationException(STORY_WRONG_FILE_TYPE);

        if (request.getTtlHours() == 0) request.setTtlHours(adminTtlHours);
        return storyMapper.toEntity(
                recordAdapter.createRecord(new CreateRecordRequest(request.getContent()),
                        author, null, RecordType.STORY, List.of(file)),
                request.getHeader(),
                now.plusHours(request.getTtlHours()),
                group,
                (now.getYear() * 1000) + now.getDayOfYear());
    }

    @Override
    public Story updateStory(UpdateStoryRequest request, Story story) {
        return storyMapper.toEntity(story, request);
    }
}
