package ru.loylabs.portal.service.notification.bell;

import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.repository.BellNotificationRepository;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.BellNotificationPersister;

import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

@Component
@RequiredArgsConstructor
@Transactional
public class BellNotificationPersisterImpl implements BellNotificationPersister {

	private final PersonRepository personRepository;

	private final BellNotificationRepository notificationRepository;


	@Override
	public void persist(BellNotification notification, Person recipient) {
		if (isNotNotificationAuthor(notification, recipient) && !recipient.isBlocked()) {
			notification.getReceivers().add(recipient);
			if(notification.getReceivers().size() > 0) notificationRepository.save(notification);
		}
	}

	@Override
	public void persist(BellNotification notification, Set<Person> recipients) {
		notification.getReceivers().addAll(recipients.stream()
				.filter(recipient -> isNotNotificationAuthor(notification, recipient))
				.filter(person -> !person.isBlocked())
				.collect(Collectors.toSet()));
		if(notification.getReceivers().size() > 0) notificationRepository.save(notification);
	}

	@Override
	public void persistForPersonWithRole(BellNotification notification, String... role) {
		var personWithRole = personRepository.findAllByRoleRoleIn(Set.of(role)).stream()
				.filter(person -> isNotNotificationAuthor(notification, person) && !person.isBlocked())
				.collect(Collectors.toSet());
		notification.getReceivers().addAll(personWithRole);
		if(notification.getReceivers().size() > 0) notificationRepository.save(notification);
	}

	@Override
	public void persistForAll(BellNotification notification) {
		var allPerson = personRepository.findAll().stream()
				.filter(person -> isNotNotificationAuthor(notification, person) && !person.isBlocked())
				.collect(Collectors.toSet());
		notification.getReceivers().addAll(allPerson);
		if(notification.getReceivers().size() > 0) notificationRepository.save(notification);
	}

	private boolean isNotNotificationAuthor(BellNotification notification, Person person) {
		if (Objects.nonNull(notification.getAuthor()) && Objects.nonNull(person)){
			return !notification.getAuthor().getId().equals(person.getId());
		}
		return true;
	}
}
