package ru.loylabs.portal.service.notification.bell.data;

import lombok.EqualsAndHashCode;
import lombok.Value;
import org.springframework.web.util.UriTemplate;
import ru.loylabs.portal.entity.CorporateCalendarEvent;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.enums.BellNotificationType;
import ru.loylabs.portal.utility.settings.SettingsArgsBuilder;

import java.time.ZoneId;
import java.time.format.DateTimeFormatter;

import static ru.loylabs.portal.config.URIConstants.CALENDAR_URI;

@Value
@EqualsAndHashCode(callSuper = false)
public class CalendarEventCreateNotificationData extends NotificationData {

	static final String path = CALENDAR_URI + "/{data}?event={id}";
	CorporateCalendarEvent calendarEvent;
	Person sender;

	@Override
	public FieldsPack initFieldsPack() {
		var formatter = DateTimeFormatter.ofPattern("dd-MM-yyyy");
		var date = calendarEvent.getStartDateTime().withZoneSameInstant(ZoneId.systemDefault());
		var uri = new UriTemplate(path)
				.expand(date.format(formatter), calendarEvent.getId())
				.toString();

		var args = new SettingsArgsBuilder()
				.author(sender)
				.calendarEventName(calendarEvent.getEventName())
				.calendarEventDate(date)
				.build();

		return new FieldsPack(sender, args, BellNotificationType.CALENDAR_NEW_EVENT, uri, calendarEvent.getId());
	}
}
