package ru.loylabs.portal.service.notification.bell.data;

import lombok.EqualsAndHashCode;
import lombok.Value;
import org.springframework.web.util.UriTemplate;
import ru.loylabs.portal.entity.CorporateCalendarEvent;
import ru.loylabs.portal.utility.settings.SettingsArgsBuilder;

import java.time.ZoneId;
import java.time.format.DateTimeFormatter;

import static ru.loylabs.portal.config.URIConstants.CALENDAR_URI;
import static ru.loylabs.portal.enums.BellNotificationType.CALENDAR_UPCOMING_EVENT;

@Value
@EqualsAndHashCode(callSuper = false)
public class CalendarUpcomingEventNotificationData extends NotificationData {

	static final String path = CALENDAR_URI + "/{data}?event={id}";
	CorporateCalendarEvent event;

	@Override
	public FieldsPack initFieldsPack() {
		var formatter = DateTimeFormatter.ofPattern("dd-MM-yyyy");
		var date = event.getStartDateTime().withZoneSameInstant(ZoneId.systemDefault());
		var uri = new UriTemplate(path)
				.expand(date.format(formatter), event.getId())
				.toString();

		var args = new SettingsArgsBuilder()
				.calendarEventName(event.getEventName())
				.build();
		return new FieldsPack(null, args, CALENDAR_UPCOMING_EVENT, uri, event.getId());
	}
}
