package ru.loylabs.portal.service.notification.bell.data;

import lombok.EqualsAndHashCode;
import lombok.Value;
import org.springframework.web.util.UriTemplate;
import ru.loylabs.portal.entity.Achievement;
import ru.loylabs.portal.entity.Record;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.utility.settings.SettingsArgsBuilder;

import static ru.loylabs.portal.config.URIConstants.ACHIEVEMENTS_URI;
import static ru.loylabs.portal.config.URIConstants.ACHIEVEMENT_ID_URI_PARAM;
import static ru.loylabs.portal.config.URIConstants.PERSON_ID_URI_PARAM;
import static ru.loylabs.portal.config.URIConstants.TASKS_URI;
import static ru.loylabs.portal.config.URIConstants.TASK_ID_URI_PARAM;
import static ru.loylabs.portal.enums.BellNotificationType.TASK_COMMENT;

@Value
@EqualsAndHashCode(callSuper = false)
public class TaskCommentNotificationData extends NotificationData {

	static final String path = "/profile"
			+ PERSON_ID_URI_PARAM
			+ ACHIEVEMENTS_URI
			+ ACHIEVEMENT_ID_URI_PARAM
			+ TASKS_URI
			+ TASK_ID_URI_PARAM;
	Achievement achievement;
	Task task;
	Record comment;

	@Override
	public FieldsPack initFieldsPack() {
		var uri = new UriTemplate(path)
				.expand(achievement.getOwner().getId(), achievement.getId(), task.getId())
				.toString();
		var args = new SettingsArgsBuilder()
				.author(comment.getAuthor())
				.task(task)
				.achievement(achievement)
				.record(comment)
				.build();

		return new FieldsPack(comment.getAuthor(), args, TASK_COMMENT, uri, comment.getId());
	}
}
