package ru.loylabs.portal.service.notification.bell.data;

import lombok.EqualsAndHashCode;
import lombok.Value;
import org.springframework.web.util.UriTemplate;
import ru.loylabs.portal.entity.Achievement;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Task;
import ru.loylabs.portal.utility.settings.SettingsArgsBuilder;

import static ru.loylabs.portal.config.URIConstants.ACHIEVEMENTS_URI;
import static ru.loylabs.portal.config.URIConstants.ACHIEVEMENT_ID_URI_PARAM;
import static ru.loylabs.portal.config.URIConstants.PERSON_ID_URI_PARAM;
import static ru.loylabs.portal.config.URIConstants.TASKS_URI;
import static ru.loylabs.portal.config.URIConstants.TASK_ID_URI_PARAM;
import static ru.loylabs.portal.enums.BellNotificationType.TASK_STATUS_UPDATE;

@Value
@EqualsAndHashCode(callSuper = false)
public class TaskStatusUpdateNotificationData extends NotificationData {

	static final String path = "/profile"
			+ PERSON_ID_URI_PARAM
			+ ACHIEVEMENTS_URI
			+ ACHIEVEMENT_ID_URI_PARAM
			+ TASKS_URI
			+ TASK_ID_URI_PARAM;
	Achievement achievement;
	Task task;
	Person updated;

	@Override
	public FieldsPack initFieldsPack() {
		var uri = new UriTemplate(path)
				.expand(achievement.getOwner().getId(), achievement.getId(), task.getId())
				.toString();
		var args = new SettingsArgsBuilder()
				.author(updated)
				.task(task)
				.achievement(achievement)
				.build();

		return new FieldsPack(updated, args, TASK_STATUS_UPDATE, uri, task.getId());
	}
}
