package ru.loylabs.portal.service.review;

import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.ApplicationEventPublisher;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.Reviewers;
import ru.loylabs.portal.listener.events.ReviewEvents;
import ru.loylabs.portal.repository.ReviewPersonSkillRepository;
import ru.loylabs.portal.repository.ReviewersRepository;
import ru.loylabs.portal.service.interfaces.ReviewSchedulingService;

import java.time.LocalDate;
import java.util.List;
import java.util.stream.Collectors;

@Component
@RequiredArgsConstructor
public class ReviewSchedulingServiceImpl implements ReviewSchedulingService {

	private final ReviewersRepository reviewersRepository;
	private final ReviewPersonSkillRepository reviewPersonSkillRepository;
	private final ApplicationEventPublisher publisher;

	@Value("${review.extending_review_end_days}")
	private long extendingDays;

	@Override
	public int deleteReviewerBecauseBlocking() {
		var rev = reviewersRepository.findAllByReviewerBlockedTrueAndVotedFalse();
		reviewersRepository.removeByReviewer(rev);
		return rev.size();
	}

	@Override
	public int extendReview() {
		var review = reviewPersonSkillRepository.findAllByEndReview(LocalDate.now());
		review = review.stream().peek(r -> r.setEndReview(LocalDate.now().plusDays(extendingDays))).collect(Collectors.toList());
		reviewPersonSkillRepository.saveAll(review);

		review.forEach(r -> sendNotificationsNotVotingReviewParticipants(reviewersRepository.findAllByReviewIdAndVotedFalse(r.getId())));
		return review.size();
	}

	private void sendNotificationsNotVotingReviewParticipants(List<Reviewers> reviewers) {
		reviewers.stream()
				.filter(this::hasNotVoted)
				.map(this::createRemainderEvent)
				.forEach(publisher::publishEvent);
	}

	private boolean hasNotVoted(Reviewers r) {
		return !r.isVoted();
	}

	private ReviewEvents.RemainderPassingReviewEvent createRemainderEvent(Reviewers r) {
		return ReviewEvents.RemainderPassingReviewEvent.of(
				r.getReview().getId(),
				r.getReviewer().getId(),
				r.getReview().getOwner().getId()
		);
	}
}
