package ru.loylabs.portal.service.security;

import java.util.Collection;
import java.util.stream.Collectors;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.SecurityPermission;

@Getter
@RequiredArgsConstructor
public class Credential implements UserDetails {

	private final Person person;

	@Override
	public Collection<? extends GrantedAuthority> getAuthorities() {
		return person.getRole().getPermissions().stream().map(SecurityPermission::getPermission).collect(Collectors.toSet());
	}

	@Override
	public String getPassword() {
		return person.getPassword();
	}

	@Override
	public String getUsername() {
		return person.getUsername();
	}

	@Override
	public boolean isAccountNonExpired() {
		return true;
	}

	@Override
	public boolean isAccountNonLocked() {
		return true;
	}

	@Override
	public boolean isCredentialsNonExpired() {
		return true;
	}

	@Override
	public boolean isEnabled() {
		return !person.isBlocked();
	}

}
