package ru.loylabs.portal.service.security.password;

import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

@ToString
@EqualsAndHashCode
public class PasswordValidationResult {

	private static final PasswordValidationResult SUCCESS = new PasswordValidationResult(null);

	private final Collection<PasswordValidationError> errors;

	private PasswordValidationResult(Collection<PasswordValidationError> errors) {
		this.errors = errors;
	}

	public static PasswordValidationResult success() {
		return SUCCESS;
	}

	public static PasswordValidationResult failure(Collection<PasswordValidationError> errors) {
		return new PasswordValidationResult(errors);
	}

	public static Builder builder() {
		return new Builder();
	}

	public static Builder withErrors(Collection<PasswordValidationError> errors) {
		return new Builder().errors(errors);
	}

	public boolean isSuccess() {
		return errors == null || errors.isEmpty();
	}

	public Collection<PasswordValidationError> getErrors() {
		return isSuccess() ? Collections.emptySet() : errors;
	}

	@Getter
	@RequiredArgsConstructor
	@ToString
	@EqualsAndHashCode
	public static class PasswordValidationError {

		private final String message;

	}

	public static class Builder {

		private Collection<PasswordValidationError> errors = new HashSet<>();

		public Builder errors(Collection<PasswordValidationError> errors) {
			this.errors = errors;

			return this;
		}

		public Builder addError(PasswordValidationError error) {
			this.errors.add(error);

			return this;
		}

		public Builder addErrors(Collection<PasswordValidationError> errors) {
			this.errors.addAll(errors);

			return this;
		}

		public PasswordValidationResult build() {
			return new PasswordValidationResult(errors);
		}

	}

}
