package ru.loylabs.portal.service.security.password;

import java.util.Collection;
import java.util.HashSet;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.service.interfaces.PasswordValidator;
import ru.loylabs.portal.service.security.password.rules.DigitPasswordRule;
import ru.loylabs.portal.service.security.password.rules.LengthPasswordRule;
import ru.loylabs.portal.service.security.password.rules.LowercasePasswordRule;
import ru.loylabs.portal.service.security.password.rules.NoWhitespacePasswordRule;
import ru.loylabs.portal.service.security.password.rules.PasswordRule;
import ru.loylabs.portal.service.security.password.rules.SpecialSymbolPasswordRule;
import ru.loylabs.portal.service.security.password.rules.UppercasePasswordRule;

@Component
public class PortalPasswordValidator implements PasswordValidator {

	private final Collection<PasswordRule> rules = new HashSet<>();

	@Autowired
	public PortalPasswordValidator(@Value("${password.validation.length:8}") int minPasswordLength) {
		rules.add(new NoWhitespacePasswordRule());
		rules.add(new LengthPasswordRule(minPasswordLength, null));
		rules.add(new UppercasePasswordRule(1));
		rules.add(new LowercasePasswordRule(1));
		rules.add(new DigitPasswordRule(1));
		rules.add(new SpecialSymbolPasswordRule(1));
	}

	@Override
	public PasswordValidationResult validate(char[] rawChars) {
		PasswordValidationResult.Builder pvrBuilder = PasswordValidationResult.builder();
		for (PasswordRule rule : rules)
			if (!rule.apply(rawChars))
				pvrBuilder.addError(new PasswordValidationResult.PasswordValidationError(rule.getErrorMessage()));

		return pvrBuilder.build();
	}

	@Override
	public PasswordValidationResult validate(String rawPassword) {
		return validate(rawPassword.toCharArray());
	}

}