package ru.loylabs.portal.service.security.password;

import java.security.SecureRandom;
import java.util.List;
import java.util.Random;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Primary;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.service.interfaces.PasswordGenerator;
import ru.loylabs.portal.service.interfaces.PasswordValidator;

@Primary
@Component
public class RandomStringWithSpecialSymbolsPasswordGenerator implements PasswordGenerator {

	private static final char[] ALLOWED_SYMBOLS;

	static {
		StringBuilder symbol = new StringBuilder();
		for (char character = '0'; character <= '9'; character++)
			symbol.append(character);
		for (char character = 'a'; character <= 'z'; character++)
			symbol.append(character);
		for (char character = 'A'; character <= 'Z'; character++)
			symbol.append(character);
		List.of('+', '-', '_', '=', '!').forEach(symbol::append);
		ALLOWED_SYMBOLS = symbol.toString().toCharArray();
	}

	private final int passwordLength;

	private final PasswordValidator validator;

	@Autowired
	public RandomStringWithSpecialSymbolsPasswordGenerator(@Value("${password.autogenerated.length}") int passwordLength,
														   PasswordValidator validator) {
		this.passwordLength = passwordLength;
		this.validator = validator;
	}

	@Override
	public String generatePassword() {
		char[] buffer = new char[passwordLength];
		Random rnd = new Random();
		do {
			for (int index = 0; index < passwordLength; index++)
				buffer[index] = ALLOWED_SYMBOLS[rnd.nextInt(ALLOWED_SYMBOLS.length)];
		} while (!validator.validate(buffer).isSuccess());

		return new String(buffer);
	}

	private Random getRandom() {
		return new SecureRandom();
	}

}
