package ru.loylabs.portal.service.security.password.rules;

import static ru.loylabs.portal.utility.NumberUtils.isPositive;

import lombok.Getter;

@Getter
public class DigitPasswordRule implements PasswordRule {

	private final int minAmount;

	private final String errorMessage;

	public DigitPasswordRule(Integer minAmount) {
		this.minAmount = isPositive(minAmount) ? minAmount : 1;
		this.errorMessage = "Password must have at least " + minAmount + " digits";
	}

	@Override
	public boolean apply(char[] rawChars) {
		int count = 0;
		for (Character chara : rawChars)
			if (Character.isDigit(chara) && ++count >= minAmount) return true;
		return false;
	}

	@Override
	public String getErrorMessage() {
		return errorMessage;
	}

}
