package ru.loylabs.portal.service.security.password.rules;

import static ru.loylabs.portal.utility.NumberUtils.isPositive;

import lombok.Getter;

@Getter
public class LengthPasswordRule implements PasswordRule {

	private final Integer minLength;

	private final Integer maxLength;

	private final String errorMessage;

	public LengthPasswordRule(Integer minLength, Integer maxLength) {
		this.minLength = isPositive(minLength) ? minLength : null;
		this.maxLength = isPositive(maxLength) ? maxLength : null;
		if (minLength == null && maxLength == null)
			throw new IllegalArgumentException("At least 1 valid length constraint required");

		StringBuilder sb = new StringBuilder("Password must ");
		if (minLength != null && maxLength != null)
			sb.append("be between ").append(minLength).append(" and ").append(maxLength);
		else if (minLength != null)
			sb.append("be at least ").append(minLength).append(" characters long");
		else
			sb.append("not be less than ").append(maxLength).append(" characters long");

		this.errorMessage = sb.toString();
	}

	@Override
	public boolean apply(char[] rawChars) {
		return ( minLength == null || rawChars.length >= minLength )
			   && ( maxLength == null || rawChars.length <= maxLength );
	}

	@Override
	public String getErrorMessage() {
		return errorMessage;
	}

}
