package ru.loylabs.portal.service.security.password.rules;

import static ru.loylabs.portal.utility.NumberUtils.isPositive;

import java.util.Collection;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;
import lombok.Getter;

@Getter
public class SpecialSymbolPasswordRule implements PasswordRule {

	private static final Collection<Character> DEFAULT_SPECIAL_SYMBOLS = List.of('+', '-', '_', '=', '!');

	private final int minAmount;

	private final Collection<Character> symbols;

	private final String errorMessage;

	public SpecialSymbolPasswordRule(Integer minAmount) {
		this(minAmount, DEFAULT_SPECIAL_SYMBOLS);
	}

	public SpecialSymbolPasswordRule(Integer minAmount, Collection<Character> symbols) {
		this.minAmount = isPositive(minAmount) ? minAmount : 1;
		this.errorMessage = "Password must have at least " + minAmount + " of those characters: '"
							+ symbols.stream().map(Objects::toString).collect(Collectors.joining(", ")) + "'";
		this.symbols = symbols;
	}

	@Override
	public boolean apply(char[] rawChars) {
		int count = 0;
		for (Character chara : rawChars)
			if (symbols.contains(chara) && ++count >= minAmount) return true;
		return false;
	}

	@Override
	public String getErrorMessage() {
		return errorMessage;
	}

}
