package ru.loylabs.portal.service.settings;

import static ru.loylabs.portal.exception.BaseException.Exception.BELL_NOTIFICATION_SETTINGS_NOT_FOUND;
import static ru.loylabs.portal.exception.BaseException.Exception.BELL_NOTIFICATION_SETTINGS_NOT_FOUND_CURRENT;

import java.time.Instant;
import java.util.UUID;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.settings.BellNotificationSettings;
import ru.loylabs.portal.entity.settings.EmailNotificationSettings;
import ru.loylabs.portal.enums.BellNotificationType;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.mapper.settings.BellNotificationSettingsMapper;
import ru.loylabs.portal.presentation.request.settings.CreateBellNotificationSettingsRequest;
import ru.loylabs.portal.presentation.search.SearchReversePolishNotation;
import ru.loylabs.portal.repository.BellNotificationSettingsRepository;
import ru.loylabs.portal.service.filter.AbstractFilteringAndSortingService;
import ru.loylabs.portal.service.filter.ListFilter;
import ru.loylabs.portal.service.interfaces.BellNotificationSettingsService;
import ru.loylabs.portal.service.interfaces.FilterUtils;
import ru.loylabs.portal.service.interfaces.NotificationType;

@Component
@RequiredArgsConstructor
public class BellNotificationSettingsServiceImpl extends AbstractFilteringAndSortingService<BellNotificationSettings> implements BellNotificationSettingsService {

	private final BellNotificationSettingsRepository settingsRepository;

	private final BellNotificationSettingsMapper settingsMapper;

	private final FilterUtils filterUtils;

	@Override
	public BellNotificationSettings getCurrentSettings(BellNotificationType notificationType) {
		return settingsRepository.findTopByNotificationTypeOrderByCreationDateDesc(notificationType)
								 .orElseThrow(() -> new ApplicationException(BELL_NOTIFICATION_SETTINGS_NOT_FOUND_CURRENT,
																			 notificationType));
	}

	@Override
	public BellNotificationSettings getSettings(UUID id) {
		return settingsRepository.findById(id)
								 .orElseThrow(() -> new ApplicationException(BELL_NOTIFICATION_SETTINGS_NOT_FOUND,
																			 id));
	}

	@Override
	public Page<BellNotificationSettings> getAllSettings(int page, int size, String sort,
														 SearchReversePolishNotation criteria) {
		ListFilter listFilter = filterUtils.getListFilter(page, size, sort, criteria, EmailNotificationSettings.class);
		return settingsRepository.findAll(getSpecification(listFilter), getPageable(listFilter));
	}

	@Override
	public BellNotificationSettings createSettings(CreateBellNotificationSettingsRequest request,
												   BellNotificationType notificationType) {
		return settingsRepository.save(settingsMapper.toEntity(request, Instant.now(), notificationType));
	}

}
