package ru.loylabs.portal.service.settings;

import static ru.loylabs.portal.exception.BaseException.Exception.EMAIL_NOTIFICATION_SETTINGS_NOT_FOUND;
import static ru.loylabs.portal.exception.BaseException.Exception.EMAIL_NOTIFICATION_SETTINGS_NOT_FOUND_CURRENT;

import java.time.Instant;
import java.util.UUID;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.settings.EmailNotificationSettings;
import ru.loylabs.portal.enums.EmailNotificationType;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.mapper.settings.EmailNotificationSettingsMapper;
import ru.loylabs.portal.presentation.request.settings.CreateEmailNotificationSettingsRequest;
import ru.loylabs.portal.presentation.search.SearchReversePolishNotation;
import ru.loylabs.portal.repository.EmailNotificationSettingsRepository;
import ru.loylabs.portal.service.filter.AbstractFilteringAndSortingService;
import ru.loylabs.portal.service.filter.ListFilter;
import ru.loylabs.portal.service.interfaces.EmailNotificationSettingsService;
import ru.loylabs.portal.service.interfaces.FilterUtils;

@Component
@RequiredArgsConstructor
public class EmailNotificationSettingsServiceImpl extends AbstractFilteringAndSortingService<EmailNotificationSettings> implements EmailNotificationSettingsService {

	private final EmailNotificationSettingsRepository settingsRepository;

	private final EmailNotificationSettingsMapper settingsMapper;

	private final FilterUtils filterUtils;

	@Override
	public EmailNotificationSettings getCurrentSettings(EmailNotificationType emailNotificationType) {
		return settingsRepository.findTopByNotificationTypeOrderByCreationDateDesc(emailNotificationType)
								 .orElseThrow(() -> new ApplicationException(EMAIL_NOTIFICATION_SETTINGS_NOT_FOUND_CURRENT,
																			 emailNotificationType));
	}

	@Override
	public EmailNotificationSettings getSettings(UUID id) {
		return settingsRepository.findById(id)
								 .orElseThrow(() -> new ApplicationException(EMAIL_NOTIFICATION_SETTINGS_NOT_FOUND,
																			 id));
	}

	@Override
	public Page<EmailNotificationSettings> getAllSettings(int page, int size, String sort,
														  SearchReversePolishNotation criteria) {
		ListFilter listFilter = filterUtils.getListFilter(page, size, sort, criteria, EmailNotificationSettings.class);
		return settingsRepository.findAll(getSpecification(listFilter), getPageable(listFilter));
	}

	@Override
	public EmailNotificationSettings createSettings(CreateEmailNotificationSettingsRequest request,
													EmailNotificationType emailNotificationType) {
		return settingsRepository.save(settingsMapper.toEntity(request, Instant.now(), emailNotificationType));
	}

}
