package ru.loylabs.portal.service.settings;

import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.settings.SettingsTag;
import ru.loylabs.portal.enums.BellNotificationType;
import ru.loylabs.portal.enums.EmailNotificationType;
import ru.loylabs.portal.repository.BellNotificationAllowedTagsRepository;
import ru.loylabs.portal.repository.EmailNotificationAllowedTagsRepository;
import ru.loylabs.portal.repository.SettingsTagRepository;
import ru.loylabs.portal.service.interfaces.SettingsTagService;

import java.util.List;
import java.util.stream.Collectors;

@Component
@RequiredArgsConstructor
public class SettingsTagServiceImpl implements SettingsTagService {

	private final SettingsTagRepository tagRepository;

	private final EmailNotificationAllowedTagsRepository emailAllowedTags;

	private final BellNotificationAllowedTagsRepository bellAllowedTags;

	@Override
	public List<SettingsTag> getAllTags() {
		return tagRepository.findAll();
	}

	@Override
	public List<SettingsTag> getAllowedTagsForType(EmailNotificationType emailNotificationType) {
		return tagRepository.findAllById(emailAllowedTags.findById_NotificationType(emailNotificationType)
														 .stream()
														 .map(allowedTag -> allowedTag.getId().getTagId())
														 .collect(Collectors.toList()));
	}

	@Override
	public List<SettingsTag> getAllowedTagsForType(BellNotificationType notificationType) {
		return tagRepository.findAllById(bellAllowedTags.findById_NotificationType(notificationType)
														.stream()
														.map(allowedTag -> allowedTag.getId().getTagId())
														.collect(Collectors.toList()));
	}

}
