package ru.loylabs.portal.service.settings;

import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.settings.StorySettings;
import ru.loylabs.portal.enums.StoryGroupType;
import ru.loylabs.portal.exception.ApplicationException;
import ru.loylabs.portal.mapper.settings.StorySettingsMapper;
import ru.loylabs.portal.presentation.request.settings.CreateStorySettingsRequest;
import ru.loylabs.portal.presentation.search.SearchReversePolishNotation;
import ru.loylabs.portal.repository.StorySettingsRepository;
import ru.loylabs.portal.service.filter.AbstractFilteringAndSortingService;
import ru.loylabs.portal.service.filter.ListFilter;
import ru.loylabs.portal.service.interfaces.FilterUtils;
import ru.loylabs.portal.service.interfaces.StorySettingsService;

import java.time.Instant;
import java.util.UUID;

import static ru.loylabs.portal.exception.BaseException.Exception.STORY_SETTINGS_NOT_FOUND;
import static ru.loylabs.portal.exception.BaseException.Exception.STORY_SETTINGS_NOT_FOUND_CURRENT;

@Component
@RequiredArgsConstructor
public class StorySettingsServiceImpl extends AbstractFilteringAndSortingService<StorySettings> implements StorySettingsService {
	private final StorySettingsRepository settingsRepository;
	private final StorySettingsMapper settingsMapper;
	private final FilterUtils filterUtils;

	@Override
	public StorySettings getCurrentSettings(StoryGroupType type) {
		return settingsRepository.findTopByGroupTypeOrderByCreationDateDesc(type)
				.orElseThrow(() -> new ApplicationException(STORY_SETTINGS_NOT_FOUND_CURRENT, type));
	}

	@Override
	public StorySettings getSettings(UUID id) {
		return settingsRepository.findById(id)
				.orElseThrow(() -> new ApplicationException(STORY_SETTINGS_NOT_FOUND, id));
	}

	@Override
	public Page<StorySettings> getAllSettings(int page, int size, String sort, SearchReversePolishNotation criteria) {
		ListFilter listFilter = filterUtils.getListFilter(page, size, sort, criteria, StorySettings.class);
		return settingsRepository.findAll(getSpecification(listFilter), getPageable(listFilter));
	}

	@Override
	public StorySettings createSettings(CreateStorySettingsRequest request, StoryGroupType storyGroupType) {
		return settingsRepository.save(settingsMapper.toEntity(request, Instant.now(), storyGroupType));
	}
}
