package ru.loylabs.portal.service.story;

import lombok.RequiredArgsConstructor;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import ru.loylabs.portal.service.interfaces.StoriesSchedulingService;
import ru.loylabs.portal.service.story.updater.SystemStoryUpdater;

import java.util.List;


@Slf4j
@RequiredArgsConstructor
@Component
public class StoriesSchedulingServiceImpl implements StoriesSchedulingService {

    private final List<SystemStoryUpdater<?>> systemStoryUpdaters;

    @Override
    @Transactional
    public int clearOutdatedStories() {
        log.info("Starting clearing outdated stories.");
        return systemStoryUpdaters.stream()
                .mapToInt(SystemStoryUpdater::clearOutdatedStories)
                .sum();
    }

    @Override
    @Transactional
    public int refreshSystemStories() {
        log.info("Starting refreshing system stories.");
        return systemStoryUpdaters.stream()
                .mapToInt(SystemStoryUpdater::refreshSystemGroup)
                .sum();
    }
}