package ru.loylabs.portal.service.telegram;

import lombok.RequiredArgsConstructor;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.InlineKeyboardMarkup;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.ReplyKeyboard;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.ReplyKeyboardMarkup;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.buttons.InlineKeyboardButton;
import org.telegram.telegrambots.meta.api.objects.replykeyboard.buttons.KeyboardRow;
import ru.loylabs.portal.entity.KbArticle;
import ru.loylabs.portal.entity.KbSection;

import java.util.*;

import static ru.loylabs.portal.service.telegram.Constants.*;

@RequiredArgsConstructor
public class KeyboardFactory {

    public ReplyKeyboard getFunctionsKeyboard() {
        KeyboardRow row = new KeyboardRow();
        row.add(FAQ);
        return new ReplyKeyboardMarkup(List.of(row));
    }

    public InlineKeyboardMarkup getSectionKeyboard(List<KbSection> sections) {
        InlineKeyboardMarkup inlineKeyboardMarkup = new InlineKeyboardMarkup();
        List<List<InlineKeyboardButton>> keyboard = new ArrayList<>();

        sections.forEach(section -> keyboard.add(Collections.singletonList(
                InlineKeyboardButton.builder()
                        .text(Optional.of(section.getName()).orElse(""))
                        .callbackData(section.getId().toString())
                        .build())));

        inlineKeyboardMarkup.setKeyboard(keyboard);
        return inlineKeyboardMarkup;
    }

    public InlineKeyboardMarkup getArticlesKeyboard(List<KbArticle> articles) {
        InlineKeyboardMarkup inlineKeyboardMarkup = new InlineKeyboardMarkup();
        List<List<InlineKeyboardButton>> keyboard = new ArrayList<>();

        articles.forEach(article -> keyboard.add(Collections.singletonList(
                InlineKeyboardButton.builder()
                        .text(Optional.of(article.getName()).orElse(""))
                        .callbackData(article.getId().toString())
                        .build())));

        inlineKeyboardMarkup.setKeyboard(keyboard);
        return inlineKeyboardMarkup;
    }

    public InlineKeyboardMarkup getArticleKeyboard(KbArticle article) {
        InlineKeyboardMarkup inlineKeyboardMarkup = new InlineKeyboardMarkup();
        List<List<InlineKeyboardButton>> keyboard = new ArrayList<>();

        keyboard.add(Collections.singletonList(InlineKeyboardButton.builder()
                .text(BACK_BUTTON)
                .callbackData(article.getSection().getId().toString())
                .build()));

        inlineKeyboardMarkup.setKeyboard(keyboard);
        return inlineKeyboardMarkup;
    }
}
