package ru.loylabs.portal.service.telegram;

import org.springframework.stereotype.Component;
import org.telegram.abilitybots.api.bot.AbilityBot;
import org.telegram.abilitybots.api.bot.BaseAbilityBot;
import org.telegram.abilitybots.api.objects.Ability;
import org.telegram.abilitybots.api.objects.Flag;
import org.telegram.abilitybots.api.objects.Reply;
import org.telegram.telegrambots.meta.api.methods.commands.SetMyCommands;
import org.telegram.telegrambots.meta.api.objects.Update;
import org.telegram.telegrambots.meta.api.objects.commands.BotCommand;
import org.telegram.telegrambots.meta.api.objects.commands.scope.BotCommandScopeDefault;
import org.telegram.telegrambots.meta.exceptions.TelegramApiException;
import ru.loylabs.portal.config.telegram.TelegramBotProperties;
import ru.loylabs.portal.repository.KbArticleRepository;
import ru.loylabs.portal.repository.KbSectionRepository;

import java.util.ArrayList;
import java.util.List;
import java.util.function.BiConsumer;

import static org.telegram.abilitybots.api.objects.Locality.*;
import static org.telegram.abilitybots.api.objects.Privacy.*;
import static ru.loylabs.portal.service.telegram.Constants.*;
import static org.telegram.abilitybots.api.util.AbilityUtils.*;

@Component
@SuppressWarnings("unused")
public class LoyaltyBot extends AbilityBot {

    private final TelegramBotProperties properties;
    private final ResponseHandler responseHandler;
    private final KbSectionRepository sectionRepository;
    private final KbArticleRepository articleRepository;

    public LoyaltyBot(TelegramBotProperties properties, KbSectionRepository sectionRepository, KbArticleRepository articleRepository) {
        super(properties.getToken(), properties.getToken());
        this.properties = properties;
        this.sectionRepository = sectionRepository;
        this.articleRepository = articleRepository;
        this.responseHandler = new ResponseHandler(silent, db, sectionRepository, articleRepository);
        initCommandList();
    }

    public Ability startBot() {
        return Ability
                .builder()
                .name("start")
                .info(START_DESCRIPTION)
                .locality(USER)
                .privacy(PUBLIC)
                .action(ctx -> responseHandler.replyToStart(ctx.chatId()))
                .build();
    }

    public Ability stopBot() {
        return Ability
                .builder()
                .name("stop")
                .info(STOP_DESCRIPTION)
                .locality(USER)
                .privacy(PUBLIC)
                .action(ctx -> responseHandler.stopChat(ctx.chatId()))
                .build();
    }

    public Reply replyToButtons() {
        BiConsumer<BaseAbilityBot, Update> action = (abilityBot, upd) -> responseHandler.replyToButtons(upd);
        return Reply.of(action, Flag.TEXT, upd -> responseHandler.userIsActive(getChatId(upd)));
    }

    public Reply replyToCallBackQuery() {
        BiConsumer<BaseAbilityBot, Update> action = ((abilityBot, upd) -> responseHandler.replyToMessageButtons(upd));
        return Reply.of(action, Flag.CALLBACK_QUERY, upd -> responseHandler.userIsActive(getChatId(upd)));
    }

    @Override
    public long creatorId() {
        return 1493617120L;
    }

    private void initCommandList() {
        List<BotCommand> commands = new ArrayList<>();
        commands.add(BotCommand.builder().command("/start").description(START_DESCRIPTION).build());
        commands.add(BotCommand.builder().command("/commands").description(COMMANDS_DESCRIPTION).build());
        //commands.add(BotCommand.builder().command("/info").description(INFO_DESCRIPTION).build());
        commands.add(BotCommand.builder().command("/stop").description(STOP_DESCRIPTION).build());
        try {
            this.execute(SetMyCommands.builder()
                    .commands(commands)
                    .scope(new BotCommandScopeDefault())
                    .build());
        } catch (TelegramApiException e) {
            throw new RuntimeException(e);
        }
    }
}
