package ru.loylabs.portal.service.telegram.reader;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.RequiredArgsConstructor;

import java.util.List;
import java.util.Map;

@RequiredArgsConstructor
public class ArticleContentReader {

    public static String getArticleText(String jsonContent) {
        String text = null;
        ArticleContent content = getArticleContent(jsonContent);
        if (content.getEntityMap().isEmpty()) {
            text = getTextFromBlocks(content);
        } else {
            text = getTextWithURL(content);
        }
        return text;
    }

    private static String getTextFromBlocks(ArticleContent content) {
        StringBuilder text = new StringBuilder();
        content.getBlocks().forEach(block -> {
            text.append(block.getText());
            text.append("\n");
        });
        return text.toString().trim();
    }

    private static String getTextWithURL(ArticleContent content) {
        StringBuilder text = new StringBuilder();
        List<ArticleContent.Block> blocks = content.getBlocks();
        Map<Integer, ArticleContent.Entity> entityMap = content.getEntityMap();
        blocks.forEach(block -> {
            text.append("[");
            text.append(block.getText());
            text.append("]");

            text.append("(");
            text.append(entityMap.getOrDefault(blocks.indexOf(block), new ArticleContent.Entity(new ArticleContent.Entity.Data(null))).getData().getUrl());
            text.append(")");

            text.append("\n");
        });
        return text.toString();
    }

    private static ArticleContent getArticleContent(String jsonContent) {
        ArticleContent content = null;
        ObjectMapper objectMapper = new ObjectMapper();
        try {
            content = objectMapper.readValue(jsonContent, ArticleContent.class);
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }
        return content;
    }
}
