package ru.loylabs.portal.service.websocket;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.messaging.simp.SimpMessagingTemplate;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.entity.BellNotification;
import ru.loylabs.portal.mapper.BellNotificationMapper;
import ru.loylabs.portal.repository.PersonalBellNotificationRepository;
import ru.loylabs.portal.service.interfaces.NotificationSender;

@Component
@Slf4j
@RequiredArgsConstructor
public class BellNotificationSenderImpl implements NotificationSender<BellNotification> {

	private final static String USER_QUEUE = "/queue/notifications";
	private final SimpMessagingTemplate template;
	private final BellNotificationMapper mapper;
	private final PersonalBellNotificationRepository personalNotificationRepository;

	@Override
	public void send(BellNotification notification) {
		try {
			notification.getReceivers().forEach(receiver -> template.convertAndSendToUser(
					receiver.getUsername(),
					USER_QUEUE,
					mapper.toView(notification,
								  false,
								  personalNotificationRepository.countByPersonIdAndSeenIsFalse(receiver.getId()))));
		} catch (Exception e) {
			log.error("Error sending notification to recipients : {}", e.getMessage());
		}
	}

}
