package ru.loylabs.portal.service.websocket;

import org.springframework.messaging.simp.SimpMessageType;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;
import org.springframework.web.socket.WebSocketMessage;
import ru.loylabs.portal.enums.WebSocketHeader;
import ru.loylabs.portal.service.interfaces.WebSocketMessageParser;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Component
public class WebSocketMessageParserImpl implements WebSocketMessageParser {

	private static final Set<String> simpMessageTypes = Arrays.stream(SimpMessageType.values()).map(Object::toString).collect(Collectors.toSet());

	@Override
	public Map<String, String> parseHeaders(WebSocketMessage<?> message) {
		var headers = new HashMap<String, String>();
		for (var header : String.valueOf(message.getPayload()).split("\n")) {
			if (simpMessageTypes.contains(header)) {
				headers.put(WebSocketHeader.OPERATION.getValue(), header);
				continue;
			}
			if (StringUtils.hasText(header)) {
				var split = header.split(":");
				if (split.length == 2) headers.put(split[0], split[1]);
			}
		}
		return headers;
	}
}
