package ru.loylabs.portal.service.websocket;

import lombok.RequiredArgsConstructor;
import org.springframework.messaging.simp.SimpMessageType;
import org.springframework.stereotype.Component;
import org.springframework.util.StringUtils;
import ru.loylabs.portal.config.jwt.JwtProvider;
import ru.loylabs.portal.service.interfaces.WebSocketSecurity;

import java.util.Map;

import static ru.loylabs.portal.enums.WebSocketHeader.AUTHENTICATION;
import static ru.loylabs.portal.enums.WebSocketHeader.OPERATION;

@Component
@RequiredArgsConstructor
public class WebSocketSecurityImpl implements WebSocketSecurity {

	private final JwtProvider jwtProvider;

	@Override
	public boolean validateToken(Map<String, String> headers) {
		if (SimpMessageType.CONNECT.name().equalsIgnoreCase(headers.get(OPERATION.getValue()))) {
			String token = getCorrectToken(headers.get(AUTHENTICATION.getValue()));
			return token != null && jwtProvider.validateAccessToken(token);
		}
		return true;
	}

	@Override
	public String getCorrectToken(String bearer) {
		if (StringUtils.hasText(bearer) && bearer.startsWith("Bearer ")) {
			return bearer.substring(7);
		} else {
			return bearer;
		}
	}
}
