package ru.loylabs.portal.service.yandex;

import static ru.loylabs.portal.utility.StringUtils.isValid;

import java.util.Collection;
import java.util.concurrent.atomic.AtomicInteger;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.interfaces.PersonYandexSyncSchedulingService;
import ru.loylabs.portal.service.interfaces.Yandex360UserService;

@Slf4j
@Service
@RequiredArgsConstructor
public class PersonYandexSyncSchedulingServiceImpl implements PersonYandexSyncSchedulingService {

	private final Yandex360UserService yandex360UserService;

	private final PersonRepository personRepository;

	// TODO 2023-10-12: Maybe do the inverse? I.e. fetch all from Yandex first, than map to our Persons.
	//                  Fetching from Yandex is much slower than fetching from database.
	@Override
	public int sync() {
		AtomicInteger count = new AtomicInteger();
		Collection<Person> people = personRepository.findAll();
		for (Person person : people) {
			if (isValid(person.getExternalUserId())) {
				try {
					yandex360UserService.getYandexUser(person.getExternalUserId());
				} catch (Exception e) {
					log.error("Error caught", e);
					log.warn("Person with id {} has yandexUserId = {}, but no matching user was found in yandex360",
							 person.getId(),
							 person.getExternalUserId());

					yandex360UserService.findByEmail(person.getUsername()).ifPresentOrElse(
							response -> {
								person.setExternalUserId(response.getId());
								count.incrementAndGet();
							},
							() -> person.setExternalUserId(null)
					);

					personRepository.save(person);
				}
			} else {
				try {
					yandex360UserService.findByEmail(person.getUsername()).ifPresent(response -> {
						person.setExternalUserId(response.getId());
						count.incrementAndGet();
						personRepository.save(person);
					});
				} catch (Exception e) {
					log.error("Error caught", e);
				}
			}
		}

		return count.get();
	}

}
