package ru.loylabs.portal.service.yandex.dto;

import java.io.Serial;
import java.io.Serializable;
import java.util.function.Function;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.ToString;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import com.fasterxml.jackson.annotation.JsonIgnore;

@NoArgsConstructor
@ToString
@EqualsAndHashCode
public abstract class Yandex360AbstractPageResponse<T> implements Serializable, Page<T> {

	@Serial
	private static final long serialVersionUID = 1L;

	@Getter
	protected Integer page;

	@Getter
	protected Integer perPage;

	@Getter
	@Setter
	protected Integer pages;

	@Getter
	@Setter
	protected Integer total;

	@JsonIgnore
	@ToString.Exclude
	@EqualsAndHashCode.Exclude
	private Pageable pageable = null;

	public Yandex360AbstractPageResponse(Integer page, Integer perPage, Integer pages, Integer total) {
		this.page = page;
		this.perPage = perPage;
		initPageable();
		this.pages = pages;
		this.total = total;
	}

	public void setPage(Integer page) {
		this.page = page;
		initPageable();
	}

	public void setPerPage(Integer perPage) {
		this.perPage = perPage;
		initPageable();
	}

	@JsonIgnore
	@Override
	public int getNumber() {
		return page - 1;
	}

	@JsonIgnore
	@Override
	public int getSize() {
		return perPage;
	}

	@JsonIgnore
	@Override
	public int getNumberOfElements() {
		return total;
	}

	@JsonIgnore
	@Override
	public boolean hasPrevious() {
		return getNumber() > 0;
	}

	@JsonIgnore
	@Override
	public boolean isFirst() {
		return !hasPrevious();
	}

	@JsonIgnore
	@Override
	public boolean isLast() {
		return !hasNext();
	}

	@JsonIgnore
	@Override
	public Pageable nextPageable() {
		return hasNext() ? getPageable().next() : Pageable.unpaged();
	}

	@JsonIgnore
	@Override
	public Pageable previousPageable() {
		return hasPrevious() ? getPageable().previousOrFirst() : Pageable.unpaged();
	}

	@JsonIgnore
	@Override
	public Pageable getPageable() {
		if (pageable == null)
			initPageable();
		return pageable == null ? Pageable.unpaged() : pageable;
	}

	@JsonIgnore
	@Override
	public Sort getSort() {
		return Sort.unsorted();
	}

	/**
	 * By default not supported, may be overridden in extending classes
	 *
	 * @throws UnsupportedOperationException will throw this unless specific implementation overrides this method
	 */
	@JsonIgnore
	@Override
	public <U> Page<U> map(Function<? super T, ? extends U> converter) {
		throw new UnsupportedOperationException("Mapping not supported yet");
	}

	protected synchronized void initPageable() {
		if (arePageableValuesPresent())
			this.pageable = PageRequest.of(page - 1, perPage);
	}

	@JsonIgnore
	protected boolean arePageableValuesPresent() {
		return page != null && perPage != null;
	}

}
