package ru.loylabs.portal.utility;

import java.util.*;

import static java.util.Objects.nonNull;

public enum CollectionUtils {

	;

	/**
	 * Checks {@link Collection} validity.
	 *
	 * @param collection {@link Collection} instance to check
	 *
	 * @return {@literal true} if {@code collection} provided is both non-null and not empty, {@literal false}
	 * otherwise
	 */
	public static boolean isValid(Collection<?> collection) {
		return nonNull(collection) && !collection.isEmpty();
	}

	public static boolean isValid(Object[] array) {
		return nonNull(array) && (array.length > 0);
	}

	/**
	 * Checks {@link Map} validity.
	 *
	 * @param map {@link Map} instance to check
	 *
	 * @return {@literal true} if {@code map} provided is both non-null and not empty, {@literal false} otherwise
	 */
	public static boolean isValid(Map<?, ?> map) {
		return nonNull(map) && !map.isEmpty();
	}

	/**
	 * Checks {@link Collection} invalidity.
	 *
	 * @param collection {@link Collection} instance to check
	 *
	 * @return {@literal true} if {@code collection} provided is either null or empty, {@literal false} otherwise
	 */
	public static boolean isInvalid(Collection<?> collection) {
		return !isValid(collection);
	}

	/**
	 * Checks {@link Map} invalidity.
	 *
	 * @param map {@link Map} instance to check
	 *
	 * @return {@literal true} if {@code map} provided is either null or empty, {@literal false} otherwise
	 */
	public static boolean isInvalid(Map<?, ?> map) {
		return !isValid(map);
	}

	/**
	 * Returns {@link Optional} of value at specified {@code index}. If {@code list} is {@literal null},
	 * {@link IndexOutOfBoundsException} would be thrown, or {@code index} is otherwise invalid, returns empty
	 * Optional.
	 *
	 * @param list  {@link List} instance to get value from.
	 * @param index desired index
	 * @param <T>   list type
	 *
	 * @return Optional with value from list, if it is present, otherwise empty Optional
	 */
	public static <T> Optional<T> safeGet(List<T> list, int index) {
		if (list == null) return Optional.empty();
		return index >= 0 && index < list.size()
			   ? Optional.ofNullable(list.get(index))
			   : Optional.empty();
	}

}
