package ru.loylabs.portal.utility;

import static ru.loylabs.portal.enums.SettingsTagType.IMG_EMAIL_LOGIN;
import static ru.loylabs.portal.enums.SettingsTagType.IMG_EMAIL_LOGO;
import static ru.loylabs.portal.utility.StringUtils.isValid;

import java.util.EnumSet;
import java.util.Map;
import java.util.Set;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.Resource;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.enums.SettingsTagType;

@Component
public class EmailImageUtils {

	public static final String CID_PREFIX = "cid:";

	private static final String IMG_EMAIL_LOGO_CID = "img_email_logo";
	private static final String IMG_EMAIL_LOGIN_CID = "img_email_login";

	private static final Map<SettingsTagType, String> IMG_TAG_TYPES_TO_CONTENT_IDS = Map.of(
			IMG_EMAIL_LOGO, IMG_EMAIL_LOGO_CID,
			IMG_EMAIL_LOGIN, IMG_EMAIL_LOGIN_CID
	);

	private static final EnumSet<SettingsTagType> IMG_TAG_TYPES = EnumSet.copyOf(IMG_TAG_TYPES_TO_CONTENT_IDS.keySet());

	private final Map<String, Resource> contentIdsToClassPathResource;

	public EmailImageUtils(@Value("classpath:images/emailLogo.png") Resource emailLogo,
						   @Value("classpath:images/emailLogin.png") Resource emailLogin) {
		this.contentIdsToClassPathResource = Map.of(
				IMG_EMAIL_LOGO_CID, emailLogo,
				IMG_EMAIL_LOGIN_CID, emailLogin
		);
	}

	public static String getContentId(SettingsTagType imgTagType) {
		if (imgTagType.name().contains("IMG_"))
			return IMG_TAG_TYPES_TO_CONTENT_IDS.get(imgTagType);
		else throw new IllegalArgumentException("Tag provided is not and 'IMG_' tag");
	}

	public static Set<SettingsTagType> getImgTagTypes() {
		return IMG_TAG_TYPES;
	}

	public EmailEmbeddableFile getEmbeddableFile(SettingsTagType imgTagType) {
		if (imgTagType.name().contains("IMG_"))
			return getEmbeddableFile(IMG_TAG_TYPES_TO_CONTENT_IDS.get(imgTagType));
		else throw new IllegalArgumentException("Tag provided is not and 'IMG_' tag");
	}

	public EmailEmbeddableFile getEmbeddableFile(String contentId) {
		return isValid(contentId) && contentIdsToClassPathResource.containsKey(contentId)
			   ? new EmailEmbeddableFile(contentId, contentIdsToClassPathResource.get(contentId))
			   : null;
	}

}
