create type gender as enum ('MALE', 'FEMALE');
create type department as enum ('DEVELOPMENT', 'SALES', 'HR', 'MARKETING', 'MANAGEMENT');
create type title as enum ('DEVELOPER', 'TESTER', 'ENGINEER', 'DESIGNER', 'SALESMAN', 'ACCOUNTANT', 'HR', 'MANAGER');
create type grade as enum ('STUDENT', 'JUNIOR', 'MIDDLE', 'SENIOR', 'NA');
create type attachment_type as enum ('IMAGE', 'DOCUMENT', 'MEDIA', 'FILE');
create type kb_category as enum ('VACATION', 'INFO', 'HIERARCHY', 'RETIREMENT', 'DISMISSAL');
create type record_type as enum ('FEED', 'COMMUNITY', 'COMMENT', 'IDEA');
create type idea_status as enum ('NEW', 'APPROVED', 'DISMISSED');
create type community_role as enum ('ADMIN', 'OWNER', 'MEMBER');
create type credential_role as enum ('ADMIN', 'EDITOR', 'USER');
create type credential_permission as enum ('IDEA_VEW_ALL_IDEAS', 'IDEA_VIEW_ONE_IDEA', 'IDEA_ACCEPT_IDEA', 'IDEA_REJECT_IDEA', 'IDEA_CREATE_IDEA', 'IDEA_VIEW_IDEA_COMMENTS', 'IDEA_MAKE_IDEA_COMMENT', 'GROUP_VIEW_ALL_GROUPS', 'GROUP_VIEW_ONE_GROUP', 'GROUP_CREATE_GROUP', 'GROUP_DELETE_GROUP', 'GROUP_ADD_GROUP_MEMBERS', 'GROUP_REMOVE_GROUP_MEMBERS', 'GROUP_SEND_MESSAGE', 'GROUP_SET_GROUP_AVATAR', 'FEED_VIEW_ALL_NOTES', 'FEED_VIEW_ONE_NOTE', 'FEED_CREATE_NOTE', 'FEED_VIEW_NOTE_COMMENTS', 'FEED_MAKE_NOTE_COMMENT', 'EMPLOYEE_VIEW_ALL_PERSONS', 'EMPLOYEE_VIEW_ONE_PERSON', 'EMPLOYEE_ADD_PERSON', 'EMPLOYEE_VIEW_CHANGE_PERSON', 'EMPLOYEE_CHANGE_PERSON', 'EMPLOYEE_BLOCK_PERSON', 'EMPLOYEE_UNBLOCK_PERSON', 'EMPLOYEE_CHANGE_PERSON_AVATAR', 'KNOWLEDGE_BASE_VIEW_ALL_SECTIONS', 'KNOWLEDGE_BASE_VIEW_ONE_SECTION', 'KNOWLEDGE_BASE_ADD_SECTION', 'KNOWLEDGE_BASE_CHANGE_SECTION', 'KNOWLEDGE_BASE_VIEW_ONE_ARTICLE', 'KNOWLEDGE_BASE_ADD_ARTICLE', 'KNOWLEDGE_BASE_CHANGE_ARTICLE', 'KNOWLEDGE_BASE_DELETE_ARTICLE');

CREATE EXTENSION IF NOT EXISTS "uuid-ossp";

create table if not exists job
(
    id         uuid primary key default uuid_generate_v4(),
    department department not null,
    title      title      not null,
    grade      grade      not null
);

create table if not exists contact
(
    id        uuid primary key default uuid_generate_v4(),
    phone     varchar unique,
    email     varchar unique,
    telegram  varchar unique,
    skype     varchar unique,
    linkedin  varchar unique,
    github    varchar unique,
    vk        varchar unique,
    instagram varchar unique
);

create table if not exists security_role
(
    id   uuid primary key default uuid_generate_v4(),
    role credential_role not null unique
);

create table if not exists security_permission
(
    id         uuid primary key default uuid_generate_v4(),
    permission credential_permission not null unique
);

create table if not exists role_permission
(
    role_id       uuid not null references security_role (id),
    permission_id uuid not null references security_permission (id),
    unique (role_id, permission_id)
);

create table if not exists attachment
(
    id              uuid primary key default uuid_generate_v4(),
    attachment_type attachment_type not null,
    name            varchar         not null,
    extension       varchar         not null,
    size            bigint          not null,
    location        varchar         not null
);

create table if not exists person
(
    id            uuid primary key default uuid_generate_v4(),
    username      varchar   not null unique,
    password      varchar   not null,
    name          varchar   not null,
    surname       varchar   not null,
    patronymic    varchar,
    dob           timestamp not null,
    gender        gender    not null,
    job_id        uuid      not null references job (id),
    city          varchar   not null,
    description   varchar,
    contact_id    uuid      not null references contact (id),
    hired         timestamp not null,
    fired         timestamp,
    blocked       boolean          default false,
    role_id       uuid      not null references security_role (id),
    attachment_id uuid references attachment (id)
);

create table if not exists achievement
(
    id              uuid primary key default uuid_generate_v4(),
    person_id       uuid    not null references person (id),
    name            varchar not null,
    description     varchar not null,
    author_id       uuid    not null references person (id),
    supervisor_id   uuid    not null references person (id),
    done            boolean not null default false,
    approve_message varchar,
    archived        boolean not null default false
);

create table if not exists task
(
    id             uuid primary key default uuid_generate_v4(),
    achievement_id uuid    not null references achievement (id),
    name           varchar not null,
    done           boolean not null default false
);

create table if not exists kb_section
(
    id   uuid primary key default uuid_generate_v4(),
    name varchar not null unique
);

create table if not exists kb_article
(
    id         uuid primary key default uuid_generate_v4(),
    name       varchar not null,
    content    varchar not null,
    section_id uuid    not null references kb_section (id)
);

create table if not exists community
(
    id            uuid primary key default uuid_generate_v4(),
    name          varchar not null,
    description   varchar not null,
    attachment_id uuid references attachment (id)
);

create table if not exists reaction
(
    id            uuid primary key default uuid_generate_v4(),
    like_count    int              default 0,
    dislike_count int              default 0,
    emoji         varchar
);

create table if not exists record
(
    id          uuid primary key default uuid_generate_v4(),
    author_id   uuid        not null references person (id),
    date        timestamp   not null,
    header      varchar     not null,
    content     varchar     not null,
    record_type record_type not null,
    reaction_id uuid        not null references reaction (id)
);

create table if not exists record_comment
(
    parent_record_id  uuid references record (id),
    comment_record_id uuid references record (id)
);

create table if not exists idea
(
    id       uuid primary key references record (id),
    status   idea_status not null,
    response varchar
);

create table if not exists record_community
(
    record_id    uuid references record (id),
    community_id uuid references community (id)
);

create table if not exists stories
(
    id        uuid primary key default uuid_generate_v4(),
    author_id uuid      not null references person (id),
    date      timestamp not null
);

create table if not exists story
(
    id          uuid primary key default uuid_generate_v4(),
    stories_id  uuid    not null references stories (id),
    header      varchar not null,
    content     varchar not null,
    reaction_id uuid references reaction (id)
);

create table if not exists community_person_role
(
    id             uuid primary key default uuid_generate_v4(),
    community_id   uuid           not null references community (id),
    person_id      uuid           not null references person (id),
    community_role community_role not null,
    unique (community_id, person_id, community_role)
);

create table if not exists task_attachment
(
    task_id       uuid not null references task (id),
    attachment_id uuid not null references attachment (id),
    unique (task_id, attachment_id)
);

create table if not exists kb_article_attachment
(
    kb_article_id uuid not null references kb_article (id),
    attachment_id uuid not null references attachment (id),
    unique (kb_article_id, attachment_id)
);

create table if not exists record_attachment
(
    record_id     uuid not null references record (id),
    attachment_id uuid not null references attachment (id),
    unique (record_id, attachment_id)
);

create table if not exists story_attachment
(
    story_id      uuid not null references story (id),
    attachment_id uuid not null references attachment (id),
    unique (story_id, attachment_id)
);
