package ru.loylabs.portal.configuration.container;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.DisposableBean;
import org.springframework.beans.factory.InitializingBean;
import org.testcontainers.containers.GenericContainer;
import org.testcontainers.containers.output.Slf4jLogConsumer;

public class RedisTestContainer implements InitializingBean, DisposableBean {

    private GenericContainer<?> redisContainer;
    private static final Logger log = LoggerFactory.getLogger(RedisTestContainer.class);

    @Override
    public void destroy() {
        if (redisContainer != null && redisContainer.isRunning()) {
            redisContainer.close();
        }
    }

    @Override
    public void afterPropertiesSet() {
        if (null == redisContainer) {
            redisContainer =
                new GenericContainer("redis:7.2").withExposedPorts(6378)
                        .withLogConsumer(new Slf4jLogConsumer(log))
                        .withReuse(true);
        }
        if (!redisContainer.isRunning()) {
            redisContainer.start();
        }
    }

    public GenericContainer<?> getRedisContainer() {
        return redisContainer;
    }
}
