package ru.loylabs.portal.configuration.container.factory;

import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.config.ConfigurableListableBeanFactory;
import org.springframework.boot.test.util.TestPropertyValues;
import org.springframework.core.annotation.AnnotatedElementUtils;
import org.springframework.test.context.ContextConfigurationAttributes;
import org.springframework.test.context.ContextCustomizer;
import org.springframework.test.context.ContextCustomizerFactory;
import ru.loylabs.portal.configuration.annotation.EmbeddedRedis;
import ru.loylabs.portal.configuration.container.RedisTestContainer;

import java.util.List;

@Slf4j
public class RedisTestContainersSpringContextCustomizerFactory implements ContextCustomizerFactory {

	private static RedisTestContainer redisBean;

	@Override
	public ContextCustomizer createContextCustomizer(@NotNull Class<?> testClass, @NotNull List<ContextConfigurationAttributes> configAttributes) {
		return (context, mergedConfig) -> {
			ConfigurableListableBeanFactory beanFactory = context.getBeanFactory();
			TestPropertyValues testValues = TestPropertyValues.empty();
			EmbeddedRedis redisAnnotation = AnnotatedElementUtils.findMergedAnnotation(testClass, EmbeddedRedis.class);
			if (redisAnnotation != null) {
				log.debug("detected the EmbeddedRedis annotation on class {}", testClass.getName());
				log.info("Warming up the redis database");
				if (redisBean == null) {
					redisBean = beanFactory.createBean(RedisTestContainer.class);
					beanFactory.registerSingleton(RedisTestContainer.class.getName(), redisBean);
				}
				testValues =
						testValues
								.and("spring.redis.host=" + redisBean.getRedisContainer().getHost())
								.and("spring.redis.port=" + redisBean.getRedisContainer().getMappedPort(6378));
			}
			testValues.applyTo(context);
		};
	}
}
