package ru.loylabs.portal.configuration.container.factory;

import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.config.ConfigurableListableBeanFactory;
import org.springframework.boot.test.util.TestPropertyValues;
import org.springframework.core.annotation.AnnotatedElementUtils;
import org.springframework.test.context.ContextConfigurationAttributes;
import org.springframework.test.context.ContextCustomizer;
import org.springframework.test.context.ContextCustomizerFactory;
import ru.loylabs.portal.configuration.annotation.EmbeddedSQL;
import ru.loylabs.portal.configuration.container.PostgreSqlTestContainer;
import ru.loylabs.portal.configuration.container.SqlTestContainer;

import java.util.List;

@Slf4j
public class SqlTestContainersSpringContextCustomizerFactory implements ContextCustomizerFactory {


	private static SqlTestContainer container;

	@Override
	public ContextCustomizer createContextCustomizer(@NotNull Class<?> testClass, @NotNull List<ContextConfigurationAttributes> configAttributes) {
		return (context, mergedConfig) -> {
			ConfigurableListableBeanFactory beanFactory = context.getBeanFactory();
			TestPropertyValues testValues = TestPropertyValues.empty();
			EmbeddedSQL sqlAnnotation = AnnotatedElementUtils.findMergedAnnotation(testClass, EmbeddedSQL.class);
			if (sqlAnnotation != null) {
				log.debug("detected the EmbeddedSQL annotation on class {}", testClass.getName());
				log.info("Warming up the sql database");
				if (container == null) {
						Class<? extends SqlTestContainer> containerClass = PostgreSqlTestContainer.class;
						container = beanFactory.createBean(containerClass);
						beanFactory.registerSingleton(containerClass.getName(), container);
				}
				testValues = testValues.and("spring.datasource.url=" + container.getTestContainer().getJdbcUrl() + "");
				testValues = testValues.and("spring.datasource.username=" + container.getTestContainer().getUsername());
				testValues = testValues.and("spring.datasource.password=" + container.getTestContainer().getPassword());
			}
			testValues.applyTo(context);
		};
	}
}
