package ru.loylabs.portal.integration;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.test.annotation.Commit;
import org.springframework.test.web.servlet.MockMvc;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.integration.util.TokenProvider;
import ru.loylabs.portal.integration.util.data.JobTestData;
import ru.loylabs.portal.integration.util.data.PersonTestData;
import ru.loylabs.portal.repository.DepartmentRepository;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.repository.SecurityRoleRepository;
import ru.loylabs.portal.repository.TitleRepository;
import ru.loylabs.portal.utility.StaticMessageSource;

import javax.annotation.PostConstruct;
import java.util.List;

import static ru.loylabs.portal.integration.util.data.JobTestData.generateTitle;
import static ru.loylabs.portal.integration.util.data.JobTestData.randomJob;

@AutoConfigureMockMvc
public abstract class IntegrationTestBaseMVC extends IntegrationTestBase {

	public final static String ARGUMENT_INDEX = " Arguments set: {index}";

	@Autowired
	protected MockMvc mockMvc;
	@Autowired
	protected TokenProvider tokenProvider;
	@Autowired
	protected StaticMessageSource messageSource;
	@Autowired
	protected PersonRepository personRepository;
	@Autowired
	protected SecurityRoleRepository roleRepository;
	@Autowired
	protected DepartmentRepository departmentRepository;
	@Autowired
	protected TitleRepository titleRepository;
	@Autowired
	private PasswordEncoder passwordEncoder;

	private static boolean initialized = false;

	protected static Person admin;
	protected static Person editor;
	protected static Person user;

	@PostConstruct
	@Commit
	private void initData() {
		if (!initialized) {
			initTitle();
			initDepartment();
			admin = initPerson("ADMIN");
			editor = initPerson("EDITOR");
			user = initPerson("USER");
			initialized = true;
		}
	}

	private void initTitle() {
		titleRepository.saveAll(List.of(
				generateTitle(),
				generateTitle(),
				generateTitle()));
	}

	private void initDepartment() {
		departmentRepository.saveAll(List.of(
				JobTestData.generateDepartment(),
				JobTestData.generateDepartment(),
				JobTestData.generateDepartment()
		));
	}

	private Person initPerson(String role) {
		var person = PersonTestData.initPersonWithRoleFromBD(role,roleRepository,passwordEncoder);
		person.setJob(randomJob(titleRepository,departmentRepository));
		return personRepository.save(person);
	}
}
