package ru.loylabs.portal.integration.util;

import lombok.Getter;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;


public class JsonResponse {
	private static final String BEGIN_SYMBOL = "$.";
	private static final String SEPARATE_SYMBOL = ".";

	public static final String ID = "id";
	public static final String NAME = "name";
	public static final String TOTAL_ITEMS = "totalItems";
	public static final String ERROR_MESSAGE = "errorMessage";
	@Getter
	private final Map<String, Object> values;

	private JsonResponse(Map<String, Object> values) {
		this.values = values;
	}

	public static JsonResponseBuilder expectedFieldsBuilder() {
		return new JsonResponseBuilder();
	}

	public static class JsonResponseBuilder {
		private Map<String, Object> values;


		private Map<String, Object> getValues() {
			if (values == null) {
				values = new HashMap<>();
			}
			return values;
		}

		public JsonResponseBuilder expected(String field, Object value) {
			return expected(null, field, value);
		}

		public JsonResponseBuilder expected(String parentField, String field, Object value) {
			field = BEGIN_SYMBOL + (parentField != null ? parentField + SEPARATE_SYMBOL : "") + field;
			getValues().put(field, value);
			return this;
		}

		public JsonResponseBuilder notEmptyField(String fieldName) {
			return expected(fieldName, new MvcResultAssert.NotEmptyField());
		}
		public JsonResponseBuilder notEmptyField(String parentFieldName, String fieldName) {
			return expected(parentFieldName,fieldName, new MvcResultAssert.NotEmptyField());
		}

		public JsonResponseBuilder id(UUID id) {
			return expected(ID, id.toString());
		}

		public JsonResponseBuilder name(String name) {
			return expected(NAME, name);
		}

		public JsonResponseBuilder totalItems(Integer totalItems) {
			return expected(TOTAL_ITEMS, totalItems);
		}

		public JsonResponseBuilder errorMessage(String containingString) {
			return expected(ERROR_MESSAGE, containingString);
		}

		public JsonResponse build() {
			return new JsonResponse(values);
		}

	}
}

