package ru.loylabs.portal.integration.util;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import ru.loylabs.portal.config.jwt.JwtProvider;
import ru.loylabs.portal.repository.PersonRepository;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

@Component
public class TokenProvider {
    @Autowired
    private JwtProvider jwtProvider;
    @Autowired
    private PersonRepository personRepository;
    private final Map<UUID, String> tokens = new HashMap<>();

    public String getPersonalTokenById(UUID personId) {
        return tokens.containsKey(personId) ? tokens.get(personId) : initPersonToken(personId);
    }

    public String initPersonToken(UUID personId){
       var person = personRepository.findById(personId)
               .orElseThrow(() -> new RuntimeException("person with id %s not found".formatted(personId)));
       var token = jwtProvider.generateAccessToken(person);
       tokens.put(personId,token);
       return token;
    }

}
