package ru.loylabs.portal.integration.util.data;

import org.instancio.Instancio;
import ru.loylabs.portal.entity.Department;
import ru.loylabs.portal.entity.Job;
import ru.loylabs.portal.entity.Title;
import ru.loylabs.portal.presentation.request.*;
import ru.loylabs.portal.repository.DepartmentRepository;
import ru.loylabs.portal.repository.TitleRepository;

import static org.instancio.Select.field;
import static ru.loylabs.portal.integration.util.TestUtils.randomFromBD;

public class JobTestData {

	public static Job randomJob(TitleRepository titleRepository, DepartmentRepository departmentRepository) {
		var job = new Job();
		job.setTitle(randomFromBD(titleRepository));
		job.setDepartment(randomFromBD(departmentRepository));
		return job;
	}

	public static Job createJobWithRandomTitle(TitleRepository titleRepository, Department department) {
		var job = new Job();
		job.setTitle(randomFromBD(titleRepository));
		job.setDepartment(department);
		return job;
	}

	public static Job createJobWithRandomDepartment(DepartmentRepository departmentRepository, Title title) {
		var job = new Job();
		job.setDepartment(randomFromBD(departmentRepository));
		job.setTitle(title);
		return job;
	}

	public static Title generateTitle() {
		return Instancio.of(Title.class).create();
	}

	public static Department generateDepartment() {
		return Instancio.of(Department.class).ignore(field(Department::getId)).ignore(field(Department::getLeader)).create();
	}

	public static CreateJobRequest generateJobRequest(DepartmentRepository departmentRepository, TitleRepository titleRepository) {
		var title = titleRepository.findAll().stream().findAny().orElseThrow();
		var department = departmentRepository.findAll().stream().findAny().orElseThrow();
		return new CreateJobRequest(department.getName(), title.getName(), "NA");
	}

	public static CreateTitleRequest generateCreateTitleRequest() {
		return Instancio.of(CreateTitleRequest.class).create();
	}

	public static UpdateTitleRequest generateUpdateTitleRequest() {
		return Instancio.of(UpdateTitleRequest.class).create();
	}

	public static CreateDepartmentRequest generateCreateDepartmentRequest(){
		return Instancio.of(CreateDepartmentRequest.class).ignore(field(CreateDepartmentRequest::getLeaderId)).create();
	}

	public static UpdateDepartmentRequest generateUpdateDepartmentRequest(){
		return Instancio.of(UpdateDepartmentRequest.class).ignore(field(UpdateDepartmentRequest::getLeaderId)).create();
	}
}
