package ru.loylabs.portal.integration.util.data;

import org.instancio.Instancio;
import org.springframework.security.crypto.password.PasswordEncoder;
import ru.loylabs.portal.entity.Contact;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.presentation.request.CreatePersonRequest;
import ru.loylabs.portal.repository.CityRepository;
import ru.loylabs.portal.repository.DepartmentRepository;
import ru.loylabs.portal.repository.SecurityRoleRepository;
import ru.loylabs.portal.repository.TitleRepository;

import java.time.LocalDate;
import java.util.UUID;

import static org.instancio.Select.field;
import static ru.loylabs.portal.integration.util.TestUtils.randomFromBD;
import static ru.loylabs.portal.integration.util.data.JobTestData.generateJobRequest;

public class PersonTestData {

	public static Person initPersonWithRoleFromBD(String role,SecurityRoleRepository repository, PasswordEncoder encoder){
		var person = generateNotBlockedPerson();
		person.setAvatar(AttachmentTestData.initPictureAttachment());
		person.setBackground(AttachmentTestData.initPictureAttachment());
		person.setRole(repository.findByRole(role).orElseThrow());
		person.setPassword(encoder.encode("HPCibozn"));
		return person;
	}

	public static Person generateNotBlockedPerson() {
		return Instancio.of(Person.class)
				.set(field(Person::isBlocked), false)
				.ignore(field(Person::getCity))
				.set(field(Person::getContact),Instancio.of(Contact.class).ignore(field(Contact::getId)).create())
				.ignore(field(Person::getId))
				.ignore(field(Person::getRole))
				.ignore(field(Person::getPersonAudit))
				.ignore(field(Person::getAvatar))
				.ignore(field(Person::getBackground))
				.ignore(field(Person::getJob))
				.create();
	}

	public static Person generatePerson() {
		return Instancio.of(Person.class)
				.ignore(field(Person::getCity))
				.set(field(Person::getContact),Instancio.of(Contact.class).ignore(field(Contact::getId)).create())
				.ignore(field(Person::getJob))
				.ignore(field(Person::getId))
				.ignore(field(Person::getPersonAudit))
				.create();
	}

	public static Person generatePerson(UUID idPerson) {
		return Instancio.of(Person.class)
				.ignore(field(Person::getCity))
				.set(field(Person::getContact),Instancio.of(Contact.class).ignore(field(Contact::getId)).create())
				.set(field(Person::getId), idPerson)
				.ignore(field(Person::getJob))
				.ignore(field(Person::getPersonAudit))
				.create();
	}

	public static CreatePersonRequest generateCreatePersonRequest(DepartmentRepository departmentRep, TitleRepository titleRep, CityRepository cityRep) {
		return Instancio.of(CreatePersonRequest.class)
				.set(field(CreatePersonRequest::getPassword),"123Asd23zxc3-")
				.set(field(CreatePersonRequest::getDob), LocalDate.of(1990, 1, 1))
				.set(field(CreatePersonRequest::getGender),"MALE")
				.set(field(CreatePersonRequest::getRole), "USER")
				.set(field(CreatePersonRequest::getJob), generateJobRequest(departmentRep, titleRep))
				.set(field(CreatePersonRequest::getCityId),randomFromBD(cityRep).getId())
				.create();
	}
}
