package ru.loylabs.portal.integration.util.data;

import org.instancio.Instancio;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.ReviewPersonSkill;
import ru.loylabs.portal.entity.ReviewPersonSkillRating;
import ru.loylabs.portal.entity.Reviewers;
import ru.loylabs.portal.entity.ReviewersId;
import ru.loylabs.portal.entity.Skill;
import ru.loylabs.portal.presentation.request.CreateReviewPersonSkill;
import ru.loylabs.portal.presentation.request.CreateReviewPersonSkillRating;
import ru.loylabs.portal.presentation.request.UpdateReviewPersonSkill;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.UUID;
import java.util.stream.Collectors;

import static org.instancio.Select.field;

public class ReviewTestData {
	public static ReviewPersonSkill generateReviewPersonSkill() {
		return Instancio.of(ReviewPersonSkill.class)
				.ignore(field(ReviewPersonSkill::getReviewers))
				.create();
	}

	public static ReviewPersonSkill generateReviewPersonSkill(UUID id, Skill skill, Person owner) {
		return Instancio.of(ReviewPersonSkill.class)
				.set(field(ReviewPersonSkill::getId), id)
				.set(field(ReviewPersonSkill::getSkill), skill)
				.set(field(ReviewPersonSkill::getOwner), owner)
				.ignore(field(ReviewPersonSkill::getReviewers))
				.create();
	}

	public static ReviewPersonSkill generateReviewPersonSkill(UUID id, Person owner, Skill skill, List<Reviewers> reviewers) {
		return Instancio.of(ReviewPersonSkill.class)
				.set(field(ReviewPersonSkill::getId), id)
				.set(field(ReviewPersonSkill::getSkill), skill)
				.set(field(ReviewPersonSkill::getOwner), owner)
				.set(field(ReviewPersonSkill::getReviewers), new ArrayList<>(reviewers))
				.create();
	}

	public static ReviewPersonSkill generateReviewPersonSkill(UUID id,  Person owner) {
		return Instancio.of(ReviewPersonSkill.class)
				.set(field(ReviewPersonSkill::getId), id)
				.set(field(ReviewPersonSkill::getOwner), owner)
				.ignore(field(ReviewPersonSkill::getReviewers))
				.create();
	}

	public static CreateReviewPersonSkill generateCreateReviewPersonSkill() {
		return Instancio.of(CreateReviewPersonSkill.class)
				.ignore(field(CreateReviewPersonSkill::getReviewersId))
				.create();
	}

	public static CreateReviewPersonSkill generateCreateReviewPersonSkill(ReviewPersonSkill review) {
		return Instancio.of(CreateReviewPersonSkill.class)
				.set(field(CreateReviewPersonSkill::getOwnerId), review.getOwner().getId())
				.set(field(CreateReviewPersonSkill::getSkillId), review.getSkill().getId())
				.set(field(CreateReviewPersonSkill::getReviewersId), review.getReviewers().stream().map(r -> r.getReviewer().getId()).collect(Collectors.toSet()))
				.create();
	}

	public static Reviewers generateReviewersSkill() {
		return Instancio.of(Reviewers.class)
				.create();
	}

	public static Reviewers generateReviewersSkill(ReviewPersonSkill review, Person reviewer) {
		return Instancio.of(Reviewers.class)
				.set(field(Reviewers::getReview), review)
				.set(field(Reviewers::getReviewer), reviewer)
				.set(field(Reviewers::getReviewersId), new ReviewersId(reviewer.getId(), review.getId()))
				.set(field(Reviewers::isVoted), false)
				.create();
	}

	public static ReviewPersonSkillRating generateReviewPersonSkillRating(ReviewPersonSkill review, Integer estimation) {
		return Instancio.of(ReviewPersonSkillRating.class)
				.set(field(ReviewPersonSkillRating::getReview), review)
				.set(field(ReviewPersonSkillRating::getRating), estimation)
				.create();
	}

	public static CreateReviewPersonSkillRating generateCreateReviewPersonSkillRating(Integer estimation) {
		return Instancio.of(CreateReviewPersonSkillRating.class)
				.set(field(CreateReviewPersonSkillRating::getRating), estimation)
				.create();
	}

	public static ReviewPersonSkillRating generateReviewPersonSkillRating() {
		return Instancio.of(ReviewPersonSkillRating.class)
				.create();
	}

	public static UpdateReviewPersonSkill generateUpdateReviewPersonSkill() {
		return Instancio.of(UpdateReviewPersonSkill.class)
				.create();
	}

	public static UpdateReviewPersonSkill generateUpdateReviewPersonSkill(Set<UUID> reviewersId) {
		return Instancio.of(UpdateReviewPersonSkill.class)
				.set(field(UpdateReviewPersonSkill::getReviewersId), reviewersId)
				.create();
	}

}
