package ru.loylabs.portal.integration.util.data;

import org.instancio.Instancio;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Reaction;
import ru.loylabs.portal.entity.Story;
import ru.loylabs.portal.entity.StoryGroup;
import ru.loylabs.portal.enums.RecordType;
import ru.loylabs.portal.enums.StoryGroupType;
import ru.loylabs.portal.presentation.request.CreateStoryGroupRequest;
import ru.loylabs.portal.presentation.request.CreateStoryRequest;
import ru.loylabs.portal.presentation.request.UpdateStoryGroupRequest;
import ru.loylabs.portal.presentation.request.UpdateStoryRequest;

import java.time.Instant;
import java.time.LocalDateTime;
import java.util.Set;

import static org.instancio.Select.field;

public class StoryTestData {

	public static StoryGroup generateEmptyStoryGroup() {
		return Instancio.of(StoryGroup.class)
				.set(field(StoryGroup::getUpdateTime), Instant.now())
				.set(field(StoryGroup::getGroupType), StoryGroupType.ADMIN)
				.ignore(field(StoryGroup::getAllStoriesAmount))
				.ignore(field(StoryGroup::getFirstStories))
				.ignore(field(StoryGroup::getStories))
				.create();
	}

	public static StoryGroup generateStoryGroup(Person author) {
		var group = Instancio.of(StoryGroup.class)
				.ignore(field(StoryGroup::getId))
				.set(field(StoryGroup::getAuthor), author)
				.set(field(StoryGroup::getUpdateTime), Instant.now())
				.set(field(StoryGroup::getGroupType), StoryGroupType.ADMIN)
				.ignore(field(StoryGroup::getAllStoriesAmount))
				.ignore(field(StoryGroup::getFirstStories))
				.ignore(field(StoryGroup::getStories))
				.create();
		group.getStories().addAll(Set.of(generateStory(author, group),generateStory(author, group)));
		return group;
	}

	public static Story generateStory(){
		return Instancio.of(Story.class)
				.set(field(Story::getGroup), generateEmptyStoryGroup())
				.set(field(Story::getReaction),Instancio.of(Reaction.class).ignore(field(Reaction::getId)).create())
				.set(field(Story::getDate),Instant.now())
				.set(field(Story::getRecordType), RecordType.STORY)
				.ignore(field(Story::getAttachments))
				.set(field(Story::getExpireTime), LocalDateTime.now().plusDays(5))
				.create();
	}

	public static Story generateStory(Person author, StoryGroup group){
		return Instancio.of(Story.class)
				.set(field(Story::getAuthor),author)
				.set(field(Story::getGroup), group)
				.ignore(field(Story::getComments))
				.ignore(field(Story::getParentRecord))
				.ignore(field(Story::getCommunity))
				.ignore(field(Story::getId))
				.set(field(Story::getReaction),Instancio.of(Reaction.class).ignore(field(Reaction::getId)).create())
				.set(field(Story::getDate),Instant.now())
				.set(field(Story::getRecordType), RecordType.STORY)
				.ignore(field(Story::getAttachments))
				.set(field(Story::getExpireTime), LocalDateTime.now().plusDays(5))
				.create();
	}

	public static CreateStoryGroupRequest generateCreateStoryGroupRequest() {
		return Instancio.of(CreateStoryGroupRequest.class)
				.set(field(CreateStoryGroupRequest::getGroupType), StoryGroupType.ADMIN)
				.ignore(field(CreateStoryGroupRequest::getRequests))
				.create();
	}

	public static UpdateStoryGroupRequest generateUpdateStoryGroupRequest() {
		return Instancio.of(UpdateStoryGroupRequest.class)
				.create();
	}

	public static CreateStoryRequest generateCreateStoryRequest() {
		return Instancio.of(CreateStoryRequest.class)
				.create();
	}

	public static UpdateStoryRequest generateUpdateStoryRequest() {
		return Instancio.of(UpdateStoryRequest.class)
				.create();
	}
}
