package ru.loylabs.portal.unit.service;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;
import ru.loylabs.portal.entity.Person;
import ru.loylabs.portal.entity.Status;
import ru.loylabs.portal.mapper.*;
import ru.loylabs.portal.repository.PersonRepository;
import ru.loylabs.portal.service.PersonServiceImpl;
import ru.loylabs.portal.service.interfaces.StatusService;

import java.util.Optional;
import java.util.UUID;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;
import static ru.loylabs.portal.integration.util.data.PersonTestData.*;
import static ru.loylabs.portal.integration.util.data.StatusTestData.*;

@DisplayName("")
@ExtendWith(MockitoExtension.class)
class PersonServiceImplTest {

    @Mock
    private StatusService statusService;
    @Mock
    private PersonRepository personRepository;
    @Spy
    private PersonMapper personMapper = new PersonMapperImpl();
    @InjectMocks
    private PersonServiceImpl personService;

    private Person person;
    private Status status;

    @BeforeEach
    void setUp() {
        person = generatePerson(UUID.randomUUID());
        status = generateStatus();
    }

    @Test
    @DisplayName("Test update status")
    void testUpdateStatus() {
        doReturn(Optional.of(person)).when(personRepository).findById(person.getId());
        doReturn(status).when(statusService).getStatus(status.getId());
        doReturn(person).when(personRepository).save(person);

        var actual = personService.updateStatus(person.getId(), status.getId());
        assertThat(actual.getStatus()).isEqualTo(status);
    }

    @Test
    @DisplayName("Test delete status")
    void testDeleteStatus() {
        doReturn(Optional.of(person)).when(personRepository).findById(person.getId());
        doReturn(person).when(personRepository).save(person);

        var actual = personService.deleteStatus(person.getId());
        assertThat(actual.getStatus()).isNull();
    }
}