package ru.loylabs.portal.unit.service.story;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;

import ru.loylabs.portal.service.interfaces.StoriesSchedulingService;
import ru.loylabs.portal.service.story.StoriesSchedulingServiceImpl;
import ru.loylabs.portal.service.story.updater.SystemBirthdaysStoryUpdater;
import ru.loylabs.portal.service.story.updater.SystemNewEmployeeStoryUpdater;
import ru.loylabs.portal.service.story.updater.SystemStoryUpdater;

import java.util.List;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.*;

@ExtendWith(MockitoExtension.class)
@DisplayName("Story scheduling service test")
class StoriesSchedulingServiceImplTest {

    @Mock
    private SystemNewEmployeeStoryUpdater newEmployeeStoryUpdater;
    @Mock
    private SystemBirthdaysStoryUpdater birthdaysStoryUpdater;
    private List<SystemStoryUpdater<?>> systemStoryUpdaters;
    private StoriesSchedulingService storiesSchedulingService;

    @BeforeEach
    public void setUp() {
        systemStoryUpdaters = List.of(birthdaysStoryUpdater, newEmployeeStoryUpdater);
        storiesSchedulingService = new StoriesSchedulingServiceImpl(systemStoryUpdaters);
    }

    @Test
    public void testClearOutdatedStories() {
        doReturn(1).when(birthdaysStoryUpdater).clearOutdatedStories();
        doReturn(1).when(newEmployeeStoryUpdater).clearOutdatedStories();

        int actual = storiesSchedulingService.clearOutdatedStories();

        verify(birthdaysStoryUpdater).clearOutdatedStories();
        verify(newEmployeeStoryUpdater).clearOutdatedStories();

        assertThat(actual).isEqualTo(2);
    }

    @Test
    public void testRefreshSystemStories() {
        doReturn(1).when(birthdaysStoryUpdater).refreshSystemGroup();
        doReturn(1).when(newEmployeeStoryUpdater).refreshSystemGroup();

        int actual = storiesSchedulingService.refreshSystemStories();

        verify(birthdaysStoryUpdater).refreshSystemGroup();
        verify(newEmployeeStoryUpdater).refreshSystemGroup();

        assertThat(actual).isEqualTo(2);
    }
}