import React, { FC, useState, useContext } from "react";
import { useDispatch } from "react-redux";

import PersonAddIcon from "@mui/icons-material/PersonAdd";
import DialogWrapper from "../../common/Modals/DialogWrapper/DialogWrapper";

import CustomButton from "../../common/Buttons/CustomButton/CustomButton";
import CreateUserContent from "./CreateUserContent/CreateUserContent";
import ModalButtons from "../../common/Buttons/ModalButtons/ModalButtons";
import { UserInfo } from "../../../types/UserInfo.types";
import { personController } from "../../../services/person.controller";
import { profilesInitial } from "../../../actions/profiles";
import { textSnackbars } from "../../common/Snackbars/Snackbars";
import { AppContext } from "../../shared/AppContextProvider";
import { roles } from "../../../constants/role";
import { CompanyContext } from "../CompanyContext/CompanyContextProvider";

const initialUserInfo = {
  email: "",
  surname: "",
  name: "",
  patronymic: "",
  jobTitle: "",
  dob: "",
  department: "",
  role: "",
  gender: "",
  city: { id: "", name: "" },
};

export const CreateUser: FC = () => {
  const dispatch = useDispatch();
  const {
    searchStatus,
    handleSnackbar,
    setTotalRecords,
    setCurrentPage,
    setSortingState,
  } = useContext(CompanyContext);
  const { user } = useContext(AppContext);
  const isAvailableRole = user.role !== roles.user;

  const [openModal, setOpenModal] = useState<boolean>(false);
  const handleModal = () => setOpenModal(!openModal);

  const [userInfo, setUserInfo] = useState<UserInfo>(initialUserInfo);

  const handleCancelButton = () => {
    setUserInfo(initialUserInfo);
    handleModal();
  };

  const handleSendButton = () => {
    personController
      .addPerson(userInfo)
      .then(() => {
        personController.allPersons(searchStatus).then((result) => {
          dispatch(profilesInitial.allProfiles(result.data.items));
          setTotalRecords(result.data.totalItems);
          setCurrentPage(0);
          setSortingState([]);
        });
        handleSnackbar("success", textSnackbars.addNewUser(userInfo.email));
      })
      .then(() => {
        handleCancelButton();
      })
      .catch((error) => {
        const sameEmail = error.response.data.errorCode === 29;
        handleSnackbar(
          "error",
          sameEmail ? "Данный e-mail уже зарегистрирован" : undefined
        );
      });
  };

  const checkFillUserInfo =
    !userInfo.email ||
    !userInfo.surname ||
    !userInfo.name ||
    !userInfo.patronymic ||
    !userInfo.jobTitle ||
    !userInfo.department ||
    !userInfo.role ||
    !userInfo.gender ||
    !userInfo.city ||
    !userInfo.dob;

  const modalButtons = (
    <ModalButtons
      nameButtonSend="Пригласить"
      handleCancel={handleCancelButton}
      handleSend={handleSendButton}
      justifyContent="end"
      disableSend={checkFillUserInfo}
      fullWidth
    />
  );

  return (
    <>
      {isAvailableRole && (
        <>
          <CustomButton
            color="secondary"
            text="Добавить сотрудника"
            startIcon={<PersonAddIcon />}
            onClick={handleModal}
          />
          <DialogWrapper
            openModal={openModal}
            handleModal={handleModal}
            width="532px"
            contentDividers
            buttons={modalButtons}
          >
            <CreateUserContent userInfo={userInfo} setUserInfo={setUserInfo} />
          </DialogWrapper>
        </>
      )}
    </>
  );
};

export default CreateUser;
