import React, { FC, useContext, useState } from "react";
import { useNavigate } from "react-router-dom";

import { Box } from "@mui/material";
import { BackButton } from "../../../common/Buttons/BackButton/BackButton";
import EditPopover from "../../../common/Modals/EditPopover/EditPopover";
import { AppContext } from "../../../shared/AppContextProvider";
import { roles } from "../../../../constants/role";
import { kbController } from "../../../../services/kb.controller";
import ConfirmModal from "../../../common/Modals/ConfirmModal/ConfirmModal";
import CreateArticleModal from "../../CreateArticleModal/CreateArticleModal";
import { KbContext } from "../../KbContextProvider/KbContextProvider";
import { ArticleMainData } from "../../../../types/ArticleMainData.types";
import SectionSelectionModal from "../../SectionSelectionModal/SectionSelectionModal";

export const ArticleHeader: FC = () => {
  const navigate = useNavigate();

  const { handleSnackbar } = useContext(KbContext);
  const { user } = useContext(AppContext);
  const editAvailable = user.role !== roles.user;
  const articleMainData: ArticleMainData = JSON.parse(
    localStorage.getItem("article") || "{}"
  );

  const [openConfirmModal, setOpenConfirmModal] = useState<boolean>(false);
  const handleConfirmModal = () => {
    setOpenConfirmModal((prev) => !prev);
  };

  const handleDelete = () => {
    kbController
      .deleteArticle(articleMainData.articleId, articleMainData.sectionId)
      .then(() => {
        handleConfirmModal();
        navigate(-1);
      })
      .catch(() => {
        handleSnackbar("error");
      });
  };

  const [openEditModal, setOpenEditmModal] = useState<boolean>(false);
  const handleEditModal = () => {
    setOpenEditmModal((prev) => !prev);
  };

  const [openMoveModal, setOpenMoveModal] = useState<boolean>(false);
  const handleMoveModal = () => {
    setOpenMoveModal((prev) => !prev);
  };

  const popoverButtons = [
    { name: "Редактировать", action: handleEditModal },
    { name: "Переместить в раздел", action: handleMoveModal },
    { name: "Удалить", action: handleConfirmModal },
  ];

  return (
    <>
      <Box display="flex" justifyContent="space-between">
        <BackButton />
        {editAvailable && <EditPopover buttonsData={popoverButtons} />}
      </Box>
      {openConfirmModal && (
        <ConfirmModal
          openConfirmModal={openConfirmModal}
          handleModal={handleConfirmModal}
          nameConfirmButton="Удалить"
          handleConfirm={handleDelete}
          text="Статья будет удалена."
        />
      )}
      {openEditModal && (
        <CreateArticleModal
          open={openEditModal}
          handleModal={handleEditModal}
          type="edit"
        />
      )}
      {openMoveModal && (
        <SectionSelectionModal
          open={openMoveModal}
          handleModal={handleMoveModal}
          type="move"
        />
      )}
    </>
  );
};

export default ArticleHeader;
