import React, { useState } from 'react'
import { Box } from '@mui/material'
import group from '../../../src/assets/images/group-person.png'
import onePerson from '../../../src/assets/images/1person.png'
import twoPerson from '../../../src/assets/images/2person.png'
import CustomButton from '../common/Buttons/CustomButton/CustomButton'
import Typography from '@mui/material/Typography'
import { Swiper, SwiperSlide } from 'swiper/react'
import { Manipulation, Navigation } from 'swiper'
import useMediaQuery from '@mui/material/useMediaQuery'
import { useTheme } from '@mui/material/styles'
import Delete from '../../assets/icons/Delete'
import CircularProgress from '@mui/material/CircularProgress'

const imgGroup = [
  { src: onePerson, plan: '10 Пользователей', price: 200, users: 10 },
  { src: twoPerson, plan: '50 Пользователей', price: 500, users: 50 },
  { src: group, plan: '100 Пользователей', price: 1200, users: 100 },
]

export const Payments = () => {
  const theme = useTheme()
  const isMobile = useMediaQuery(theme.breakpoints.only('mobile'))

  const styleSwiper = {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center',
    // gap: '44px',
    height: '50vh',
    mb: '24px',

    '& > .swiper > .swiper-wrapper > .swiper-slide': {
      borderRadius: '12px',
      display: 'flex',
      flexDirection: 'column',
      justifyContent: 'center',
      alignItems: 'center',
    },

    '& > .swiper > .swiper-button-prev, & > .swiper > .swiper-button-next': {
      color: 'rgba(229, 235, 242, 0.65)',
      padding: '16px',
      borderRadius: '180px',
      backgroundColor: 'rgba(203, 225, 255, 0.17)',
      width: '48px',
      height: '48px',
      backdropFilter: 'blur(25px)',
    },

    '& > .swiper > .swiper-button-prev::after, & > .swiper > .swiper-button-next::after': {
      fontSize: '12px',
    },
    '& > .swiper > .swiper-button-prev': {
      left: 0,
    },
    '& > .swiper > .swiper-button-next': {
      right: 0,
    },
  }

  const [total, setTotal] = useState(0)
  const [usersTotal, setUsersTotal] = useState(0)
  const [loading, setLoading] = useState(true)

  const addInBasket = (priceItem: number, users: number) => {
    setTotal((prevState) => prevState + priceItem)
    setUsersTotal((prevState) => prevState + users)
  }
  const clearBasket = () => {
    setTotal(0)
    setUsersTotal(0)
  }

  const handleImageLoad = () => {
    setLoading(false)
  }

  return (
    <Box sx={{ marginInline: isMobile ? '20px' : '10px' }}>
      <Typography variant={'h3'} sx={{ display: 'flex', justifyContent: 'flex-start' }}>
        Пополнить счет
      </Typography>
      <Box height={isMobile ? 204 : 344} sx={styleSwiper}>
        <Swiper
          spaceBetween={16}
          slidesPerView='auto'
          slidesPerGroup={1}
          modules={[Navigation, Manipulation]}
          navigation={!isMobile}
          centeredSlidesBounds
          centerInsufficientSlides
          slidesOffsetAfter={0}
          normalizeSlideIndex={false}
          onActiveIndexChange={() => {}}
        >
          {imgGroup.map((item, index) => (
            <SwiperSlide id={index.toString()}>
              <Box
                sx={{
                  display: 'flex',
                  flexDirection: 'column',
                  justifyContent: 'center',
                  alignItems: 'center',
                  gap: '12px',
                  height: '80%',
                }}
              >
                <Box sx={{ height: 'calc(50vh - 60px)', width: '50%' }}>
                  {loading && (
                    <CircularProgress
                      color='inherit'
                      sx={{ position: 'relative', top: '60%', left: '20%', transform: 'translate(-50%, -50%)' }}
                    />
                  )}
                  <img
                    src={item.src}
                    alt={'logo'}
                    style={{ height: '100%', width: '100%', objectFit: 'contain', display: loading ? 'none' : 'block' }}
                    onLoad={handleImageLoad}
                  />
                </Box>
                <Box sx={{ display: 'flex', flexDirection: 'column', alignItems: 'start', justifyContent: 'start' }}>
                  <Typography>Пакет на: {item.plan}</Typography>
                  <Typography>Цена: {item.price}</Typography>
                </Box>
                <CustomButton text={'Добавить'} onClick={() => addInBasket(item.price, item.users)} />
              </Box>
            </SwiperSlide>
          ))}
        </Swiper>
        <Box
          sx={{
            width: '100%',
            display: 'flex',
            flexDirection: 'row',
            justifyContent: 'space-between',
            alignItems: 'center',
            gap: '12px',
          }}
        >
          <Box>
            <Typography>Выбрано на сумму: {total}</Typography>
            <Typography>Выбрано пользователей в пакете: {usersTotal}</Typography>
          </Box>

          <CustomButton
            text={'Очистить'}
            variant={'text'}
            startIcon={<Delete color={'primary'} />}
            onClick={clearBasket}
          />
        </Box>
      </Box>
      <CustomButton text={'Оплатить'} />
    </Box>
  )
}
