import React, {Dispatch, SetStateAction} from 'react';
import {Box} from "@mui/material";
import {styled} from "@mui/material/styles";
import Rating, {IconContainerProps} from "@mui/material/Rating";
import StarIcon from '@mui/icons-material/Star';
import {getColorByValue} from "../utils/getColorByValue";

const StyledRating = styled(Rating)(({theme}) => ({
    '& .MuiRating-iconEmpty .MuiSvgIcon-root': {
        color: theme.palette.secondary.contrastText,
    },
}));

const styleBox = {
    display: 'flex', flexDirection: 'column', alignItems: 'center', gap: '24px'
}

const styleRating = {
    display: 'flex', gap: '12px'
}

interface IProps {
    estimation: number | null
    setEstimation: Dispatch<SetStateAction<number | null>>
}

function RatingCustom({setEstimation, estimation}: IProps) {
    const [hover, setHover] = React.useState(-1);

    const customIcons:{
            [index: string]: {
                icon: React.ReactElement;
            };
        } = {};

    for (let i = 1; i <= 10; i++) {
        customIcons[i] = {
            icon: <StarIcon sx={{ color: getColorByValue(hover !== -1 ? hover : estimation) }} />
        };
    }

    function IconContainer(props: IconContainerProps) {
        const {value, ...others} = props;
        return <span {...others}>{customIcons[value].icon}</span>;
    }

    const handleChange = (e: any, value: number | null) => {
        setEstimation(value)
    }

    const handleHoverChange = (e: any, value: number) => {
        setHover(value)
    }

    return (
        <Box sx={styleBox}>
            <StyledRating
                max={10}
                name="highlight-selected-only"
                value={estimation}
                onChange={(_event, value) => handleChange(_event, value)}
                onChangeActive={(_event, value) => handleHoverChange(_event, value)}
                sx={styleRating}
                IconContainerComponent={IconContainer}
            />
            {estimation !== null && (
                <Box color={getColorByValue(hover !== -1 ? hover : estimation)}>
                    {`${(hover !== -1 ? hover : estimation)} из 10`}
                </Box>
            )}
        </Box>
    );
}

export default RatingCustom