import React, { FC } from "react";

import IconButton from "@mui/material/IconButton";
import { ReactComponent as Attachment } from "../../../../assets/icons/attachment.svg";

interface AttachmentButtonProps {
  onChange: (props?: any) => void;
  withBackground?: boolean;
  padding?: string;
  ariaDescribedby?: string;
  ariaLabel?: string;
  edge?: false | "start" | "end";
}

export const AttachmentButton: FC<AttachmentButtonProps> = ({
  onChange,
  withBackground,
  padding = "12px",
  edge,
}) => {
  const styleAttachButton = {
    width: "fit-content",
    p: padding,
    "& .MuiSvgIcon-root": {
      width: "24px",
      height: "24px",
    },
    "&:hover": {
      backgroundColor: "rgba(185, 215, 255, 0.08)",
    },
    backgroundColor: withBackground ? "rgba(203, 225, 255, 0.17)" : undefined,
  };

  return (
    <IconButton
      color="secondary"
      component="label"
      sx={styleAttachButton}
      onChange={onChange}
      disableRipple
      size="small"
      edge={edge}
    >
      <input hidden accept="*" multiple type="file" />
      <Attachment />
    </IconButton>
  );
};

export default AttachmentButton;